analyticsevent

package
v1.38.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the analyticsevent type in the database.
	Label = "analytics_event"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldEventName holds the string denoting the event_name field in the database.
	FieldEventName = "event_name"
	// FieldEventCategory holds the string denoting the event_category field in the database.
	FieldEventCategory = "event_category"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldDurationMs holds the string denoting the duration_ms field in the database.
	FieldDurationMs = "duration_ms"
	// FieldPage holds the string denoting the page field in the database.
	FieldPage = "page"
	// FieldComponent holds the string denoting the component field in the database.
	FieldComponent = "component"
	// FieldLabels holds the string denoting the labels field in the database.
	FieldLabels = "labels"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// Table holds the table name of the analyticsevent in the database.
	Table = "analytics_events"
)

Variables

var (
	// EventNameValidator is a validator for the "event_name" field. It is called by the builders before save.
	EventNameValidator func(string) error
	// EventCategoryValidator is a validator for the "event_category" field. It is called by the builders before save.
	EventCategoryValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(string) error
)

Columns holds all SQL columns for analyticsevent fields.

Functions

func And

And groups predicates with the AND operator between them.

func Component

func Component(v string) predicate.AnalyticsEvent

Component applies equality check predicate on the "component" field. It's identical to ComponentEQ.

func ComponentContains

func ComponentContains(v string) predicate.AnalyticsEvent

ComponentContains applies the Contains predicate on the "component" field.

func ComponentContainsFold

func ComponentContainsFold(v string) predicate.AnalyticsEvent

ComponentContainsFold applies the ContainsFold predicate on the "component" field.

func ComponentEQ

func ComponentEQ(v string) predicate.AnalyticsEvent

ComponentEQ applies the EQ predicate on the "component" field.

func ComponentEqualFold

func ComponentEqualFold(v string) predicate.AnalyticsEvent

ComponentEqualFold applies the EqualFold predicate on the "component" field.

func ComponentGT

func ComponentGT(v string) predicate.AnalyticsEvent

ComponentGT applies the GT predicate on the "component" field.

func ComponentGTE

func ComponentGTE(v string) predicate.AnalyticsEvent

ComponentGTE applies the GTE predicate on the "component" field.

func ComponentHasPrefix

func ComponentHasPrefix(v string) predicate.AnalyticsEvent

ComponentHasPrefix applies the HasPrefix predicate on the "component" field.

func ComponentHasSuffix

func ComponentHasSuffix(v string) predicate.AnalyticsEvent

ComponentHasSuffix applies the HasSuffix predicate on the "component" field.

func ComponentIn

func ComponentIn(vs ...string) predicate.AnalyticsEvent

ComponentIn applies the In predicate on the "component" field.

func ComponentIsNil

func ComponentIsNil() predicate.AnalyticsEvent

ComponentIsNil applies the IsNil predicate on the "component" field.

func ComponentLT

func ComponentLT(v string) predicate.AnalyticsEvent

ComponentLT applies the LT predicate on the "component" field.

func ComponentLTE

func ComponentLTE(v string) predicate.AnalyticsEvent

ComponentLTE applies the LTE predicate on the "component" field.

func ComponentNEQ

func ComponentNEQ(v string) predicate.AnalyticsEvent

ComponentNEQ applies the NEQ predicate on the "component" field.

func ComponentNotIn

func ComponentNotIn(vs ...string) predicate.AnalyticsEvent

ComponentNotIn applies the NotIn predicate on the "component" field.

func ComponentNotNil

func ComponentNotNil() predicate.AnalyticsEvent

ComponentNotNil applies the NotNil predicate on the "component" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.AnalyticsEvent

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.AnalyticsEvent

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.AnalyticsEvent

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.AnalyticsEvent

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.AnalyticsEvent

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.AnalyticsEvent

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.AnalyticsEvent

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.AnalyticsEvent

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.AnalyticsEvent

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DurationMs

func DurationMs(v int64) predicate.AnalyticsEvent

DurationMs applies equality check predicate on the "duration_ms" field. It's identical to DurationMsEQ.

func DurationMsEQ

func DurationMsEQ(v int64) predicate.AnalyticsEvent

DurationMsEQ applies the EQ predicate on the "duration_ms" field.

func DurationMsGT

func DurationMsGT(v int64) predicate.AnalyticsEvent

DurationMsGT applies the GT predicate on the "duration_ms" field.

func DurationMsGTE

func DurationMsGTE(v int64) predicate.AnalyticsEvent

DurationMsGTE applies the GTE predicate on the "duration_ms" field.

func DurationMsIn

func DurationMsIn(vs ...int64) predicate.AnalyticsEvent

DurationMsIn applies the In predicate on the "duration_ms" field.

func DurationMsIsNil

func DurationMsIsNil() predicate.AnalyticsEvent

DurationMsIsNil applies the IsNil predicate on the "duration_ms" field.

func DurationMsLT

func DurationMsLT(v int64) predicate.AnalyticsEvent

DurationMsLT applies the LT predicate on the "duration_ms" field.

func DurationMsLTE

func DurationMsLTE(v int64) predicate.AnalyticsEvent

DurationMsLTE applies the LTE predicate on the "duration_ms" field.

func DurationMsNEQ

func DurationMsNEQ(v int64) predicate.AnalyticsEvent

DurationMsNEQ applies the NEQ predicate on the "duration_ms" field.

func DurationMsNotIn

func DurationMsNotIn(vs ...int64) predicate.AnalyticsEvent

DurationMsNotIn applies the NotIn predicate on the "duration_ms" field.

func DurationMsNotNil

func DurationMsNotNil() predicate.AnalyticsEvent

DurationMsNotNil applies the NotNil predicate on the "duration_ms" field.

func EventCategory

func EventCategory(v string) predicate.AnalyticsEvent

EventCategory applies equality check predicate on the "event_category" field. It's identical to EventCategoryEQ.

func EventCategoryContains

func EventCategoryContains(v string) predicate.AnalyticsEvent

EventCategoryContains applies the Contains predicate on the "event_category" field.

func EventCategoryContainsFold

func EventCategoryContainsFold(v string) predicate.AnalyticsEvent

EventCategoryContainsFold applies the ContainsFold predicate on the "event_category" field.

func EventCategoryEQ

func EventCategoryEQ(v string) predicate.AnalyticsEvent

EventCategoryEQ applies the EQ predicate on the "event_category" field.

func EventCategoryEqualFold

func EventCategoryEqualFold(v string) predicate.AnalyticsEvent

EventCategoryEqualFold applies the EqualFold predicate on the "event_category" field.

func EventCategoryGT

func EventCategoryGT(v string) predicate.AnalyticsEvent

EventCategoryGT applies the GT predicate on the "event_category" field.

func EventCategoryGTE

func EventCategoryGTE(v string) predicate.AnalyticsEvent

EventCategoryGTE applies the GTE predicate on the "event_category" field.

func EventCategoryHasPrefix

func EventCategoryHasPrefix(v string) predicate.AnalyticsEvent

EventCategoryHasPrefix applies the HasPrefix predicate on the "event_category" field.

func EventCategoryHasSuffix

func EventCategoryHasSuffix(v string) predicate.AnalyticsEvent

EventCategoryHasSuffix applies the HasSuffix predicate on the "event_category" field.

func EventCategoryIn

func EventCategoryIn(vs ...string) predicate.AnalyticsEvent

EventCategoryIn applies the In predicate on the "event_category" field.

func EventCategoryLT

func EventCategoryLT(v string) predicate.AnalyticsEvent

EventCategoryLT applies the LT predicate on the "event_category" field.

func EventCategoryLTE

func EventCategoryLTE(v string) predicate.AnalyticsEvent

EventCategoryLTE applies the LTE predicate on the "event_category" field.

func EventCategoryNEQ

func EventCategoryNEQ(v string) predicate.AnalyticsEvent

EventCategoryNEQ applies the NEQ predicate on the "event_category" field.

func EventCategoryNotIn

func EventCategoryNotIn(vs ...string) predicate.AnalyticsEvent

EventCategoryNotIn applies the NotIn predicate on the "event_category" field.

func EventName

func EventName(v string) predicate.AnalyticsEvent

EventName applies equality check predicate on the "event_name" field. It's identical to EventNameEQ.

func EventNameContains

func EventNameContains(v string) predicate.AnalyticsEvent

EventNameContains applies the Contains predicate on the "event_name" field.

func EventNameContainsFold

func EventNameContainsFold(v string) predicate.AnalyticsEvent

EventNameContainsFold applies the ContainsFold predicate on the "event_name" field.

func EventNameEQ

func EventNameEQ(v string) predicate.AnalyticsEvent

EventNameEQ applies the EQ predicate on the "event_name" field.

func EventNameEqualFold

func EventNameEqualFold(v string) predicate.AnalyticsEvent

EventNameEqualFold applies the EqualFold predicate on the "event_name" field.

func EventNameGT

func EventNameGT(v string) predicate.AnalyticsEvent

EventNameGT applies the GT predicate on the "event_name" field.

func EventNameGTE

func EventNameGTE(v string) predicate.AnalyticsEvent

EventNameGTE applies the GTE predicate on the "event_name" field.

func EventNameHasPrefix

func EventNameHasPrefix(v string) predicate.AnalyticsEvent

EventNameHasPrefix applies the HasPrefix predicate on the "event_name" field.

func EventNameHasSuffix

func EventNameHasSuffix(v string) predicate.AnalyticsEvent

EventNameHasSuffix applies the HasSuffix predicate on the "event_name" field.

func EventNameIn

func EventNameIn(vs ...string) predicate.AnalyticsEvent

EventNameIn applies the In predicate on the "event_name" field.

func EventNameLT

func EventNameLT(v string) predicate.AnalyticsEvent

EventNameLT applies the LT predicate on the "event_name" field.

func EventNameLTE

func EventNameLTE(v string) predicate.AnalyticsEvent

EventNameLTE applies the LTE predicate on the "event_name" field.

func EventNameNEQ

func EventNameNEQ(v string) predicate.AnalyticsEvent

EventNameNEQ applies the NEQ predicate on the "event_name" field.

func EventNameNotIn

func EventNameNotIn(vs ...string) predicate.AnalyticsEvent

EventNameNotIn applies the NotIn predicate on the "event_name" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.AnalyticsEvent

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.AnalyticsEvent

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.AnalyticsEvent

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.AnalyticsEvent

IDNotIn applies the NotIn predicate on the ID field.

func LabelsIsNil

func LabelsIsNil() predicate.AnalyticsEvent

LabelsIsNil applies the IsNil predicate on the "labels" field.

func LabelsNotNil

func LabelsNotNil() predicate.AnalyticsEvent

LabelsNotNil applies the NotNil predicate on the "labels" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Page

Page applies equality check predicate on the "page" field. It's identical to PageEQ.

func PageContains

func PageContains(v string) predicate.AnalyticsEvent

PageContains applies the Contains predicate on the "page" field.

func PageContainsFold

func PageContainsFold(v string) predicate.AnalyticsEvent

PageContainsFold applies the ContainsFold predicate on the "page" field.

func PageEQ

PageEQ applies the EQ predicate on the "page" field.

func PageEqualFold

func PageEqualFold(v string) predicate.AnalyticsEvent

PageEqualFold applies the EqualFold predicate on the "page" field.

func PageGT

PageGT applies the GT predicate on the "page" field.

func PageGTE

func PageGTE(v string) predicate.AnalyticsEvent

PageGTE applies the GTE predicate on the "page" field.

func PageHasPrefix

func PageHasPrefix(v string) predicate.AnalyticsEvent

PageHasPrefix applies the HasPrefix predicate on the "page" field.

func PageHasSuffix

func PageHasSuffix(v string) predicate.AnalyticsEvent

PageHasSuffix applies the HasSuffix predicate on the "page" field.

func PageIn

func PageIn(vs ...string) predicate.AnalyticsEvent

PageIn applies the In predicate on the "page" field.

func PageIsNil

func PageIsNil() predicate.AnalyticsEvent

PageIsNil applies the IsNil predicate on the "page" field.

func PageLT

PageLT applies the LT predicate on the "page" field.

func PageLTE

func PageLTE(v string) predicate.AnalyticsEvent

PageLTE applies the LTE predicate on the "page" field.

func PageNEQ

func PageNEQ(v string) predicate.AnalyticsEvent

PageNEQ applies the NEQ predicate on the "page" field.

func PageNotIn

func PageNotIn(vs ...string) predicate.AnalyticsEvent

PageNotIn applies the NotIn predicate on the "page" field.

func PageNotNil

func PageNotNil() predicate.AnalyticsEvent

PageNotNil applies the NotNil predicate on the "page" field.

func SessionID

func SessionID(v string) predicate.AnalyticsEvent

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.AnalyticsEvent

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.AnalyticsEvent

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

func SessionIDEQ(v string) predicate.AnalyticsEvent

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.AnalyticsEvent

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

func SessionIDGT(v string) predicate.AnalyticsEvent

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

func SessionIDGTE(v string) predicate.AnalyticsEvent

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.AnalyticsEvent

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.AnalyticsEvent

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.AnalyticsEvent

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDIsNil

func SessionIDIsNil() predicate.AnalyticsEvent

SessionIDIsNil applies the IsNil predicate on the "session_id" field.

func SessionIDLT

func SessionIDLT(v string) predicate.AnalyticsEvent

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

func SessionIDLTE(v string) predicate.AnalyticsEvent

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

func SessionIDNEQ(v string) predicate.AnalyticsEvent

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.AnalyticsEvent

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func SessionIDNotNil

func SessionIDNotNil() predicate.AnalyticsEvent

SessionIDNotNil applies the NotNil predicate on the "session_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the AnalyticsEvent queries.

func ByComponent

func ByComponent(opts ...sql.OrderTermOption) OrderOption

ByComponent orders the results by the component field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDurationMs

func ByDurationMs(opts ...sql.OrderTermOption) OrderOption

ByDurationMs orders the results by the duration_ms field.

func ByEventCategory

func ByEventCategory(opts ...sql.OrderTermOption) OrderOption

ByEventCategory orders the results by the event_category field.

func ByEventName

func ByEventName(opts ...sql.OrderTermOption) OrderOption

ByEventName orders the results by the event_name field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByPage

func ByPage(opts ...sql.OrderTermOption) OrderOption

ByPage orders the results by the page field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

Jump to