classificationanalytics

package
v1.24.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the classificationanalytics type in the database.
	Label = "classification_analytics"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldAnalyticsID holds the string denoting the analytics_id field in the database.
	FieldAnalyticsID = "analytics_id"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldToolName holds the string denoting the tool_name field in the database.
	FieldToolName = "tool_name"
	// FieldCommandPreview holds the string denoting the command_preview field in the database.
	FieldCommandPreview = "command_preview"
	// FieldCwd holds the string denoting the cwd field in the database.
	FieldCwd = "cwd"
	// FieldDecision holds the string denoting the decision field in the database.
	FieldDecision = "decision"
	// FieldRiskLevel holds the string denoting the risk_level field in the database.
	FieldRiskLevel = "risk_level"
	// FieldRuleID holds the string denoting the rule_id field in the database.
	FieldRuleID = "rule_id"
	// FieldRuleName holds the string denoting the rule_name field in the database.
	FieldRuleName = "rule_name"
	// FieldReason holds the string denoting the reason field in the database.
	FieldReason = "reason"
	// FieldAlternative holds the string denoting the alternative field in the database.
	FieldAlternative = "alternative"
	// FieldDurationMs holds the string denoting the duration_ms field in the database.
	FieldDurationMs = "duration_ms"
	// FieldApprovalID holds the string denoting the approval_id field in the database.
	FieldApprovalID = "approval_id"
	// FieldCommandProgram holds the string denoting the command_program field in the database.
	FieldCommandProgram = "command_program"
	// FieldCommandCategory holds the string denoting the command_category field in the database.
	FieldCommandCategory = "command_category"
	// FieldCommandSubcategory holds the string denoting the command_subcategory field in the database.
	FieldCommandSubcategory = "command_subcategory"
	// FieldPythonImports holds the string denoting the python_imports field in the database.
	FieldPythonImports = "python_imports"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// Table holds the table name of the classificationanalytics in the database.
	Table = "classification_analytics"
)

Variables

var (
	// AnalyticsIDValidator is a validator for the "analytics_id" field. It is called by the builders before save.
	AnalyticsIDValidator func(string) error
	// ToolNameValidator is a validator for the "tool_name" field. It is called by the builders before save.
	ToolNameValidator func(string) error
	// DecisionValidator is a validator for the "decision" field. It is called by the builders before save.
	DecisionValidator func(string) error
	// RiskLevelValidator is a validator for the "risk_level" field. It is called by the builders before save.
	RiskLevelValidator func(string) error
	// DefaultDurationMs holds the default value on creation for the "duration_ms" field.
	DefaultDurationMs int64
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)

Columns holds all SQL columns for classificationanalytics fields.

Functions

func Alternative

Alternative applies equality check predicate on the "alternative" field. It's identical to AlternativeEQ.

func AlternativeContains

func AlternativeContains(v string) predicate.ClassificationAnalytics

AlternativeContains applies the Contains predicate on the "alternative" field.

func AlternativeContainsFold

func AlternativeContainsFold(v string) predicate.ClassificationAnalytics

AlternativeContainsFold applies the ContainsFold predicate on the "alternative" field.

func AlternativeEQ

func AlternativeEQ(v string) predicate.ClassificationAnalytics

AlternativeEQ applies the EQ predicate on the "alternative" field.

func AlternativeEqualFold

func AlternativeEqualFold(v string) predicate.ClassificationAnalytics

AlternativeEqualFold applies the EqualFold predicate on the "alternative" field.

func AlternativeGT

func AlternativeGT(v string) predicate.ClassificationAnalytics

AlternativeGT applies the GT predicate on the "alternative" field.

func AlternativeGTE

func AlternativeGTE(v string) predicate.ClassificationAnalytics

AlternativeGTE applies the GTE predicate on the "alternative" field.

func AlternativeHasPrefix

func AlternativeHasPrefix(v string) predicate.ClassificationAnalytics

AlternativeHasPrefix applies the HasPrefix predicate on the "alternative" field.

func AlternativeHasSuffix

func AlternativeHasSuffix(v string) predicate.ClassificationAnalytics

AlternativeHasSuffix applies the HasSuffix predicate on the "alternative" field.

func AlternativeIn

func AlternativeIn(vs ...string) predicate.ClassificationAnalytics

AlternativeIn applies the In predicate on the "alternative" field.

func AlternativeIsNil

func AlternativeIsNil() predicate.ClassificationAnalytics

AlternativeIsNil applies the IsNil predicate on the "alternative" field.

func AlternativeLT

func AlternativeLT(v string) predicate.ClassificationAnalytics

AlternativeLT applies the LT predicate on the "alternative" field.

func AlternativeLTE

func AlternativeLTE(v string) predicate.ClassificationAnalytics

AlternativeLTE applies the LTE predicate on the "alternative" field.

func AlternativeNEQ

func AlternativeNEQ(v string) predicate.ClassificationAnalytics

AlternativeNEQ applies the NEQ predicate on the "alternative" field.

func AlternativeNotIn

func AlternativeNotIn(vs ...string) predicate.ClassificationAnalytics

AlternativeNotIn applies the NotIn predicate on the "alternative" field.

func AlternativeNotNil

func AlternativeNotNil() predicate.ClassificationAnalytics

AlternativeNotNil applies the NotNil predicate on the "alternative" field.

func AnalyticsID

AnalyticsID applies equality check predicate on the "analytics_id" field. It's identical to AnalyticsIDEQ.

func AnalyticsIDContains

func AnalyticsIDContains(v string) predicate.ClassificationAnalytics

AnalyticsIDContains applies the Contains predicate on the "analytics_id" field.

func AnalyticsIDContainsFold

func AnalyticsIDContainsFold(v string) predicate.ClassificationAnalytics

AnalyticsIDContainsFold applies the ContainsFold predicate on the "analytics_id" field.

func AnalyticsIDEQ

func AnalyticsIDEQ(v string) predicate.ClassificationAnalytics

AnalyticsIDEQ applies the EQ predicate on the "analytics_id" field.

func AnalyticsIDEqualFold

func AnalyticsIDEqualFold(v string) predicate.ClassificationAnalytics

AnalyticsIDEqualFold applies the EqualFold predicate on the "analytics_id" field.

func AnalyticsIDGT

func AnalyticsIDGT(v string) predicate.ClassificationAnalytics

AnalyticsIDGT applies the GT predicate on the "analytics_id" field.

func AnalyticsIDGTE

func AnalyticsIDGTE(v string) predicate.ClassificationAnalytics

AnalyticsIDGTE applies the GTE predicate on the "analytics_id" field.

func AnalyticsIDHasPrefix

func AnalyticsIDHasPrefix(v string) predicate.ClassificationAnalytics

AnalyticsIDHasPrefix applies the HasPrefix predicate on the "analytics_id" field.

func AnalyticsIDHasSuffix

func AnalyticsIDHasSuffix(v string) predicate.ClassificationAnalytics

AnalyticsIDHasSuffix applies the HasSuffix predicate on the "analytics_id" field.

func AnalyticsIDIn

func AnalyticsIDIn(vs ...string) predicate.ClassificationAnalytics

AnalyticsIDIn applies the In predicate on the "analytics_id" field.

func AnalyticsIDLT

func AnalyticsIDLT(v string) predicate.ClassificationAnalytics

AnalyticsIDLT applies the LT predicate on the "analytics_id" field.

func AnalyticsIDLTE

func AnalyticsIDLTE(v string) predicate.ClassificationAnalytics

AnalyticsIDLTE applies the LTE predicate on the "analytics_id" field.

func AnalyticsIDNEQ

func AnalyticsIDNEQ(v string) predicate.ClassificationAnalytics

AnalyticsIDNEQ applies the NEQ predicate on the "analytics_id" field.

func AnalyticsIDNotIn

func AnalyticsIDNotIn(vs ...string) predicate.ClassificationAnalytics

AnalyticsIDNotIn applies the NotIn predicate on the "analytics_id" field.

func And

And groups predicates with the AND operator between them.

func ApprovalID

ApprovalID applies equality check predicate on the "approval_id" field. It's identical to ApprovalIDEQ.

func ApprovalIDContains

func ApprovalIDContains(v string) predicate.ClassificationAnalytics

ApprovalIDContains applies the Contains predicate on the "approval_id" field.

func ApprovalIDContainsFold

func ApprovalIDContainsFold(v string) predicate.ClassificationAnalytics

ApprovalIDContainsFold applies the ContainsFold predicate on the "approval_id" field.

func ApprovalIDEQ

ApprovalIDEQ applies the EQ predicate on the "approval_id" field.

func ApprovalIDEqualFold

func ApprovalIDEqualFold(v string) predicate.ClassificationAnalytics

ApprovalIDEqualFold applies the EqualFold predicate on the "approval_id" field.

func ApprovalIDGT

ApprovalIDGT applies the GT predicate on the "approval_id" field.

func ApprovalIDGTE

func ApprovalIDGTE(v string) predicate.ClassificationAnalytics

ApprovalIDGTE applies the GTE predicate on the "approval_id" field.

func ApprovalIDHasPrefix

func ApprovalIDHasPrefix(v string) predicate.ClassificationAnalytics

ApprovalIDHasPrefix applies the HasPrefix predicate on the "approval_id" field.

func ApprovalIDHasSuffix

func ApprovalIDHasSuffix(v string) predicate.ClassificationAnalytics

ApprovalIDHasSuffix applies the HasSuffix predicate on the "approval_id" field.

func ApprovalIDIn

func ApprovalIDIn(vs ...string) predicate.ClassificationAnalytics

ApprovalIDIn applies the In predicate on the "approval_id" field.

func ApprovalIDIsNil

func ApprovalIDIsNil() predicate.ClassificationAnalytics

ApprovalIDIsNil applies the IsNil predicate on the "approval_id" field.

func ApprovalIDLT

ApprovalIDLT applies the LT predicate on the "approval_id" field.

func ApprovalIDLTE

func ApprovalIDLTE(v string) predicate.ClassificationAnalytics

ApprovalIDLTE applies the LTE predicate on the "approval_id" field.

func ApprovalIDNEQ

func ApprovalIDNEQ(v string) predicate.ClassificationAnalytics

ApprovalIDNEQ applies the NEQ predicate on the "approval_id" field.

func ApprovalIDNotIn

func ApprovalIDNotIn(vs ...string) predicate.ClassificationAnalytics

ApprovalIDNotIn applies the NotIn predicate on the "approval_id" field.

func ApprovalIDNotNil

func ApprovalIDNotNil() predicate.ClassificationAnalytics

ApprovalIDNotNil applies the NotNil predicate on the "approval_id" field.

func CommandCategory

func CommandCategory(v string) predicate.ClassificationAnalytics

CommandCategory applies equality check predicate on the "command_category" field. It's identical to CommandCategoryEQ.

func CommandCategoryContains

func CommandCategoryContains(v string) predicate.ClassificationAnalytics

CommandCategoryContains applies the Contains predicate on the "command_category" field.

func CommandCategoryContainsFold

func CommandCategoryContainsFold(v string) predicate.ClassificationAnalytics

CommandCategoryContainsFold applies the ContainsFold predicate on the "command_category" field.

func CommandCategoryEQ

func CommandCategoryEQ(v string) predicate.ClassificationAnalytics

CommandCategoryEQ applies the EQ predicate on the "command_category" field.

func CommandCategoryEqualFold

func CommandCategoryEqualFold(v string) predicate.ClassificationAnalytics

CommandCategoryEqualFold applies the EqualFold predicate on the "command_category" field.

func CommandCategoryGT

func CommandCategoryGT(v string) predicate.ClassificationAnalytics

CommandCategoryGT applies the GT predicate on the "command_category" field.

func CommandCategoryGTE

func CommandCategoryGTE(v string) predicate.ClassificationAnalytics

CommandCategoryGTE applies the GTE predicate on the "command_category" field.

func CommandCategoryHasPrefix

func CommandCategoryHasPrefix(v string) predicate.ClassificationAnalytics

CommandCategoryHasPrefix applies the HasPrefix predicate on the "command_category" field.

func CommandCategoryHasSuffix

func CommandCategoryHasSuffix(v string) predicate.ClassificationAnalytics

CommandCategoryHasSuffix applies the HasSuffix predicate on the "command_category" field.

func CommandCategoryIn

func CommandCategoryIn(vs ...string) predicate.ClassificationAnalytics

CommandCategoryIn applies the In predicate on the "command_category" field.

func CommandCategoryIsNil

func CommandCategoryIsNil() predicate.ClassificationAnalytics

CommandCategoryIsNil applies the IsNil predicate on the "command_category" field.

func CommandCategoryLT

func CommandCategoryLT(v string) predicate.ClassificationAnalytics

CommandCategoryLT applies the LT predicate on the "command_category" field.

func CommandCategoryLTE

func CommandCategoryLTE(v string) predicate.ClassificationAnalytics

CommandCategoryLTE applies the LTE predicate on the "command_category" field.

func CommandCategoryNEQ

func CommandCategoryNEQ(v string) predicate.ClassificationAnalytics

CommandCategoryNEQ applies the NEQ predicate on the "command_category" field.

func CommandCategoryNotIn

func CommandCategoryNotIn(vs ...string) predicate.ClassificationAnalytics

CommandCategoryNotIn applies the NotIn predicate on the "command_category" field.

func CommandCategoryNotNil

func CommandCategoryNotNil() predicate.ClassificationAnalytics

CommandCategoryNotNil applies the NotNil predicate on the "command_category" field.

func CommandPreview

func CommandPreview(v string) predicate.ClassificationAnalytics

CommandPreview applies equality check predicate on the "command_preview" field. It's identical to CommandPreviewEQ.

func CommandPreviewContains

func CommandPreviewContains(v string) predicate.ClassificationAnalytics

CommandPreviewContains applies the Contains predicate on the "command_preview" field.

func CommandPreviewContainsFold

func CommandPreviewContainsFold(v string) predicate.ClassificationAnalytics

CommandPreviewContainsFold applies the ContainsFold predicate on the "command_preview" field.

func CommandPreviewEQ

func CommandPreviewEQ(v string) predicate.ClassificationAnalytics

CommandPreviewEQ applies the EQ predicate on the "command_preview" field.

func CommandPreviewEqualFold

func CommandPreviewEqualFold(v string) predicate.ClassificationAnalytics

CommandPreviewEqualFold applies the EqualFold predicate on the "command_preview" field.

func CommandPreviewGT

func CommandPreviewGT(v string) predicate.ClassificationAnalytics

CommandPreviewGT applies the GT predicate on the "command_preview" field.

func CommandPreviewGTE

func CommandPreviewGTE(v string) predicate.ClassificationAnalytics

CommandPreviewGTE applies the GTE predicate on the "command_preview" field.

func CommandPreviewHasPrefix

func CommandPreviewHasPrefix(v string) predicate.ClassificationAnalytics

CommandPreviewHasPrefix applies the HasPrefix predicate on the "command_preview" field.

func CommandPreviewHasSuffix

func CommandPreviewHasSuffix(v string) predicate.ClassificationAnalytics

CommandPreviewHasSuffix applies the HasSuffix predicate on the "command_preview" field.

func CommandPreviewIn

func CommandPreviewIn(vs ...string) predicate.ClassificationAnalytics

CommandPreviewIn applies the In predicate on the "command_preview" field.

func CommandPreviewIsNil

func CommandPreviewIsNil() predicate.ClassificationAnalytics

CommandPreviewIsNil applies the IsNil predicate on the "command_preview" field.

func CommandPreviewLT

func CommandPreviewLT(v string) predicate.ClassificationAnalytics

CommandPreviewLT applies the LT predicate on the "command_preview" field.

func CommandPreviewLTE

func CommandPreviewLTE(v string) predicate.ClassificationAnalytics

CommandPreviewLTE applies the LTE predicate on the "command_preview" field.

func CommandPreviewNEQ

func CommandPreviewNEQ(v string) predicate.ClassificationAnalytics

CommandPreviewNEQ applies the NEQ predicate on the "command_preview" field.

func CommandPreviewNotIn

func CommandPreviewNotIn(vs ...string) predicate.ClassificationAnalytics

CommandPreviewNotIn applies the NotIn predicate on the "command_preview" field.

func CommandPreviewNotNil

func CommandPreviewNotNil() predicate.ClassificationAnalytics

CommandPreviewNotNil applies the NotNil predicate on the "command_preview" field.

func CommandProgram

func CommandProgram(v string) predicate.ClassificationAnalytics

CommandProgram applies equality check predicate on the "command_program" field. It's identical to CommandProgramEQ.

func CommandProgramContains

func CommandProgramContains(v string) predicate.ClassificationAnalytics

CommandProgramContains applies the Contains predicate on the "command_program" field.

func CommandProgramContainsFold

func CommandProgramContainsFold(v string) predicate.ClassificationAnalytics

CommandProgramContainsFold applies the ContainsFold predicate on the "command_program" field.

func CommandProgramEQ

func CommandProgramEQ(v string) predicate.ClassificationAnalytics

CommandProgramEQ applies the EQ predicate on the "command_program" field.

func CommandProgramEqualFold

func CommandProgramEqualFold(v string) predicate.ClassificationAnalytics

CommandProgramEqualFold applies the EqualFold predicate on the "command_program" field.

func CommandProgramGT

func CommandProgramGT(v string) predicate.ClassificationAnalytics

CommandProgramGT applies the GT predicate on the "command_program" field.

func CommandProgramGTE

func CommandProgramGTE(v string) predicate.ClassificationAnalytics

CommandProgramGTE applies the GTE predicate on the "command_program" field.

func CommandProgramHasPrefix

func CommandProgramHasPrefix(v string) predicate.ClassificationAnalytics

CommandProgramHasPrefix applies the HasPrefix predicate on the "command_program" field.

func CommandProgramHasSuffix

func CommandProgramHasSuffix(v string) predicate.ClassificationAnalytics

CommandProgramHasSuffix applies the HasSuffix predicate on the "command_program" field.

func CommandProgramIn

func CommandProgramIn(vs ...string) predicate.ClassificationAnalytics

CommandProgramIn applies the In predicate on the "command_program" field.

func CommandProgramIsNil

func CommandProgramIsNil() predicate.ClassificationAnalytics

CommandProgramIsNil applies the IsNil predicate on the "command_program" field.

func CommandProgramLT

func CommandProgramLT(v string) predicate.ClassificationAnalytics

CommandProgramLT applies the LT predicate on the "command_program" field.

func CommandProgramLTE

func CommandProgramLTE(v string) predicate.ClassificationAnalytics

CommandProgramLTE applies the LTE predicate on the "command_program" field.

func CommandProgramNEQ

func CommandProgramNEQ(v string) predicate.ClassificationAnalytics

CommandProgramNEQ applies the NEQ predicate on the "command_program" field.

func CommandProgramNotIn

func CommandProgramNotIn(vs ...string) predicate.ClassificationAnalytics

CommandProgramNotIn applies the NotIn predicate on the "command_program" field.

func CommandProgramNotNil

func CommandProgramNotNil() predicate.ClassificationAnalytics

CommandProgramNotNil applies the NotNil predicate on the "command_program" field.

func CommandSubcategory

func CommandSubcategory(v string) predicate.ClassificationAnalytics

CommandSubcategory applies equality check predicate on the "command_subcategory" field. It's identical to CommandSubcategoryEQ.

func CommandSubcategoryContains

func CommandSubcategoryContains(v string) predicate.ClassificationAnalytics

CommandSubcategoryContains applies the Contains predicate on the "command_subcategory" field.

func CommandSubcategoryContainsFold

func CommandSubcategoryContainsFold(v string) predicate.ClassificationAnalytics

CommandSubcategoryContainsFold applies the ContainsFold predicate on the "command_subcategory" field.

func CommandSubcategoryEQ

func CommandSubcategoryEQ(v string) predicate.ClassificationAnalytics

CommandSubcategoryEQ applies the EQ predicate on the "command_subcategory" field.

func CommandSubcategoryEqualFold

func CommandSubcategoryEqualFold(v string) predicate.ClassificationAnalytics

CommandSubcategoryEqualFold applies the EqualFold predicate on the "command_subcategory" field.

func CommandSubcategoryGT

func CommandSubcategoryGT(v string) predicate.ClassificationAnalytics

CommandSubcategoryGT applies the GT predicate on the "command_subcategory" field.

func CommandSubcategoryGTE

func CommandSubcategoryGTE(v string) predicate.ClassificationAnalytics

CommandSubcategoryGTE applies the GTE predicate on the "command_subcategory" field.

func CommandSubcategoryHasPrefix

func CommandSubcategoryHasPrefix(v string) predicate.ClassificationAnalytics

CommandSubcategoryHasPrefix applies the HasPrefix predicate on the "command_subcategory" field.

func CommandSubcategoryHasSuffix

func CommandSubcategoryHasSuffix(v string) predicate.ClassificationAnalytics

CommandSubcategoryHasSuffix applies the HasSuffix predicate on the "command_subcategory" field.

func CommandSubcategoryIn

func CommandSubcategoryIn(vs ...string) predicate.ClassificationAnalytics

CommandSubcategoryIn applies the In predicate on the "command_subcategory" field.

func CommandSubcategoryIsNil

func CommandSubcategoryIsNil() predicate.ClassificationAnalytics

CommandSubcategoryIsNil applies the IsNil predicate on the "command_subcategory" field.

func CommandSubcategoryLT

func CommandSubcategoryLT(v string) predicate.ClassificationAnalytics

CommandSubcategoryLT applies the LT predicate on the "command_subcategory" field.

func CommandSubcategoryLTE

func CommandSubcategoryLTE(v string) predicate.ClassificationAnalytics

CommandSubcategoryLTE applies the LTE predicate on the "command_subcategory" field.

func CommandSubcategoryNEQ

func CommandSubcategoryNEQ(v string) predicate.ClassificationAnalytics

CommandSubcategoryNEQ applies the NEQ predicate on the "command_subcategory" field.

func CommandSubcategoryNotIn

func CommandSubcategoryNotIn(vs ...string) predicate.ClassificationAnalytics

CommandSubcategoryNotIn applies the NotIn predicate on the "command_subcategory" field.

func CommandSubcategoryNotNil

func CommandSubcategoryNotNil() predicate.ClassificationAnalytics

CommandSubcategoryNotNil applies the NotNil predicate on the "command_subcategory" field.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.ClassificationAnalytics

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.ClassificationAnalytics

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Cwd

Cwd applies equality check predicate on the "cwd" field. It's identical to CwdEQ.

func CwdContains

CwdContains applies the Contains predicate on the "cwd" field.

func CwdContainsFold

func CwdContainsFold(v string) predicate.ClassificationAnalytics

CwdContainsFold applies the ContainsFold predicate on the "cwd" field.

func CwdEQ

CwdEQ applies the EQ predicate on the "cwd" field.

func CwdEqualFold

CwdEqualFold applies the EqualFold predicate on the "cwd" field.

func CwdGT

CwdGT applies the GT predicate on the "cwd" field.

func CwdGTE

CwdGTE applies the GTE predicate on the "cwd" field.

func CwdHasPrefix

CwdHasPrefix applies the HasPrefix predicate on the "cwd" field.

func CwdHasSuffix

CwdHasSuffix applies the HasSuffix predicate on the "cwd" field.

func CwdIn

CwdIn applies the In predicate on the "cwd" field.

func CwdIsNil

CwdIsNil applies the IsNil predicate on the "cwd" field.

func CwdLT

CwdLT applies the LT predicate on the "cwd" field.

func CwdLTE

CwdLTE applies the LTE predicate on the "cwd" field.

func CwdNEQ

CwdNEQ applies the NEQ predicate on the "cwd" field.

func CwdNotIn

CwdNotIn applies the NotIn predicate on the "cwd" field.

func CwdNotNil

CwdNotNil applies the NotNil predicate on the "cwd" field.

func Decision

Decision applies equality check predicate on the "decision" field. It's identical to DecisionEQ.

func DecisionContains

func DecisionContains(v string) predicate.ClassificationAnalytics

DecisionContains applies the Contains predicate on the "decision" field.

func DecisionContainsFold

func DecisionContainsFold(v string) predicate.ClassificationAnalytics

DecisionContainsFold applies the ContainsFold predicate on the "decision" field.

func DecisionEQ

DecisionEQ applies the EQ predicate on the "decision" field.

func DecisionEqualFold

func DecisionEqualFold(v string) predicate.ClassificationAnalytics

DecisionEqualFold applies the EqualFold predicate on the "decision" field.

func DecisionGT

DecisionGT applies the GT predicate on the "decision" field.

func DecisionGTE

DecisionGTE applies the GTE predicate on the "decision" field.

func DecisionHasPrefix

func DecisionHasPrefix(v string) predicate.ClassificationAnalytics

DecisionHasPrefix applies the HasPrefix predicate on the "decision" field.

func DecisionHasSuffix

func DecisionHasSuffix(v string) predicate.ClassificationAnalytics

DecisionHasSuffix applies the HasSuffix predicate on the "decision" field.

func DecisionIn

func DecisionIn(vs ...string) predicate.ClassificationAnalytics

DecisionIn applies the In predicate on the "decision" field.

func DecisionLT

DecisionLT applies the LT predicate on the "decision" field.

func DecisionLTE

DecisionLTE applies the LTE predicate on the "decision" field.

func DecisionNEQ

DecisionNEQ applies the NEQ predicate on the "decision" field.

func DecisionNotIn

func DecisionNotIn(vs ...string) predicate.ClassificationAnalytics

DecisionNotIn applies the NotIn predicate on the "decision" field.

func DurationMs

DurationMs applies equality check predicate on the "duration_ms" field. It's identical to DurationMsEQ.

func DurationMsEQ

func DurationMsEQ(v int64) predicate.ClassificationAnalytics

DurationMsEQ applies the EQ predicate on the "duration_ms" field.

func DurationMsGT

func DurationMsGT(v int64) predicate.ClassificationAnalytics

DurationMsGT applies the GT predicate on the "duration_ms" field.

func DurationMsGTE

func DurationMsGTE(v int64) predicate.ClassificationAnalytics

DurationMsGTE applies the GTE predicate on the "duration_ms" field.

func DurationMsIn

func DurationMsIn(vs ...int64) predicate.ClassificationAnalytics

DurationMsIn applies the In predicate on the "duration_ms" field.

func DurationMsLT

func DurationMsLT(v int64) predicate.ClassificationAnalytics

DurationMsLT applies the LT predicate on the "duration_ms" field.

func DurationMsLTE

func DurationMsLTE(v int64) predicate.ClassificationAnalytics

DurationMsLTE applies the LTE predicate on the "duration_ms" field.

func DurationMsNEQ

func DurationMsNEQ(v int64) predicate.ClassificationAnalytics

DurationMsNEQ applies the NEQ predicate on the "duration_ms" field.

func DurationMsNotIn

func DurationMsNotIn(vs ...int64) predicate.ClassificationAnalytics

DurationMsNotIn applies the NotIn predicate on the "duration_ms" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.ClassificationAnalytics

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func PythonImportsIsNil

func PythonImportsIsNil() predicate.ClassificationAnalytics

PythonImportsIsNil applies the IsNil predicate on the "python_imports" field.

func PythonImportsNotNil

func PythonImportsNotNil() predicate.ClassificationAnalytics

PythonImportsNotNil applies the NotNil predicate on the "python_imports" field.

func Reason

Reason applies equality check predicate on the "reason" field. It's identical to ReasonEQ.

func ReasonContains

func ReasonContains(v string) predicate.ClassificationAnalytics

ReasonContains applies the Contains predicate on the "reason" field.

func ReasonContainsFold

func ReasonContainsFold(v string) predicate.ClassificationAnalytics

ReasonContainsFold applies the ContainsFold predicate on the "reason" field.

func ReasonEQ

ReasonEQ applies the EQ predicate on the "reason" field.

func ReasonEqualFold

func ReasonEqualFold(v string) predicate.ClassificationAnalytics

ReasonEqualFold applies the EqualFold predicate on the "reason" field.

func ReasonGT

ReasonGT applies the GT predicate on the "reason" field.

func ReasonGTE

ReasonGTE applies the GTE predicate on the "reason" field.

func ReasonHasPrefix

func ReasonHasPrefix(v string) predicate.ClassificationAnalytics

ReasonHasPrefix applies the HasPrefix predicate on the "reason" field.

func ReasonHasSuffix

func ReasonHasSuffix(v string) predicate.ClassificationAnalytics

ReasonHasSuffix applies the HasSuffix predicate on the "reason" field.

func ReasonIn

ReasonIn applies the In predicate on the "reason" field.

func ReasonIsNil

func ReasonIsNil() predicate.ClassificationAnalytics

ReasonIsNil applies the IsNil predicate on the "reason" field.

func ReasonLT

ReasonLT applies the LT predicate on the "reason" field.

func ReasonLTE

ReasonLTE applies the LTE predicate on the "reason" field.

func ReasonNEQ

ReasonNEQ applies the NEQ predicate on the "reason" field.

func ReasonNotIn

func ReasonNotIn(vs ...string) predicate.ClassificationAnalytics

ReasonNotIn applies the NotIn predicate on the "reason" field.

func ReasonNotNil

func ReasonNotNil() predicate.ClassificationAnalytics

ReasonNotNil applies the NotNil predicate on the "reason" field.

func RiskLevel

RiskLevel applies equality check predicate on the "risk_level" field. It's identical to RiskLevelEQ.

func RiskLevelContains

func RiskLevelContains(v string) predicate.ClassificationAnalytics

RiskLevelContains applies the Contains predicate on the "risk_level" field.

func RiskLevelContainsFold

func RiskLevelContainsFold(v string) predicate.ClassificationAnalytics

RiskLevelContainsFold applies the ContainsFold predicate on the "risk_level" field.

func RiskLevelEQ

RiskLevelEQ applies the EQ predicate on the "risk_level" field.

func RiskLevelEqualFold

func RiskLevelEqualFold(v string) predicate.ClassificationAnalytics

RiskLevelEqualFold applies the EqualFold predicate on the "risk_level" field.

func RiskLevelGT

RiskLevelGT applies the GT predicate on the "risk_level" field.

func RiskLevelGTE

RiskLevelGTE applies the GTE predicate on the "risk_level" field.

func RiskLevelHasPrefix

func RiskLevelHasPrefix(v string) predicate.ClassificationAnalytics

RiskLevelHasPrefix applies the HasPrefix predicate on the "risk_level" field.

func RiskLevelHasSuffix

func RiskLevelHasSuffix(v string) predicate.ClassificationAnalytics

RiskLevelHasSuffix applies the HasSuffix predicate on the "risk_level" field.

func RiskLevelIn

func RiskLevelIn(vs ...string) predicate.ClassificationAnalytics

RiskLevelIn applies the In predicate on the "risk_level" field.

func RiskLevelLT

RiskLevelLT applies the LT predicate on the "risk_level" field.

func RiskLevelLTE

RiskLevelLTE applies the LTE predicate on the "risk_level" field.

func RiskLevelNEQ

RiskLevelNEQ applies the NEQ predicate on the "risk_level" field.

func RiskLevelNotIn

func RiskLevelNotIn(vs ...string) predicate.ClassificationAnalytics

RiskLevelNotIn applies the NotIn predicate on the "risk_level" field.

func RuleID

RuleID applies equality check predicate on the "rule_id" field. It's identical to RuleIDEQ.

func RuleIDContains

func RuleIDContains(v string) predicate.ClassificationAnalytics

RuleIDContains applies the Contains predicate on the "rule_id" field.

func RuleIDContainsFold

func RuleIDContainsFold(v string) predicate.ClassificationAnalytics

RuleIDContainsFold applies the ContainsFold predicate on the "rule_id" field.

func RuleIDEQ

RuleIDEQ applies the EQ predicate on the "rule_id" field.

func RuleIDEqualFold

func RuleIDEqualFold(v string) predicate.ClassificationAnalytics

RuleIDEqualFold applies the EqualFold predicate on the "rule_id" field.

func RuleIDGT

RuleIDGT applies the GT predicate on the "rule_id" field.

func RuleIDGTE

RuleIDGTE applies the GTE predicate on the "rule_id" field.

func RuleIDHasPrefix

func RuleIDHasPrefix(v string) predicate.ClassificationAnalytics

RuleIDHasPrefix applies the HasPrefix predicate on the "rule_id" field.

func RuleIDHasSuffix

func RuleIDHasSuffix(v string) predicate.ClassificationAnalytics

RuleIDHasSuffix applies the HasSuffix predicate on the "rule_id" field.

func RuleIDIn

RuleIDIn applies the In predicate on the "rule_id" field.

func RuleIDIsNil

func RuleIDIsNil() predicate.ClassificationAnalytics

RuleIDIsNil applies the IsNil predicate on the "rule_id" field.

func RuleIDLT

RuleIDLT applies the LT predicate on the "rule_id" field.

func RuleIDLTE

RuleIDLTE applies the LTE predicate on the "rule_id" field.

func RuleIDNEQ

RuleIDNEQ applies the NEQ predicate on the "rule_id" field.

func RuleIDNotIn

func RuleIDNotIn(vs ...string) predicate.ClassificationAnalytics

RuleIDNotIn applies the NotIn predicate on the "rule_id" field.

func RuleIDNotNil

func RuleIDNotNil() predicate.ClassificationAnalytics

RuleIDNotNil applies the NotNil predicate on the "rule_id" field.

func RuleName

RuleName applies equality check predicate on the "rule_name" field. It's identical to RuleNameEQ.

func RuleNameContains

func RuleNameContains(v string) predicate.ClassificationAnalytics

RuleNameContains applies the Contains predicate on the "rule_name" field.

func RuleNameContainsFold

func RuleNameContainsFold(v string) predicate.ClassificationAnalytics

RuleNameContainsFold applies the ContainsFold predicate on the "rule_name" field.

func RuleNameEQ

RuleNameEQ applies the EQ predicate on the "rule_name" field.

func RuleNameEqualFold

func RuleNameEqualFold(v string) predicate.ClassificationAnalytics

RuleNameEqualFold applies the EqualFold predicate on the "rule_name" field.

func RuleNameGT

RuleNameGT applies the GT predicate on the "rule_name" field.

func RuleNameGTE

RuleNameGTE applies the GTE predicate on the "rule_name" field.

func RuleNameHasPrefix

func RuleNameHasPrefix(v string) predicate.ClassificationAnalytics

RuleNameHasPrefix applies the HasPrefix predicate on the "rule_name" field.

func RuleNameHasSuffix

func RuleNameHasSuffix(v string) predicate.ClassificationAnalytics

RuleNameHasSuffix applies the HasSuffix predicate on the "rule_name" field.

func RuleNameIn

func RuleNameIn(vs ...string) predicate.ClassificationAnalytics

RuleNameIn applies the In predicate on the "rule_name" field.

func RuleNameIsNil

func RuleNameIsNil() predicate.ClassificationAnalytics

RuleNameIsNil applies the IsNil predicate on the "rule_name" field.

func RuleNameLT

RuleNameLT applies the LT predicate on the "rule_name" field.

func RuleNameLTE

RuleNameLTE applies the LTE predicate on the "rule_name" field.

func RuleNameNEQ

RuleNameNEQ applies the NEQ predicate on the "rule_name" field.

func RuleNameNotIn

func RuleNameNotIn(vs ...string) predicate.ClassificationAnalytics

RuleNameNotIn applies the NotIn predicate on the "rule_name" field.

func RuleNameNotNil

func RuleNameNotNil() predicate.ClassificationAnalytics

RuleNameNotNil applies the NotNil predicate on the "rule_name" field.

func SessionID

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.ClassificationAnalytics

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.ClassificationAnalytics

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.ClassificationAnalytics

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.ClassificationAnalytics

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.ClassificationAnalytics

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.ClassificationAnalytics

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDIsNil

func SessionIDIsNil() predicate.ClassificationAnalytics

SessionIDIsNil applies the IsNil predicate on the "session_id" field.

func SessionIDLT

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.ClassificationAnalytics

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func SessionIDNotNil

func SessionIDNotNil() predicate.ClassificationAnalytics

SessionIDNotNil applies the NotNil predicate on the "session_id" field.

func ToolName

ToolName applies equality check predicate on the "tool_name" field. It's identical to ToolNameEQ.

func ToolNameContains

func ToolNameContains(v string) predicate.ClassificationAnalytics

ToolNameContains applies the Contains predicate on the "tool_name" field.

func ToolNameContainsFold

func ToolNameContainsFold(v string) predicate.ClassificationAnalytics

ToolNameContainsFold applies the ContainsFold predicate on the "tool_name" field.

func ToolNameEQ

ToolNameEQ applies the EQ predicate on the "tool_name" field.

func ToolNameEqualFold

func ToolNameEqualFold(v string) predicate.ClassificationAnalytics

ToolNameEqualFold applies the EqualFold predicate on the "tool_name" field.

func ToolNameGT

ToolNameGT applies the GT predicate on the "tool_name" field.

func ToolNameGTE

ToolNameGTE applies the GTE predicate on the "tool_name" field.

func ToolNameHasPrefix

func ToolNameHasPrefix(v string) predicate.ClassificationAnalytics

ToolNameHasPrefix applies the HasPrefix predicate on the "tool_name" field.

func ToolNameHasSuffix

func ToolNameHasSuffix(v string) predicate.ClassificationAnalytics

ToolNameHasSuffix applies the HasSuffix predicate on the "tool_name" field.

func ToolNameIn

func ToolNameIn(vs ...string) predicate.ClassificationAnalytics

ToolNameIn applies the In predicate on the "tool_name" field.

func ToolNameLT

ToolNameLT applies the LT predicate on the "tool_name" field.

func ToolNameLTE

ToolNameLTE applies the LTE predicate on the "tool_name" field.

func ToolNameNEQ

ToolNameNEQ applies the NEQ predicate on the "tool_name" field.

func ToolNameNotIn

func ToolNameNotIn(vs ...string) predicate.ClassificationAnalytics

ToolNameNotIn applies the NotIn predicate on the "tool_name" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ClassificationAnalytics queries.

func ByAlternative

func ByAlternative(opts ...sql.OrderTermOption) OrderOption

ByAlternative orders the results by the alternative field.

func ByAnalyticsID

func ByAnalyticsID(opts ...sql.OrderTermOption) OrderOption

ByAnalyticsID orders the results by the analytics_id field.

func ByApprovalID

func ByApprovalID(opts ...sql.OrderTermOption) OrderOption

ByApprovalID orders the results by the approval_id field.

func ByCommandCategory

func ByCommandCategory(opts ...sql.OrderTermOption) OrderOption

ByCommandCategory orders the results by the command_category field.

func ByCommandPreview

func ByCommandPreview(opts ...sql.OrderTermOption) OrderOption

ByCommandPreview orders the results by the command_preview field.

func ByCommandProgram

func ByCommandProgram(opts ...sql.OrderTermOption) OrderOption

ByCommandProgram orders the results by the command_program field.

func ByCommandSubcategory

func ByCommandSubcategory(opts ...sql.OrderTermOption) OrderOption

ByCommandSubcategory orders the results by the command_subcategory field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCwd

func ByCwd(opts ...sql.OrderTermOption) OrderOption

ByCwd orders the results by the cwd field.

func ByDecision

func ByDecision(opts ...sql.OrderTermOption) OrderOption

ByDecision orders the results by the decision field.

func ByDurationMs

func ByDurationMs(opts ...sql.OrderTermOption) OrderOption

ByDurationMs orders the results by the duration_ms field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByReason

func ByReason(opts ...sql.OrderTermOption) OrderOption

ByReason orders the results by the reason field.

func ByRiskLevel

func ByRiskLevel(opts ...sql.OrderTermOption) OrderOption

ByRiskLevel orders the results by the risk_level field.

func ByRuleID

func ByRuleID(opts ...sql.OrderTermOption) OrderOption

ByRuleID orders the results by the rule_id field.

func ByRuleName

func ByRuleName(opts ...sql.OrderTermOption) OrderOption

ByRuleName orders the results by the rule_name field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

func ByToolName

func ByToolName(opts ...sql.OrderTermOption) OrderOption

ByToolName orders the results by the tool_name field.

Jump to