claudemetadata

package
v1.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the claudemetadata type in the database.
	Label = "claude_metadata"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldKey holds the string denoting the key field in the database.
	FieldKey = "key"
	// FieldValue holds the string denoting the value field in the database.
	FieldValue = "value"
	// EdgeClaudeSession holds the string denoting the claude_session edge name in mutations.
	EdgeClaudeSession = "claude_session"
	// Table holds the table name of the claudemetadata in the database.
	Table = "claude_metadata"
	// ClaudeSessionTable is the table that holds the claude_session relation/edge.
	ClaudeSessionTable = "claude_metadata"
	// ClaudeSessionInverseTable is the table name for the ClaudeSession entity.
	// It exists in this package in order to avoid circular dependency with the "claudesession" package.
	ClaudeSessionInverseTable = "claude_sessions"
	// ClaudeSessionColumn is the table column denoting the claude_session relation/edge.
	ClaudeSessionColumn = "claude_session_metadata"
)

Variables

var (
	// KeyValidator is a validator for the "key" field. It is called by the builders before save.
	KeyValidator func(string) error
	// ValueValidator is a validator for the "value" field. It is called by the builders before save.
	ValueValidator func(string) error
)
var Columns = []string{
	FieldID,
	FieldKey,
	FieldValue,
}

Columns holds all SQL columns for claudemetadata fields.

var ForeignKeys = []string{
	"claude_session_metadata",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "claude_metadata" table and are not defined as standalone fields in the schema.

Functions

func And

And groups predicates with the AND operator between them.

func HasClaudeSession

func HasClaudeSession() predicate.ClaudeMetadata

HasClaudeSession applies the HasEdge predicate on the "claude_session" edge.

func HasClaudeSessionWith

func HasClaudeSessionWith(preds ...predicate.ClaudeSession) predicate.ClaudeMetadata

HasClaudeSessionWith applies the HasEdge predicate on the "claude_session" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.ClaudeMetadata

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.ClaudeMetadata

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.ClaudeMetadata

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.ClaudeMetadata

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.ClaudeMetadata

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.ClaudeMetadata

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.ClaudeMetadata

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.ClaudeMetadata

IDNotIn applies the NotIn predicate on the ID field.

func Key

Key applies equality check predicate on the "key" field. It's identical to KeyEQ.

func KeyContains

func KeyContains(v string) predicate.ClaudeMetadata

KeyContains applies the Contains predicate on the "key" field.

func KeyContainsFold

func KeyContainsFold(v string) predicate.ClaudeMetadata

KeyContainsFold applies the ContainsFold predicate on the "key" field.

func KeyEQ

KeyEQ applies the EQ predicate on the "key" field.

func KeyEqualFold

func KeyEqualFold(v string) predicate.ClaudeMetadata

KeyEqualFold applies the EqualFold predicate on the "key" field.

func KeyGT

KeyGT applies the GT predicate on the "key" field.

func KeyGTE

KeyGTE applies the GTE predicate on the "key" field.

func KeyHasPrefix

func KeyHasPrefix(v string) predicate.ClaudeMetadata

KeyHasPrefix applies the HasPrefix predicate on the "key" field.

func KeyHasSuffix

func KeyHasSuffix(v string) predicate.ClaudeMetadata

KeyHasSuffix applies the HasSuffix predicate on the "key" field.

func KeyIn

func KeyIn(vs ...string) predicate.ClaudeMetadata

KeyIn applies the In predicate on the "key" field.

func KeyLT

KeyLT applies the LT predicate on the "key" field.

func KeyLTE

KeyLTE applies the LTE predicate on the "key" field.

func KeyNEQ

KeyNEQ applies the NEQ predicate on the "key" field.

func KeyNotIn

func KeyNotIn(vs ...string) predicate.ClaudeMetadata

KeyNotIn applies the NotIn predicate on the "key" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Value

Value applies equality check predicate on the "value" field. It's identical to ValueEQ.

func ValueContains

func ValueContains(v string) predicate.ClaudeMetadata

ValueContains applies the Contains predicate on the "value" field.

func ValueContainsFold

func ValueContainsFold(v string) predicate.ClaudeMetadata

ValueContainsFold applies the ContainsFold predicate on the "value" field.

func ValueEQ

func ValueEQ(v string) predicate.ClaudeMetadata

ValueEQ applies the EQ predicate on the "value" field.

func ValueEqualFold

func ValueEqualFold(v string) predicate.ClaudeMetadata

ValueEqualFold applies the EqualFold predicate on the "value" field.

func ValueGT

func ValueGT(v string) predicate.ClaudeMetadata

ValueGT applies the GT predicate on the "value" field.

func ValueGTE

func ValueGTE(v string) predicate.ClaudeMetadata

ValueGTE applies the GTE predicate on the "value" field.

func ValueHasPrefix

func ValueHasPrefix(v string) predicate.ClaudeMetadata

ValueHasPrefix applies the HasPrefix predicate on the "value" field.

func ValueHasSuffix

func ValueHasSuffix(v string) predicate.ClaudeMetadata

ValueHasSuffix applies the HasSuffix predicate on the "value" field.

func ValueIn

func ValueIn(vs ...string) predicate.ClaudeMetadata

ValueIn applies the In predicate on the "value" field.

func ValueLT

func ValueLT(v string) predicate.ClaudeMetadata

ValueLT applies the LT predicate on the "value" field.

func ValueLTE

func ValueLTE(v string) predicate.ClaudeMetadata

ValueLTE applies the LTE predicate on the "value" field.

func ValueNEQ

func ValueNEQ(v string) predicate.ClaudeMetadata

ValueNEQ applies the NEQ predicate on the "value" field.

func ValueNotIn

func ValueNotIn(vs ...string) predicate.ClaudeMetadata

ValueNotIn applies the NotIn predicate on the "value" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ClaudeMetadata queries.

func ByClaudeSessionField

func ByClaudeSessionField(field string, opts ...sql.OrderTermOption) OrderOption

ByClaudeSessionField orders the results by claude_session field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKey

func ByKey(opts ...sql.OrderTermOption) OrderOption

ByKey orders the results by the key field.

func ByValue

func ByValue(opts ...sql.OrderTermOption) OrderOption

ByValue orders the results by the value field.

Jump to