escapeevent

package
v1.44.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the escapeevent type in the database.
	Label = "escape_event"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldStage holds the string denoting the stage field in the database.
	FieldStage = "stage"
	// FieldSequenceType holds the string denoting the sequence_type field in the database.
	FieldSequenceType = "sequence_type"
	// FieldSequenceSubtype holds the string denoting the sequence_subtype field in the database.
	FieldSequenceSubtype = "sequence_subtype"
	// FieldByteLength holds the string denoting the byte_length field in the database.
	FieldByteLength = "byte_length"
	// FieldPayloadHash holds the string denoting the payload_hash field in the database.
	FieldPayloadHash = "payload_hash"
	// FieldRawBytes holds the string denoting the raw_bytes field in the database.
	FieldRawBytes = "raw_bytes"
	// FieldMangled holds the string denoting the mangled field in the database.
	FieldMangled = "mangled"
	// FieldMangleType holds the string denoting the mangle_type field in the database.
	FieldMangleType = "mangle_type"
	// FieldWallTime holds the string denoting the wall_time field in the database.
	FieldWallTime = "wall_time"
	// FieldSessionSeq holds the string denoting the session_seq field in the database.
	FieldSessionSeq = "session_seq"
	// Table holds the table name of the escapeevent in the database.
	Table = "escape_events"
)

Variables

var (
	// SessionIDValidator is a validator for the "session_id" field. It is called by the builders before save.
	SessionIDValidator func(string) error
	// StageValidator is a validator for the "stage" field. It is called by the builders before save.
	StageValidator func(string) error
	// SequenceTypeValidator is a validator for the "sequence_type" field. It is called by the builders before save.
	SequenceTypeValidator func(string) error
	// DefaultMangled holds the default value on creation for the "mangled" field.
	DefaultMangled bool
	// DefaultWallTime holds the default value on creation for the "wall_time" field.
	DefaultWallTime func() time.Time
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(string) error
)

Columns holds all SQL columns for escapeevent fields.

Functions

func And

func And(predicates ...predicate.EscapeEvent) predicate.EscapeEvent

And groups predicates with the AND operator between them.

func ByteLength

func ByteLength(v int) predicate.EscapeEvent

ByteLength applies equality check predicate on the "byte_length" field. It's identical to ByteLengthEQ.

func ByteLengthEQ

func ByteLengthEQ(v int) predicate.EscapeEvent

ByteLengthEQ applies the EQ predicate on the "byte_length" field.

func ByteLengthGT

func ByteLengthGT(v int) predicate.EscapeEvent

ByteLengthGT applies the GT predicate on the "byte_length" field.

func ByteLengthGTE

func ByteLengthGTE(v int) predicate.EscapeEvent

ByteLengthGTE applies the GTE predicate on the "byte_length" field.

func ByteLengthIn

func ByteLengthIn(vs ...int) predicate.EscapeEvent

ByteLengthIn applies the In predicate on the "byte_length" field.

func ByteLengthLT

func ByteLengthLT(v int) predicate.EscapeEvent

ByteLengthLT applies the LT predicate on the "byte_length" field.

func ByteLengthLTE

func ByteLengthLTE(v int) predicate.EscapeEvent

ByteLengthLTE applies the LTE predicate on the "byte_length" field.

func ByteLengthNEQ

func ByteLengthNEQ(v int) predicate.EscapeEvent

ByteLengthNEQ applies the NEQ predicate on the "byte_length" field.

func ByteLengthNotIn

func ByteLengthNotIn(vs ...int) predicate.EscapeEvent

ByteLengthNotIn applies the NotIn predicate on the "byte_length" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.EscapeEvent

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.EscapeEvent

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.EscapeEvent

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.EscapeEvent

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.EscapeEvent

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.EscapeEvent

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.EscapeEvent

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.EscapeEvent

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.EscapeEvent

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.EscapeEvent

IDNotIn applies the NotIn predicate on the ID field.

func MangleType

func MangleType(v string) predicate.EscapeEvent

MangleType applies equality check predicate on the "mangle_type" field. It's identical to MangleTypeEQ.

func MangleTypeContains

func MangleTypeContains(v string) predicate.EscapeEvent

MangleTypeContains applies the Contains predicate on the "mangle_type" field.

func MangleTypeContainsFold

func MangleTypeContainsFold(v string) predicate.EscapeEvent

MangleTypeContainsFold applies the ContainsFold predicate on the "mangle_type" field.

func MangleTypeEQ

func MangleTypeEQ(v string) predicate.EscapeEvent

MangleTypeEQ applies the EQ predicate on the "mangle_type" field.

func MangleTypeEqualFold

func MangleTypeEqualFold(v string) predicate.EscapeEvent

MangleTypeEqualFold applies the EqualFold predicate on the "mangle_type" field.

func MangleTypeGT

func MangleTypeGT(v string) predicate.EscapeEvent

MangleTypeGT applies the GT predicate on the "mangle_type" field.

func MangleTypeGTE

func MangleTypeGTE(v string) predicate.EscapeEvent

MangleTypeGTE applies the GTE predicate on the "mangle_type" field.

func MangleTypeHasPrefix

func MangleTypeHasPrefix(v string) predicate.EscapeEvent

MangleTypeHasPrefix applies the HasPrefix predicate on the "mangle_type" field.

func MangleTypeHasSuffix

func MangleTypeHasSuffix(v string) predicate.EscapeEvent

MangleTypeHasSuffix applies the HasSuffix predicate on the "mangle_type" field.

func MangleTypeIn

func MangleTypeIn(vs ...string) predicate.EscapeEvent

MangleTypeIn applies the In predicate on the "mangle_type" field.

func MangleTypeIsNil

func MangleTypeIsNil() predicate.EscapeEvent

MangleTypeIsNil applies the IsNil predicate on the "mangle_type" field.

func MangleTypeLT

func MangleTypeLT(v string) predicate.EscapeEvent

MangleTypeLT applies the LT predicate on the "mangle_type" field.

func MangleTypeLTE

func MangleTypeLTE(v string) predicate.EscapeEvent

MangleTypeLTE applies the LTE predicate on the "mangle_type" field.

func MangleTypeNEQ

func MangleTypeNEQ(v string) predicate.EscapeEvent

MangleTypeNEQ applies the NEQ predicate on the "mangle_type" field.

func MangleTypeNotIn

func MangleTypeNotIn(vs ...string) predicate.EscapeEvent

MangleTypeNotIn applies the NotIn predicate on the "mangle_type" field.

func MangleTypeNotNil

func MangleTypeNotNil() predicate.EscapeEvent

MangleTypeNotNil applies the NotNil predicate on the "mangle_type" field.

func Mangled

func Mangled(v bool) predicate.EscapeEvent

Mangled applies equality check predicate on the "mangled" field. It's identical to MangledEQ.

func MangledEQ

func MangledEQ(v bool) predicate.EscapeEvent

MangledEQ applies the EQ predicate on the "mangled" field.

func MangledNEQ

func MangledNEQ(v bool) predicate.EscapeEvent

MangledNEQ applies the NEQ predicate on the "mangled" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.EscapeEvent) predicate.EscapeEvent

Or groups predicates with the OR operator between them.

func PayloadHash

func PayloadHash(v string) predicate.EscapeEvent

PayloadHash applies equality check predicate on the "payload_hash" field. It's identical to PayloadHashEQ.

func PayloadHashContains

func PayloadHashContains(v string) predicate.EscapeEvent

PayloadHashContains applies the Contains predicate on the "payload_hash" field.

func PayloadHashContainsFold

func PayloadHashContainsFold(v string) predicate.EscapeEvent

PayloadHashContainsFold applies the ContainsFold predicate on the "payload_hash" field.

func PayloadHashEQ

func PayloadHashEQ(v string) predicate.EscapeEvent

PayloadHashEQ applies the EQ predicate on the "payload_hash" field.

func PayloadHashEqualFold

func PayloadHashEqualFold(v string) predicate.EscapeEvent

PayloadHashEqualFold applies the EqualFold predicate on the "payload_hash" field.

func PayloadHashGT

func PayloadHashGT(v string) predicate.EscapeEvent

PayloadHashGT applies the GT predicate on the "payload_hash" field.

func PayloadHashGTE

func PayloadHashGTE(v string) predicate.EscapeEvent

PayloadHashGTE applies the GTE predicate on the "payload_hash" field.

func PayloadHashHasPrefix

func PayloadHashHasPrefix(v string) predicate.EscapeEvent

PayloadHashHasPrefix applies the HasPrefix predicate on the "payload_hash" field.

func PayloadHashHasSuffix

func PayloadHashHasSuffix(v string) predicate.EscapeEvent

PayloadHashHasSuffix applies the HasSuffix predicate on the "payload_hash" field.

func PayloadHashIn

func PayloadHashIn(vs ...string) predicate.EscapeEvent

PayloadHashIn applies the In predicate on the "payload_hash" field.

func PayloadHashIsNil

func PayloadHashIsNil() predicate.EscapeEvent

PayloadHashIsNil applies the IsNil predicate on the "payload_hash" field.

func PayloadHashLT

func PayloadHashLT(v string) predicate.EscapeEvent

PayloadHashLT applies the LT predicate on the "payload_hash" field.

func PayloadHashLTE

func PayloadHashLTE(v string) predicate.EscapeEvent

PayloadHashLTE applies the LTE predicate on the "payload_hash" field.

func PayloadHashNEQ

func PayloadHashNEQ(v string) predicate.EscapeEvent

PayloadHashNEQ applies the NEQ predicate on the "payload_hash" field.

func PayloadHashNotIn

func PayloadHashNotIn(vs ...string) predicate.EscapeEvent

PayloadHashNotIn applies the NotIn predicate on the "payload_hash" field.

func PayloadHashNotNil

func PayloadHashNotNil() predicate.EscapeEvent

PayloadHashNotNil applies the NotNil predicate on the "payload_hash" field.

func RawBytes

func RawBytes(v []byte) predicate.EscapeEvent

RawBytes applies equality check predicate on the "raw_bytes" field. It's identical to RawBytesEQ.

func RawBytesEQ

func RawBytesEQ(v []byte) predicate.EscapeEvent

RawBytesEQ applies the EQ predicate on the "raw_bytes" field.

func RawBytesGT

func RawBytesGT(v []byte) predicate.EscapeEvent

RawBytesGT applies the GT predicate on the "raw_bytes" field.

func RawBytesGTE

func RawBytesGTE(v []byte) predicate.EscapeEvent

RawBytesGTE applies the GTE predicate on the "raw_bytes" field.

func RawBytesIn

func RawBytesIn(vs ...[]byte) predicate.EscapeEvent

RawBytesIn applies the In predicate on the "raw_bytes" field.

func RawBytesIsNil

func RawBytesIsNil() predicate.EscapeEvent

RawBytesIsNil applies the IsNil predicate on the "raw_bytes" field.

func RawBytesLT

func RawBytesLT(v []byte) predicate.EscapeEvent

RawBytesLT applies the LT predicate on the "raw_bytes" field.

func RawBytesLTE

func RawBytesLTE(v []byte) predicate.EscapeEvent

RawBytesLTE applies the LTE predicate on the "raw_bytes" field.

func RawBytesNEQ

func RawBytesNEQ(v []byte) predicate.EscapeEvent

RawBytesNEQ applies the NEQ predicate on the "raw_bytes" field.

func RawBytesNotIn

func RawBytesNotIn(vs ...[]byte) predicate.EscapeEvent

RawBytesNotIn applies the NotIn predicate on the "raw_bytes" field.

func RawBytesNotNil

func RawBytesNotNil() predicate.EscapeEvent

RawBytesNotNil applies the NotNil predicate on the "raw_bytes" field.

func SequenceSubtype

func SequenceSubtype(v string) predicate.EscapeEvent

SequenceSubtype applies equality check predicate on the "sequence_subtype" field. It's identical to SequenceSubtypeEQ.

func SequenceSubtypeContains

func SequenceSubtypeContains(v string) predicate.EscapeEvent

SequenceSubtypeContains applies the Contains predicate on the "sequence_subtype" field.

func SequenceSubtypeContainsFold

func SequenceSubtypeContainsFold(v string) predicate.EscapeEvent

SequenceSubtypeContainsFold applies the ContainsFold predicate on the "sequence_subtype" field.

func SequenceSubtypeEQ

func SequenceSubtypeEQ(v string) predicate.EscapeEvent

SequenceSubtypeEQ applies the EQ predicate on the "sequence_subtype" field.

func SequenceSubtypeEqualFold

func SequenceSubtypeEqualFold(v string) predicate.EscapeEvent

SequenceSubtypeEqualFold applies the EqualFold predicate on the "sequence_subtype" field.

func SequenceSubtypeGT

func SequenceSubtypeGT(v string) predicate.EscapeEvent

SequenceSubtypeGT applies the GT predicate on the "sequence_subtype" field.

func SequenceSubtypeGTE

func SequenceSubtypeGTE(v string) predicate.EscapeEvent

SequenceSubtypeGTE applies the GTE predicate on the "sequence_subtype" field.

func SequenceSubtypeHasPrefix

func SequenceSubtypeHasPrefix(v string) predicate.EscapeEvent

SequenceSubtypeHasPrefix applies the HasPrefix predicate on the "sequence_subtype" field.

func SequenceSubtypeHasSuffix

func SequenceSubtypeHasSuffix(v string) predicate.EscapeEvent

SequenceSubtypeHasSuffix applies the HasSuffix predicate on the "sequence_subtype" field.

func SequenceSubtypeIn

func SequenceSubtypeIn(vs ...string) predicate.EscapeEvent

SequenceSubtypeIn applies the In predicate on the "sequence_subtype" field.

func SequenceSubtypeIsNil

func SequenceSubtypeIsNil() predicate.EscapeEvent

SequenceSubtypeIsNil applies the IsNil predicate on the "sequence_subtype" field.

func SequenceSubtypeLT

func SequenceSubtypeLT(v string) predicate.EscapeEvent

SequenceSubtypeLT applies the LT predicate on the "sequence_subtype" field.

func SequenceSubtypeLTE

func SequenceSubtypeLTE(v string) predicate.EscapeEvent

SequenceSubtypeLTE applies the LTE predicate on the "sequence_subtype" field.

func SequenceSubtypeNEQ

func SequenceSubtypeNEQ(v string) predicate.EscapeEvent

SequenceSubtypeNEQ applies the NEQ predicate on the "sequence_subtype" field.

func SequenceSubtypeNotIn

func SequenceSubtypeNotIn(vs ...string) predicate.EscapeEvent

SequenceSubtypeNotIn applies the NotIn predicate on the "sequence_subtype" field.

func SequenceSubtypeNotNil

func SequenceSubtypeNotNil() predicate.EscapeEvent

SequenceSubtypeNotNil applies the NotNil predicate on the "sequence_subtype" field.

func SequenceType

func SequenceType(v string) predicate.EscapeEvent

SequenceType applies equality check predicate on the "sequence_type" field. It's identical to SequenceTypeEQ.

func SequenceTypeContains

func SequenceTypeContains(v string) predicate.EscapeEvent

SequenceTypeContains applies the Contains predicate on the "sequence_type" field.

func SequenceTypeContainsFold

func SequenceTypeContainsFold(v string) predicate.EscapeEvent

SequenceTypeContainsFold applies the ContainsFold predicate on the "sequence_type" field.

func SequenceTypeEQ

func SequenceTypeEQ(v string) predicate.EscapeEvent

SequenceTypeEQ applies the EQ predicate on the "sequence_type" field.

func SequenceTypeEqualFold

func SequenceTypeEqualFold(v string) predicate.EscapeEvent

SequenceTypeEqualFold applies the EqualFold predicate on the "sequence_type" field.

func SequenceTypeGT

func SequenceTypeGT(v string) predicate.EscapeEvent

SequenceTypeGT applies the GT predicate on the "sequence_type" field.

func SequenceTypeGTE

func SequenceTypeGTE(v string) predicate.EscapeEvent

SequenceTypeGTE applies the GTE predicate on the "sequence_type" field.

func SequenceTypeHasPrefix

func SequenceTypeHasPrefix(v string) predicate.EscapeEvent

SequenceTypeHasPrefix applies the HasPrefix predicate on the "sequence_type" field.

func SequenceTypeHasSuffix

func SequenceTypeHasSuffix(v string) predicate.EscapeEvent

SequenceTypeHasSuffix applies the HasSuffix predicate on the "sequence_type" field.

func SequenceTypeIn

func SequenceTypeIn(vs ...string) predicate.EscapeEvent

SequenceTypeIn applies the In predicate on the "sequence_type" field.

func SequenceTypeLT

func SequenceTypeLT(v string) predicate.EscapeEvent

SequenceTypeLT applies the LT predicate on the "sequence_type" field.

func SequenceTypeLTE

func SequenceTypeLTE(v string) predicate.EscapeEvent

SequenceTypeLTE applies the LTE predicate on the "sequence_type" field.

func SequenceTypeNEQ

func SequenceTypeNEQ(v string) predicate.EscapeEvent

SequenceTypeNEQ applies the NEQ predicate on the "sequence_type" field.

func SequenceTypeNotIn

func SequenceTypeNotIn(vs ...string) predicate.EscapeEvent

SequenceTypeNotIn applies the NotIn predicate on the "sequence_type" field.

func SessionID

func SessionID(v string) predicate.EscapeEvent

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.EscapeEvent

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.EscapeEvent

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

func SessionIDEQ(v string) predicate.EscapeEvent

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.EscapeEvent

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

func SessionIDGT(v string) predicate.EscapeEvent

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

func SessionIDGTE(v string) predicate.EscapeEvent

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.EscapeEvent

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.EscapeEvent

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.EscapeEvent

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDLT

func SessionIDLT(v string) predicate.EscapeEvent

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

func SessionIDLTE(v string) predicate.EscapeEvent

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

func SessionIDNEQ(v string) predicate.EscapeEvent

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.EscapeEvent

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func SessionSeq

func SessionSeq(v int64) predicate.EscapeEvent

SessionSeq applies equality check predicate on the "session_seq" field. It's identical to SessionSeqEQ.

func SessionSeqEQ

func SessionSeqEQ(v int64) predicate.EscapeEvent

SessionSeqEQ applies the EQ predicate on the "session_seq" field.

func SessionSeqGT

func SessionSeqGT(v int64) predicate.EscapeEvent

SessionSeqGT applies the GT predicate on the "session_seq" field.

func SessionSeqGTE

func SessionSeqGTE(v int64) predicate.EscapeEvent

SessionSeqGTE applies the GTE predicate on the "session_seq" field.

func SessionSeqIn

func SessionSeqIn(vs ...int64) predicate.EscapeEvent

SessionSeqIn applies the In predicate on the "session_seq" field.

func SessionSeqLT

func SessionSeqLT(v int64) predicate.EscapeEvent

SessionSeqLT applies the LT predicate on the "session_seq" field.

func SessionSeqLTE

func SessionSeqLTE(v int64) predicate.EscapeEvent

SessionSeqLTE applies the LTE predicate on the "session_seq" field.

func SessionSeqNEQ

func SessionSeqNEQ(v int64) predicate.EscapeEvent

SessionSeqNEQ applies the NEQ predicate on the "session_seq" field.

func SessionSeqNotIn

func SessionSeqNotIn(vs ...int64) predicate.EscapeEvent

SessionSeqNotIn applies the NotIn predicate on the "session_seq" field.

func Stage

func Stage(v string) predicate.EscapeEvent

Stage applies equality check predicate on the "stage" field. It's identical to StageEQ.

func StageContains

func StageContains(v string) predicate.EscapeEvent

StageContains applies the Contains predicate on the "stage" field.

func StageContainsFold

func StageContainsFold(v string) predicate.EscapeEvent

StageContainsFold applies the ContainsFold predicate on the "stage" field.

func StageEQ

func StageEQ(v string) predicate.EscapeEvent

StageEQ applies the EQ predicate on the "stage" field.

func StageEqualFold

func StageEqualFold(v string) predicate.EscapeEvent

StageEqualFold applies the EqualFold predicate on the "stage" field.

func StageGT

func StageGT(v string) predicate.EscapeEvent

StageGT applies the GT predicate on the "stage" field.

func StageGTE

func StageGTE(v string) predicate.EscapeEvent

StageGTE applies the GTE predicate on the "stage" field.

func StageHasPrefix

func StageHasPrefix(v string) predicate.EscapeEvent

StageHasPrefix applies the HasPrefix predicate on the "stage" field.

func StageHasSuffix

func StageHasSuffix(v string) predicate.EscapeEvent

StageHasSuffix applies the HasSuffix predicate on the "stage" field.

func StageIn

func StageIn(vs ...string) predicate.EscapeEvent

StageIn applies the In predicate on the "stage" field.

func StageLT

func StageLT(v string) predicate.EscapeEvent

StageLT applies the LT predicate on the "stage" field.

func StageLTE

func StageLTE(v string) predicate.EscapeEvent

StageLTE applies the LTE predicate on the "stage" field.

func StageNEQ

func StageNEQ(v string) predicate.EscapeEvent

StageNEQ applies the NEQ predicate on the "stage" field.

func StageNotIn

func StageNotIn(vs ...string) predicate.EscapeEvent

StageNotIn applies the NotIn predicate on the "stage" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WallTime

func WallTime(v time.Time) predicate.EscapeEvent

WallTime applies equality check predicate on the "wall_time" field. It's identical to WallTimeEQ.

func WallTimeEQ

func WallTimeEQ(v time.Time) predicate.EscapeEvent

WallTimeEQ applies the EQ predicate on the "wall_time" field.

func WallTimeGT

func WallTimeGT(v time.Time) predicate.EscapeEvent

WallTimeGT applies the GT predicate on the "wall_time" field.

func WallTimeGTE

func WallTimeGTE(v time.Time) predicate.EscapeEvent

WallTimeGTE applies the GTE predicate on the "wall_time" field.

func WallTimeIn

func WallTimeIn(vs ...time.Time) predicate.EscapeEvent

WallTimeIn applies the In predicate on the "wall_time" field.

func WallTimeLT

func WallTimeLT(v time.Time) predicate.EscapeEvent

WallTimeLT applies the LT predicate on the "wall_time" field.

func WallTimeLTE

func WallTimeLTE(v time.Time) predicate.EscapeEvent

WallTimeLTE applies the LTE predicate on the "wall_time" field.

func WallTimeNEQ

func WallTimeNEQ(v time.Time) predicate.EscapeEvent

WallTimeNEQ applies the NEQ predicate on the "wall_time" field.

func WallTimeNotIn

func WallTimeNotIn(vs ...time.Time) predicate.EscapeEvent

WallTimeNotIn applies the NotIn predicate on the "wall_time" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the EscapeEvent queries.

func ByByteLength

func ByByteLength(opts ...sql.OrderTermOption) OrderOption

ByByteLength orders the results by the byte_length field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByMangleType

func ByMangleType(opts ...sql.OrderTermOption) OrderOption

ByMangleType orders the results by the mangle_type field.

func ByMangled

func ByMangled(opts ...sql.OrderTermOption) OrderOption

ByMangled orders the results by the mangled field.

func ByPayloadHash

func ByPayloadHash(opts ...sql.OrderTermOption) OrderOption

ByPayloadHash orders the results by the payload_hash field.

func BySequenceSubtype

func BySequenceSubtype(opts ...sql.OrderTermOption) OrderOption

BySequenceSubtype orders the results by the sequence_subtype field.

func BySequenceType

func BySequenceType(opts ...sql.OrderTermOption) OrderOption

BySequenceType orders the results by the sequence_type field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

func BySessionSeq

func BySessionSeq(opts ...sql.OrderTermOption) OrderOption

BySessionSeq orders the results by the session_seq field.

func ByStage

func ByStage(opts ...sql.OrderTermOption) OrderOption

ByStage orders the results by the stage field.

func ByWallTime

func ByWallTime(opts ...sql.OrderTermOption) OrderOption

ByWallTime orders the results by the wall_time field.

Jump to