schema

package
v0.0.0-...-6d2f010 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ApprovalRule

type ApprovalRule struct {
	ent.Schema
}

ApprovalRule holds the schema definition for the ApprovalRule entity.

func (ApprovalRule) Edges

func (ApprovalRule) Edges() []ent.Edge

Edges of the ApprovalRule.

func (ApprovalRule) Fields

func (ApprovalRule) Fields() []ent.Field

Fields of the ApprovalRule.

func (ApprovalRule) Indexes

func (ApprovalRule) Indexes() []ent.Index

Indexes of the ApprovalRule.

type ClassificationAnalytics

type ClassificationAnalytics struct {
	ent.Schema
}

ClassificationAnalytics holds the schema definition for the ClassificationAnalytics entity.

func (ClassificationAnalytics) Edges

func (ClassificationAnalytics) Edges() []ent.Edge

Edges of the ClassificationAnalytics.

func (ClassificationAnalytics) Fields

func (ClassificationAnalytics) Fields() []ent.Field

Fields of the ClassificationAnalytics.

func (ClassificationAnalytics) Indexes

func (ClassificationAnalytics) Indexes() []ent.Index

Indexes of the ClassificationAnalytics.

type ClaudeMetadata

type ClaudeMetadata struct {
	ent.Schema
}

ClaudeMetadata holds the schema definition for the ClaudeMetadata entity.

func (ClaudeMetadata) Edges

func (ClaudeMetadata) Edges() []ent.Edge

Edges of the ClaudeMetadata.

func (ClaudeMetadata) Fields

func (ClaudeMetadata) Fields() []ent.Field

Fields of the ClaudeMetadata.

type ClaudeSession

type ClaudeSession struct {
	ent.Schema
}

ClaudeSession holds the schema definition for the ClaudeSession entity.

func (ClaudeSession) Edges

func (ClaudeSession) Edges() []ent.Edge

Edges of the ClaudeSession.

func (ClaudeSession) Fields

func (ClaudeSession) Fields() []ent.Field

Fields of the ClaudeSession.

type DiffStats

type DiffStats struct {
	ent.Schema
}

DiffStats holds the schema definition for the DiffStats entity.

func (DiffStats) Edges

func (DiffStats) Edges() []ent.Edge

Edges of the DiffStats.

func (DiffStats) Fields

func (DiffStats) Fields() []ent.Field

Fields of the DiffStats.

type Session

type Session struct {
	ent.Schema
}

Session holds the schema definition for the Session entity.

func (Session) Edges

func (Session) Edges() []ent.Edge

Edges of the Session.

func (Session) Fields

func (Session) Fields() []ent.Field

Fields of the Session.

func (Session) Indexes

func (Session) Indexes() []ent.Index

Indexes of the Session.

type Tag

type Tag struct {
	ent.Schema
}

Tag holds the schema definition for the Tag entity.

func (Tag) Edges

func (Tag) Edges() []ent.Edge

Edges of the Tag.

func (Tag) Fields

func (Tag) Fields() []ent.Field

Fields of the Tag.

func (Tag) Indexes

func (Tag) Indexes() []ent.Index

Indexes of the Tag.

type Worktree

type Worktree struct {
	ent.Schema
}

Worktree holds the schema definition for the Worktree entity.

func (Worktree) Edges

func (Worktree) Edges() []ent.Edge

Edges of the Worktree.

func (Worktree) Fields

func (Worktree) Fields() []ent.Field

Fields of the Worktree.

Jump to