sessiongoal

package
v1.42.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the sessiongoal type in the database.
	Label = "session_goal"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldSessionUUID holds the string denoting the session_uuid field in the database.
	FieldSessionUUID = "session_uuid"
	// FieldGoal holds the string denoting the goal field in the database.
	FieldGoal = "goal"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldTasks holds the string denoting the tasks field in the database.
	FieldTasks = "tasks"
	// FieldSetBy holds the string denoting the set_by field in the database.
	FieldSetBy = "set_by"
	// FieldWorkspaceKey holds the string denoting the workspace_key field in the database.
	FieldWorkspaceKey = "workspace_key"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the sessiongoal in the database.
	Table = "session_goals"
)

Variables

var (
	// SessionUUIDValidator is a validator for the "session_uuid" field. It is called by the builders before save.
	SessionUUIDValidator func(string) error
	// GoalValidator is a validator for the "goal" field. It is called by the builders before save.
	GoalValidator func(string) error
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for sessiongoal fields.

Functions

func And

func And(predicates ...predicate.SessionGoal) predicate.SessionGoal

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.SessionGoal

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.SessionGoal

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.SessionGoal

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.SessionGoal

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.SessionGoal

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.SessionGoal

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.SessionGoal

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.SessionGoal

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.SessionGoal

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Goal

Goal applies equality check predicate on the "goal" field. It's identical to GoalEQ.

func GoalContains

func GoalContains(v string) predicate.SessionGoal

GoalContains applies the Contains predicate on the "goal" field.

func GoalContainsFold

func GoalContainsFold(v string) predicate.SessionGoal

GoalContainsFold applies the ContainsFold predicate on the "goal" field.

func GoalEQ

func GoalEQ(v string) predicate.SessionGoal

GoalEQ applies the EQ predicate on the "goal" field.

func GoalEqualFold

func GoalEqualFold(v string) predicate.SessionGoal

GoalEqualFold applies the EqualFold predicate on the "goal" field.

func GoalGT

func GoalGT(v string) predicate.SessionGoal

GoalGT applies the GT predicate on the "goal" field.

func GoalGTE

func GoalGTE(v string) predicate.SessionGoal

GoalGTE applies the GTE predicate on the "goal" field.

func GoalHasPrefix

func GoalHasPrefix(v string) predicate.SessionGoal

GoalHasPrefix applies the HasPrefix predicate on the "goal" field.

func GoalHasSuffix

func GoalHasSuffix(v string) predicate.SessionGoal

GoalHasSuffix applies the HasSuffix predicate on the "goal" field.

func GoalIn

func GoalIn(vs ...string) predicate.SessionGoal

GoalIn applies the In predicate on the "goal" field.

func GoalLT

func GoalLT(v string) predicate.SessionGoal

GoalLT applies the LT predicate on the "goal" field.

func GoalLTE

func GoalLTE(v string) predicate.SessionGoal

GoalLTE applies the LTE predicate on the "goal" field.

func GoalNEQ

func GoalNEQ(v string) predicate.SessionGoal

GoalNEQ applies the NEQ predicate on the "goal" field.

func GoalNotIn

func GoalNotIn(vs ...string) predicate.SessionGoal

GoalNotIn applies the NotIn predicate on the "goal" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.SessionGoal

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.SessionGoal

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.SessionGoal

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.SessionGoal

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.SessionGoal

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.SessionGoal

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.SessionGoal

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.SessionGoal

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.SessionGoal) predicate.SessionGoal

Or groups predicates with the OR operator between them.

func SessionUUID

func SessionUUID(v string) predicate.SessionGoal

SessionUUID applies equality check predicate on the "session_uuid" field. It's identical to SessionUUIDEQ.

func SessionUUIDContains

func SessionUUIDContains(v string) predicate.SessionGoal

SessionUUIDContains applies the Contains predicate on the "session_uuid" field.

func SessionUUIDContainsFold

func SessionUUIDContainsFold(v string) predicate.SessionGoal

SessionUUIDContainsFold applies the ContainsFold predicate on the "session_uuid" field.

func SessionUUIDEQ

func SessionUUIDEQ(v string) predicate.SessionGoal

SessionUUIDEQ applies the EQ predicate on the "session_uuid" field.

func SessionUUIDEqualFold

func SessionUUIDEqualFold(v string) predicate.SessionGoal

SessionUUIDEqualFold applies the EqualFold predicate on the "session_uuid" field.

func SessionUUIDGT

func SessionUUIDGT(v string) predicate.SessionGoal

SessionUUIDGT applies the GT predicate on the "session_uuid" field.

func SessionUUIDGTE

func SessionUUIDGTE(v string) predicate.SessionGoal

SessionUUIDGTE applies the GTE predicate on the "session_uuid" field.

func SessionUUIDHasPrefix

func SessionUUIDHasPrefix(v string) predicate.SessionGoal

SessionUUIDHasPrefix applies the HasPrefix predicate on the "session_uuid" field.

func SessionUUIDHasSuffix

func SessionUUIDHasSuffix(v string) predicate.SessionGoal

SessionUUIDHasSuffix applies the HasSuffix predicate on the "session_uuid" field.

func SessionUUIDIn

func SessionUUIDIn(vs ...string) predicate.SessionGoal

SessionUUIDIn applies the In predicate on the "session_uuid" field.

func SessionUUIDLT

func SessionUUIDLT(v string) predicate.SessionGoal

SessionUUIDLT applies the LT predicate on the "session_uuid" field.

func SessionUUIDLTE

func SessionUUIDLTE(v string) predicate.SessionGoal

SessionUUIDLTE applies the LTE predicate on the "session_uuid" field.

func SessionUUIDNEQ

func SessionUUIDNEQ(v string) predicate.SessionGoal

SessionUUIDNEQ applies the NEQ predicate on the "session_uuid" field.

func SessionUUIDNotIn

func SessionUUIDNotIn(vs ...string) predicate.SessionGoal

SessionUUIDNotIn applies the NotIn predicate on the "session_uuid" field.

func SetBy

func SetBy(v string) predicate.SessionGoal

SetBy applies equality check predicate on the "set_by" field. It's identical to SetByEQ.

func SetByContains

func SetByContains(v string) predicate.SessionGoal

SetByContains applies the Contains predicate on the "set_by" field.

func SetByContainsFold

func SetByContainsFold(v string) predicate.SessionGoal

SetByContainsFold applies the ContainsFold predicate on the "set_by" field.

func SetByEQ

func SetByEQ(v string) predicate.SessionGoal

SetByEQ applies the EQ predicate on the "set_by" field.

func SetByEqualFold

func SetByEqualFold(v string) predicate.SessionGoal

SetByEqualFold applies the EqualFold predicate on the "set_by" field.

func SetByGT

func SetByGT(v string) predicate.SessionGoal

SetByGT applies the GT predicate on the "set_by" field.

func SetByGTE

func SetByGTE(v string) predicate.SessionGoal

SetByGTE applies the GTE predicate on the "set_by" field.

func SetByHasPrefix

func SetByHasPrefix(v string) predicate.SessionGoal

SetByHasPrefix applies the HasPrefix predicate on the "set_by" field.

func SetByHasSuffix

func SetByHasSuffix(v string) predicate.SessionGoal

SetByHasSuffix applies the HasSuffix predicate on the "set_by" field.

func SetByIn

func SetByIn(vs ...string) predicate.SessionGoal

SetByIn applies the In predicate on the "set_by" field.

func SetByIsNil

func SetByIsNil() predicate.SessionGoal

SetByIsNil applies the IsNil predicate on the "set_by" field.

func SetByLT

func SetByLT(v string) predicate.SessionGoal

SetByLT applies the LT predicate on the "set_by" field.

func SetByLTE

func SetByLTE(v string) predicate.SessionGoal

SetByLTE applies the LTE predicate on the "set_by" field.

func SetByNEQ

func SetByNEQ(v string) predicate.SessionGoal

SetByNEQ applies the NEQ predicate on the "set_by" field.

func SetByNotIn

func SetByNotIn(vs ...string) predicate.SessionGoal

SetByNotIn applies the NotIn predicate on the "set_by" field.

func SetByNotNil

func SetByNotNil() predicate.SessionGoal

SetByNotNil applies the NotNil predicate on the "set_by" field.

func Status

func Status(v string) predicate.SessionGoal

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.SessionGoal

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.SessionGoal

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.SessionGoal

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.SessionGoal

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.SessionGoal

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.SessionGoal

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.SessionGoal

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.SessionGoal

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.SessionGoal

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.SessionGoal

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.SessionGoal

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.SessionGoal

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.SessionGoal

StatusNotIn applies the NotIn predicate on the "status" field.

func Tasks

func Tasks(v string) predicate.SessionGoal

Tasks applies equality check predicate on the "tasks" field. It's identical to TasksEQ.

func TasksContains

func TasksContains(v string) predicate.SessionGoal

TasksContains applies the Contains predicate on the "tasks" field.

func TasksContainsFold

func TasksContainsFold(v string) predicate.SessionGoal

TasksContainsFold applies the ContainsFold predicate on the "tasks" field.

func TasksEQ

func TasksEQ(v string) predicate.SessionGoal

TasksEQ applies the EQ predicate on the "tasks" field.

func TasksEqualFold

func TasksEqualFold(v string) predicate.SessionGoal

TasksEqualFold applies the EqualFold predicate on the "tasks" field.

func TasksGT

func TasksGT(v string) predicate.SessionGoal

TasksGT applies the GT predicate on the "tasks" field.

func TasksGTE

func TasksGTE(v string) predicate.SessionGoal

TasksGTE applies the GTE predicate on the "tasks" field.

func TasksHasPrefix

func TasksHasPrefix(v string) predicate.SessionGoal

TasksHasPrefix applies the HasPrefix predicate on the "tasks" field.

func TasksHasSuffix

func TasksHasSuffix(v string) predicate.SessionGoal

TasksHasSuffix applies the HasSuffix predicate on the "tasks" field.

func TasksIn

func TasksIn(vs ...string) predicate.SessionGoal

TasksIn applies the In predicate on the "tasks" field.

func TasksIsNil

func TasksIsNil() predicate.SessionGoal

TasksIsNil applies the IsNil predicate on the "tasks" field.

func TasksLT

func TasksLT(v string) predicate.SessionGoal

TasksLT applies the LT predicate on the "tasks" field.

func TasksLTE

func TasksLTE(v string) predicate.SessionGoal

TasksLTE applies the LTE predicate on the "tasks" field.

func TasksNEQ

func TasksNEQ(v string) predicate.SessionGoal

TasksNEQ applies the NEQ predicate on the "tasks" field.

func TasksNotIn

func TasksNotIn(vs ...string) predicate.SessionGoal

TasksNotIn applies the NotIn predicate on the "tasks" field.

func TasksNotNil

func TasksNotNil() predicate.SessionGoal

TasksNotNil applies the NotNil predicate on the "tasks" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.SessionGoal

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.SessionGoal

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.SessionGoal

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.SessionGoal

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.SessionGoal

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.SessionGoal

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.SessionGoal

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.SessionGoal

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.SessionGoal

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WorkspaceKey added in v1.41.0

func WorkspaceKey(v string) predicate.SessionGoal

WorkspaceKey applies equality check predicate on the "workspace_key" field. It's identical to WorkspaceKeyEQ.

func WorkspaceKeyContains added in v1.41.0

func WorkspaceKeyContains(v string) predicate.SessionGoal

WorkspaceKeyContains applies the Contains predicate on the "workspace_key" field.

func WorkspaceKeyContainsFold added in v1.41.0

func WorkspaceKeyContainsFold(v string) predicate.SessionGoal

WorkspaceKeyContainsFold applies the ContainsFold predicate on the "workspace_key" field.

func WorkspaceKeyEQ added in v1.41.0

func WorkspaceKeyEQ(v string) predicate.SessionGoal

WorkspaceKeyEQ applies the EQ predicate on the "workspace_key" field.

func WorkspaceKeyEqualFold added in v1.41.0

func WorkspaceKeyEqualFold(v string) predicate.SessionGoal

WorkspaceKeyEqualFold applies the EqualFold predicate on the "workspace_key" field.

func WorkspaceKeyGT added in v1.41.0

func WorkspaceKeyGT(v string) predicate.SessionGoal

WorkspaceKeyGT applies the GT predicate on the "workspace_key" field.

func WorkspaceKeyGTE added in v1.41.0

func WorkspaceKeyGTE(v string) predicate.SessionGoal

WorkspaceKeyGTE applies the GTE predicate on the "workspace_key" field.

func WorkspaceKeyHasPrefix added in v1.41.0

func WorkspaceKeyHasPrefix(v string) predicate.SessionGoal

WorkspaceKeyHasPrefix applies the HasPrefix predicate on the "workspace_key" field.

func WorkspaceKeyHasSuffix added in v1.41.0

func WorkspaceKeyHasSuffix(v string) predicate.SessionGoal

WorkspaceKeyHasSuffix applies the HasSuffix predicate on the "workspace_key" field.

func WorkspaceKeyIn added in v1.41.0

func WorkspaceKeyIn(vs ...string) predicate.SessionGoal

WorkspaceKeyIn applies the In predicate on the "workspace_key" field.

func WorkspaceKeyIsNil added in v1.41.0

func WorkspaceKeyIsNil() predicate.SessionGoal

WorkspaceKeyIsNil applies the IsNil predicate on the "workspace_key" field.

func WorkspaceKeyLT added in v1.41.0

func WorkspaceKeyLT(v string) predicate.SessionGoal

WorkspaceKeyLT applies the LT predicate on the "workspace_key" field.

func WorkspaceKeyLTE added in v1.41.0

func WorkspaceKeyLTE(v string) predicate.SessionGoal

WorkspaceKeyLTE applies the LTE predicate on the "workspace_key" field.

func WorkspaceKeyNEQ added in v1.41.0

func WorkspaceKeyNEQ(v string) predicate.SessionGoal

WorkspaceKeyNEQ applies the NEQ predicate on the "workspace_key" field.

func WorkspaceKeyNotIn added in v1.41.0

func WorkspaceKeyNotIn(vs ...string) predicate.SessionGoal

WorkspaceKeyNotIn applies the NotIn predicate on the "workspace_key" field.

func WorkspaceKeyNotNil added in v1.41.0

func WorkspaceKeyNotNil() predicate.SessionGoal

WorkspaceKeyNotNil applies the NotNil predicate on the "workspace_key" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the SessionGoal queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByGoal

func ByGoal(opts ...sql.OrderTermOption) OrderOption

ByGoal orders the results by the goal field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func BySessionUUID

func BySessionUUID(opts ...sql.OrderTermOption) OrderOption

BySessionUUID orders the results by the session_uuid field.

func BySetBy

func BySetBy(opts ...sql.OrderTermOption) OrderOption

BySetBy orders the results by the set_by field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByTasks

func ByTasks(opts ...sql.OrderTermOption) OrderOption

ByTasks orders the results by the tasks field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByWorkspaceKey added in v1.41.0

func ByWorkspaceKey(opts ...sql.OrderTermOption) OrderOption

ByWorkspaceKey orders the results by the workspace_key field.

Jump to