Documentation
¶
Index ¶
- Constants
- Variables
- func Alternative(v string) predicate.ApprovalRule
- func AlternativeContains(v string) predicate.ApprovalRule
- func AlternativeContainsFold(v string) predicate.ApprovalRule
- func AlternativeEQ(v string) predicate.ApprovalRule
- func AlternativeEqualFold(v string) predicate.ApprovalRule
- func AlternativeGT(v string) predicate.ApprovalRule
- func AlternativeGTE(v string) predicate.ApprovalRule
- func AlternativeHasPrefix(v string) predicate.ApprovalRule
- func AlternativeHasSuffix(v string) predicate.ApprovalRule
- func AlternativeIn(vs ...string) predicate.ApprovalRule
- func AlternativeIsNil() predicate.ApprovalRule
- func AlternativeLT(v string) predicate.ApprovalRule
- func AlternativeLTE(v string) predicate.ApprovalRule
- func AlternativeNEQ(v string) predicate.ApprovalRule
- func AlternativeNotIn(vs ...string) predicate.ApprovalRule
- func AlternativeNotNil() predicate.ApprovalRule
- func And(predicates ...predicate.ApprovalRule) predicate.ApprovalRule
- func CommandPattern(v string) predicate.ApprovalRule
- func CommandPatternContains(v string) predicate.ApprovalRule
- func CommandPatternContainsFold(v string) predicate.ApprovalRule
- func CommandPatternEQ(v string) predicate.ApprovalRule
- func CommandPatternEqualFold(v string) predicate.ApprovalRule
- func CommandPatternGT(v string) predicate.ApprovalRule
- func CommandPatternGTE(v string) predicate.ApprovalRule
- func CommandPatternHasPrefix(v string) predicate.ApprovalRule
- func CommandPatternHasSuffix(v string) predicate.ApprovalRule
- func CommandPatternIn(vs ...string) predicate.ApprovalRule
- func CommandPatternIsNil() predicate.ApprovalRule
- func CommandPatternLT(v string) predicate.ApprovalRule
- func CommandPatternLTE(v string) predicate.ApprovalRule
- func CommandPatternNEQ(v string) predicate.ApprovalRule
- func CommandPatternNotIn(vs ...string) predicate.ApprovalRule
- func CommandPatternNotNil() predicate.ApprovalRule
- func CreatedAt(v time.Time) predicate.ApprovalRule
- func CreatedAtEQ(v time.Time) predicate.ApprovalRule
- func CreatedAtGT(v time.Time) predicate.ApprovalRule
- func CreatedAtGTE(v time.Time) predicate.ApprovalRule
- func CreatedAtIn(vs ...time.Time) predicate.ApprovalRule
- func CreatedAtLT(v time.Time) predicate.ApprovalRule
- func CreatedAtLTE(v time.Time) predicate.ApprovalRule
- func CreatedAtNEQ(v time.Time) predicate.ApprovalRule
- func CreatedAtNotIn(vs ...time.Time) predicate.ApprovalRule
- func Decision(v int) predicate.ApprovalRule
- func DecisionEQ(v int) predicate.ApprovalRule
- func DecisionGT(v int) predicate.ApprovalRule
- func DecisionGTE(v int) predicate.ApprovalRule
- func DecisionIn(vs ...int) predicate.ApprovalRule
- func DecisionLT(v int) predicate.ApprovalRule
- func DecisionLTE(v int) predicate.ApprovalRule
- func DecisionNEQ(v int) predicate.ApprovalRule
- func DecisionNotIn(vs ...int) predicate.ApprovalRule
- func Enabled(v bool) predicate.ApprovalRule
- func EnabledEQ(v bool) predicate.ApprovalRule
- func EnabledNEQ(v bool) predicate.ApprovalRule
- func FilePattern(v string) predicate.ApprovalRule
- func FilePatternContains(v string) predicate.ApprovalRule
- func FilePatternContainsFold(v string) predicate.ApprovalRule
- func FilePatternEQ(v string) predicate.ApprovalRule
- func FilePatternEqualFold(v string) predicate.ApprovalRule
- func FilePatternGT(v string) predicate.ApprovalRule
- func FilePatternGTE(v string) predicate.ApprovalRule
- func FilePatternHasPrefix(v string) predicate.ApprovalRule
- func FilePatternHasSuffix(v string) predicate.ApprovalRule
- func FilePatternIn(vs ...string) predicate.ApprovalRule
- func FilePatternIsNil() predicate.ApprovalRule
- func FilePatternLT(v string) predicate.ApprovalRule
- func FilePatternLTE(v string) predicate.ApprovalRule
- func FilePatternNEQ(v string) predicate.ApprovalRule
- func FilePatternNotIn(vs ...string) predicate.ApprovalRule
- func FilePatternNotNil() predicate.ApprovalRule
- func ID(id int) predicate.ApprovalRule
- func IDEQ(id int) predicate.ApprovalRule
- func IDGT(id int) predicate.ApprovalRule
- func IDGTE(id int) predicate.ApprovalRule
- func IDIn(ids ...int) predicate.ApprovalRule
- func IDLT(id int) predicate.ApprovalRule
- func IDLTE(id int) predicate.ApprovalRule
- func IDNEQ(id int) predicate.ApprovalRule
- func IDNotIn(ids ...int) predicate.ApprovalRule
- func Name(v string) predicate.ApprovalRule
- func NameContains(v string) predicate.ApprovalRule
- func NameContainsFold(v string) predicate.ApprovalRule
- func NameEQ(v string) predicate.ApprovalRule
- func NameEqualFold(v string) predicate.ApprovalRule
- func NameGT(v string) predicate.ApprovalRule
- func NameGTE(v string) predicate.ApprovalRule
- func NameHasPrefix(v string) predicate.ApprovalRule
- func NameHasSuffix(v string) predicate.ApprovalRule
- func NameIn(vs ...string) predicate.ApprovalRule
- func NameLT(v string) predicate.ApprovalRule
- func NameLTE(v string) predicate.ApprovalRule
- func NameNEQ(v string) predicate.ApprovalRule
- func NameNotIn(vs ...string) predicate.ApprovalRule
- func Not(p predicate.ApprovalRule) predicate.ApprovalRule
- func Or(predicates ...predicate.ApprovalRule) predicate.ApprovalRule
- func Priority(v int) predicate.ApprovalRule
- func PriorityEQ(v int) predicate.ApprovalRule
- func PriorityGT(v int) predicate.ApprovalRule
- func PriorityGTE(v int) predicate.ApprovalRule
- func PriorityIn(vs ...int) predicate.ApprovalRule
- func PriorityLT(v int) predicate.ApprovalRule
- func PriorityLTE(v int) predicate.ApprovalRule
- func PriorityNEQ(v int) predicate.ApprovalRule
- func PriorityNotIn(vs ...int) predicate.ApprovalRule
- func Reason(v string) predicate.ApprovalRule
- func ReasonContains(v string) predicate.ApprovalRule
- func ReasonContainsFold(v string) predicate.ApprovalRule
- func ReasonEQ(v string) predicate.ApprovalRule
- func ReasonEqualFold(v string) predicate.ApprovalRule
- func ReasonGT(v string) predicate.ApprovalRule
- func ReasonGTE(v string) predicate.ApprovalRule
- func ReasonHasPrefix(v string) predicate.ApprovalRule
- func ReasonHasSuffix(v string) predicate.ApprovalRule
- func ReasonIn(vs ...string) predicate.ApprovalRule
- func ReasonIsNil() predicate.ApprovalRule
- func ReasonLT(v string) predicate.ApprovalRule
- func ReasonLTE(v string) predicate.ApprovalRule
- func ReasonNEQ(v string) predicate.ApprovalRule
- func ReasonNotIn(vs ...string) predicate.ApprovalRule
- func ReasonNotNil() predicate.ApprovalRule
- func RiskLevel(v int) predicate.ApprovalRule
- func RiskLevelEQ(v int) predicate.ApprovalRule
- func RiskLevelGT(v int) predicate.ApprovalRule
- func RiskLevelGTE(v int) predicate.ApprovalRule
- func RiskLevelIn(vs ...int) predicate.ApprovalRule
- func RiskLevelLT(v int) predicate.ApprovalRule
- func RiskLevelLTE(v int) predicate.ApprovalRule
- func RiskLevelNEQ(v int) predicate.ApprovalRule
- func RiskLevelNotIn(vs ...int) predicate.ApprovalRule
- func RuleID(v string) predicate.ApprovalRule
- func RuleIDContains(v string) predicate.ApprovalRule
- func RuleIDContainsFold(v string) predicate.ApprovalRule
- func RuleIDEQ(v string) predicate.ApprovalRule
- func RuleIDEqualFold(v string) predicate.ApprovalRule
- func RuleIDGT(v string) predicate.ApprovalRule
- func RuleIDGTE(v string) predicate.ApprovalRule
- func RuleIDHasPrefix(v string) predicate.ApprovalRule
- func RuleIDHasSuffix(v string) predicate.ApprovalRule
- func RuleIDIn(vs ...string) predicate.ApprovalRule
- func RuleIDLT(v string) predicate.ApprovalRule
- func RuleIDLTE(v string) predicate.ApprovalRule
- func RuleIDNEQ(v string) predicate.ApprovalRule
- func RuleIDNotIn(vs ...string) predicate.ApprovalRule
- func Source(v string) predicate.ApprovalRule
- func SourceContains(v string) predicate.ApprovalRule
- func SourceContainsFold(v string) predicate.ApprovalRule
- func SourceEQ(v string) predicate.ApprovalRule
- func SourceEqualFold(v string) predicate.ApprovalRule
- func SourceGT(v string) predicate.ApprovalRule
- func SourceGTE(v string) predicate.ApprovalRule
- func SourceHasPrefix(v string) predicate.ApprovalRule
- func SourceHasSuffix(v string) predicate.ApprovalRule
- func SourceIn(vs ...string) predicate.ApprovalRule
- func SourceLT(v string) predicate.ApprovalRule
- func SourceLTE(v string) predicate.ApprovalRule
- func SourceNEQ(v string) predicate.ApprovalRule
- func SourceNotIn(vs ...string) predicate.ApprovalRule
- func ToolCategory(v string) predicate.ApprovalRule
- func ToolCategoryContains(v string) predicate.ApprovalRule
- func ToolCategoryContainsFold(v string) predicate.ApprovalRule
- func ToolCategoryEQ(v string) predicate.ApprovalRule
- func ToolCategoryEqualFold(v string) predicate.ApprovalRule
- func ToolCategoryGT(v string) predicate.ApprovalRule
- func ToolCategoryGTE(v string) predicate.ApprovalRule
- func ToolCategoryHasPrefix(v string) predicate.ApprovalRule
- func ToolCategoryHasSuffix(v string) predicate.ApprovalRule
- func ToolCategoryIn(vs ...string) predicate.ApprovalRule
- func ToolCategoryIsNil() predicate.ApprovalRule
- func ToolCategoryLT(v string) predicate.ApprovalRule
- func ToolCategoryLTE(v string) predicate.ApprovalRule
- func ToolCategoryNEQ(v string) predicate.ApprovalRule
- func ToolCategoryNotIn(vs ...string) predicate.ApprovalRule
- func ToolCategoryNotNil() predicate.ApprovalRule
- func ToolName(v string) predicate.ApprovalRule
- func ToolNameContains(v string) predicate.ApprovalRule
- func ToolNameContainsFold(v string) predicate.ApprovalRule
- func ToolNameEQ(v string) predicate.ApprovalRule
- func ToolNameEqualFold(v string) predicate.ApprovalRule
- func ToolNameGT(v string) predicate.ApprovalRule
- func ToolNameGTE(v string) predicate.ApprovalRule
- func ToolNameHasPrefix(v string) predicate.ApprovalRule
- func ToolNameHasSuffix(v string) predicate.ApprovalRule
- func ToolNameIn(vs ...string) predicate.ApprovalRule
- func ToolNameIsNil() predicate.ApprovalRule
- func ToolNameLT(v string) predicate.ApprovalRule
- func ToolNameLTE(v string) predicate.ApprovalRule
- func ToolNameNEQ(v string) predicate.ApprovalRule
- func ToolNameNotIn(vs ...string) predicate.ApprovalRule
- func ToolNameNotNil() predicate.ApprovalRule
- func ToolPattern(v string) predicate.ApprovalRule
- func ToolPatternContains(v string) predicate.ApprovalRule
- func ToolPatternContainsFold(v string) predicate.ApprovalRule
- func ToolPatternEQ(v string) predicate.ApprovalRule
- func ToolPatternEqualFold(v string) predicate.ApprovalRule
- func ToolPatternGT(v string) predicate.ApprovalRule
- func ToolPatternGTE(v string) predicate.ApprovalRule
- func ToolPatternHasPrefix(v string) predicate.ApprovalRule
- func ToolPatternHasSuffix(v string) predicate.ApprovalRule
- func ToolPatternIn(vs ...string) predicate.ApprovalRule
- func ToolPatternIsNil() predicate.ApprovalRule
- func ToolPatternLT(v string) predicate.ApprovalRule
- func ToolPatternLTE(v string) predicate.ApprovalRule
- func ToolPatternNEQ(v string) predicate.ApprovalRule
- func ToolPatternNotIn(vs ...string) predicate.ApprovalRule
- func ToolPatternNotNil() predicate.ApprovalRule
- func UpdatedAt(v time.Time) predicate.ApprovalRule
- func UpdatedAtEQ(v time.Time) predicate.ApprovalRule
- func UpdatedAtGT(v time.Time) predicate.ApprovalRule
- func UpdatedAtGTE(v time.Time) predicate.ApprovalRule
- func UpdatedAtIn(vs ...time.Time) predicate.ApprovalRule
- func UpdatedAtLT(v time.Time) predicate.ApprovalRule
- func UpdatedAtLTE(v time.Time) predicate.ApprovalRule
- func UpdatedAtNEQ(v time.Time) predicate.ApprovalRule
- func UpdatedAtNotIn(vs ...time.Time) predicate.ApprovalRule
- func ValidColumn(column string) bool
- type OrderOption
- func ByAlternative(opts ...sql.OrderTermOption) OrderOption
- func ByCommandPattern(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDecision(opts ...sql.OrderTermOption) OrderOption
- func ByEnabled(opts ...sql.OrderTermOption) OrderOption
- func ByFilePattern(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByPriority(opts ...sql.OrderTermOption) OrderOption
- func ByReason(opts ...sql.OrderTermOption) OrderOption
- func ByRiskLevel(opts ...sql.OrderTermOption) OrderOption
- func ByRuleID(opts ...sql.OrderTermOption) OrderOption
- func BySource(opts ...sql.OrderTermOption) OrderOption
- func ByToolCategory(opts ...sql.OrderTermOption) OrderOption
- func ByToolName(opts ...sql.OrderTermOption) OrderOption
- func ByToolPattern(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the approvalrule type in the database. Label = "approval_rule" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldRuleID holds the string denoting the rule_id field in the database. FieldRuleID = "rule_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldToolName holds the string denoting the tool_name field in the database. FieldToolName = "tool_name" // FieldToolPattern holds the string denoting the tool_pattern field in the database. FieldToolPattern = "tool_pattern" // FieldToolCategory holds the string denoting the tool_category field in the database. FieldToolCategory = "tool_category" // FieldCommandPattern holds the string denoting the command_pattern field in the database. FieldCommandPattern = "command_pattern" // FieldFilePattern holds the string denoting the file_pattern field in the database. FieldFilePattern = "file_pattern" // FieldDecision holds the string denoting the decision field in the database. FieldDecision = "decision" // FieldRiskLevel holds the string denoting the risk_level field in the database. FieldRiskLevel = "risk_level" // FieldReason holds the string denoting the reason field in the database. FieldReason = "reason" // FieldAlternative holds the string denoting the alternative field in the database. FieldAlternative = "alternative" // FieldPriority holds the string denoting the priority field in the database. FieldPriority = "priority" // FieldEnabled holds the string denoting the enabled field in the database. FieldEnabled = "enabled" // FieldSource holds the string denoting the source field in the database. FieldSource = "source" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the approvalrule in the database. Table = "approval_rules" )
Variables ¶
var ( // RuleIDValidator is a validator for the "rule_id" field. It is called by the builders before save. RuleIDValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultPriority holds the default value on creation for the "priority" field. DefaultPriority int // DefaultEnabled holds the default value on creation for the "enabled" field. DefaultEnabled bool // DefaultSource holds the default value on creation for the "source" field. DefaultSource string // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldRuleID, FieldName, FieldToolName, FieldToolPattern, FieldToolCategory, FieldCommandPattern, FieldFilePattern, FieldDecision, FieldRiskLevel, FieldReason, FieldAlternative, FieldPriority, FieldEnabled, FieldSource, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for approvalrule fields.
Functions ¶
func Alternative ¶
func Alternative(v string) predicate.ApprovalRule
Alternative applies equality check predicate on the "alternative" field. It's identical to AlternativeEQ.
func AlternativeContains ¶
func AlternativeContains(v string) predicate.ApprovalRule
AlternativeContains applies the Contains predicate on the "alternative" field.
func AlternativeContainsFold ¶
func AlternativeContainsFold(v string) predicate.ApprovalRule
AlternativeContainsFold applies the ContainsFold predicate on the "alternative" field.
func AlternativeEQ ¶
func AlternativeEQ(v string) predicate.ApprovalRule
AlternativeEQ applies the EQ predicate on the "alternative" field.
func AlternativeEqualFold ¶
func AlternativeEqualFold(v string) predicate.ApprovalRule
AlternativeEqualFold applies the EqualFold predicate on the "alternative" field.
func AlternativeGT ¶
func AlternativeGT(v string) predicate.ApprovalRule
AlternativeGT applies the GT predicate on the "alternative" field.
func AlternativeGTE ¶
func AlternativeGTE(v string) predicate.ApprovalRule
AlternativeGTE applies the GTE predicate on the "alternative" field.
func AlternativeHasPrefix ¶
func AlternativeHasPrefix(v string) predicate.ApprovalRule
AlternativeHasPrefix applies the HasPrefix predicate on the "alternative" field.
func AlternativeHasSuffix ¶
func AlternativeHasSuffix(v string) predicate.ApprovalRule
AlternativeHasSuffix applies the HasSuffix predicate on the "alternative" field.
func AlternativeIn ¶
func AlternativeIn(vs ...string) predicate.ApprovalRule
AlternativeIn applies the In predicate on the "alternative" field.
func AlternativeIsNil ¶
func AlternativeIsNil() predicate.ApprovalRule
AlternativeIsNil applies the IsNil predicate on the "alternative" field.
func AlternativeLT ¶
func AlternativeLT(v string) predicate.ApprovalRule
AlternativeLT applies the LT predicate on the "alternative" field.
func AlternativeLTE ¶
func AlternativeLTE(v string) predicate.ApprovalRule
AlternativeLTE applies the LTE predicate on the "alternative" field.
func AlternativeNEQ ¶
func AlternativeNEQ(v string) predicate.ApprovalRule
AlternativeNEQ applies the NEQ predicate on the "alternative" field.
func AlternativeNotIn ¶
func AlternativeNotIn(vs ...string) predicate.ApprovalRule
AlternativeNotIn applies the NotIn predicate on the "alternative" field.
func AlternativeNotNil ¶
func AlternativeNotNil() predicate.ApprovalRule
AlternativeNotNil applies the NotNil predicate on the "alternative" field.
func And ¶
func And(predicates ...predicate.ApprovalRule) predicate.ApprovalRule
And groups predicates with the AND operator between them.
func CommandPattern ¶
func CommandPattern(v string) predicate.ApprovalRule
CommandPattern applies equality check predicate on the "command_pattern" field. It's identical to CommandPatternEQ.
func CommandPatternContains ¶
func CommandPatternContains(v string) predicate.ApprovalRule
CommandPatternContains applies the Contains predicate on the "command_pattern" field.
func CommandPatternContainsFold ¶
func CommandPatternContainsFold(v string) predicate.ApprovalRule
CommandPatternContainsFold applies the ContainsFold predicate on the "command_pattern" field.
func CommandPatternEQ ¶
func CommandPatternEQ(v string) predicate.ApprovalRule
CommandPatternEQ applies the EQ predicate on the "command_pattern" field.
func CommandPatternEqualFold ¶
func CommandPatternEqualFold(v string) predicate.ApprovalRule
CommandPatternEqualFold applies the EqualFold predicate on the "command_pattern" field.
func CommandPatternGT ¶
func CommandPatternGT(v string) predicate.ApprovalRule
CommandPatternGT applies the GT predicate on the "command_pattern" field.
func CommandPatternGTE ¶
func CommandPatternGTE(v string) predicate.ApprovalRule
CommandPatternGTE applies the GTE predicate on the "command_pattern" field.
func CommandPatternHasPrefix ¶
func CommandPatternHasPrefix(v string) predicate.ApprovalRule
CommandPatternHasPrefix applies the HasPrefix predicate on the "command_pattern" field.
func CommandPatternHasSuffix ¶
func CommandPatternHasSuffix(v string) predicate.ApprovalRule
CommandPatternHasSuffix applies the HasSuffix predicate on the "command_pattern" field.
func CommandPatternIn ¶
func CommandPatternIn(vs ...string) predicate.ApprovalRule
CommandPatternIn applies the In predicate on the "command_pattern" field.
func CommandPatternIsNil ¶
func CommandPatternIsNil() predicate.ApprovalRule
CommandPatternIsNil applies the IsNil predicate on the "command_pattern" field.
func CommandPatternLT ¶
func CommandPatternLT(v string) predicate.ApprovalRule
CommandPatternLT applies the LT predicate on the "command_pattern" field.
func CommandPatternLTE ¶
func CommandPatternLTE(v string) predicate.ApprovalRule
CommandPatternLTE applies the LTE predicate on the "command_pattern" field.
func CommandPatternNEQ ¶
func CommandPatternNEQ(v string) predicate.ApprovalRule
CommandPatternNEQ applies the NEQ predicate on the "command_pattern" field.
func CommandPatternNotIn ¶
func CommandPatternNotIn(vs ...string) predicate.ApprovalRule
CommandPatternNotIn applies the NotIn predicate on the "command_pattern" field.
func CommandPatternNotNil ¶
func CommandPatternNotNil() predicate.ApprovalRule
CommandPatternNotNil applies the NotNil predicate on the "command_pattern" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.ApprovalRule
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.ApprovalRule
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.ApprovalRule
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.ApprovalRule
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.ApprovalRule
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.ApprovalRule
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.ApprovalRule
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.ApprovalRule
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.ApprovalRule
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Decision ¶
func Decision(v int) predicate.ApprovalRule
Decision applies equality check predicate on the "decision" field. It's identical to DecisionEQ.
func DecisionEQ ¶
func DecisionEQ(v int) predicate.ApprovalRule
DecisionEQ applies the EQ predicate on the "decision" field.
func DecisionGT ¶
func DecisionGT(v int) predicate.ApprovalRule
DecisionGT applies the GT predicate on the "decision" field.
func DecisionGTE ¶
func DecisionGTE(v int) predicate.ApprovalRule
DecisionGTE applies the GTE predicate on the "decision" field.
func DecisionIn ¶
func DecisionIn(vs ...int) predicate.ApprovalRule
DecisionIn applies the In predicate on the "decision" field.
func DecisionLT ¶
func DecisionLT(v int) predicate.ApprovalRule
DecisionLT applies the LT predicate on the "decision" field.
func DecisionLTE ¶
func DecisionLTE(v int) predicate.ApprovalRule
DecisionLTE applies the LTE predicate on the "decision" field.
func DecisionNEQ ¶
func DecisionNEQ(v int) predicate.ApprovalRule
DecisionNEQ applies the NEQ predicate on the "decision" field.
func DecisionNotIn ¶
func DecisionNotIn(vs ...int) predicate.ApprovalRule
DecisionNotIn applies the NotIn predicate on the "decision" field.
func Enabled ¶
func Enabled(v bool) predicate.ApprovalRule
Enabled applies equality check predicate on the "enabled" field. It's identical to EnabledEQ.
func EnabledEQ ¶
func EnabledEQ(v bool) predicate.ApprovalRule
EnabledEQ applies the EQ predicate on the "enabled" field.
func EnabledNEQ ¶
func EnabledNEQ(v bool) predicate.ApprovalRule
EnabledNEQ applies the NEQ predicate on the "enabled" field.
func FilePattern ¶
func FilePattern(v string) predicate.ApprovalRule
FilePattern applies equality check predicate on the "file_pattern" field. It's identical to FilePatternEQ.
func FilePatternContains ¶
func FilePatternContains(v string) predicate.ApprovalRule
FilePatternContains applies the Contains predicate on the "file_pattern" field.
func FilePatternContainsFold ¶
func FilePatternContainsFold(v string) predicate.ApprovalRule
FilePatternContainsFold applies the ContainsFold predicate on the "file_pattern" field.
func FilePatternEQ ¶
func FilePatternEQ(v string) predicate.ApprovalRule
FilePatternEQ applies the EQ predicate on the "file_pattern" field.
func FilePatternEqualFold ¶
func FilePatternEqualFold(v string) predicate.ApprovalRule
FilePatternEqualFold applies the EqualFold predicate on the "file_pattern" field.
func FilePatternGT ¶
func FilePatternGT(v string) predicate.ApprovalRule
FilePatternGT applies the GT predicate on the "file_pattern" field.
func FilePatternGTE ¶
func FilePatternGTE(v string) predicate.ApprovalRule
FilePatternGTE applies the GTE predicate on the "file_pattern" field.
func FilePatternHasPrefix ¶
func FilePatternHasPrefix(v string) predicate.ApprovalRule
FilePatternHasPrefix applies the HasPrefix predicate on the "file_pattern" field.
func FilePatternHasSuffix ¶
func FilePatternHasSuffix(v string) predicate.ApprovalRule
FilePatternHasSuffix applies the HasSuffix predicate on the "file_pattern" field.
func FilePatternIn ¶
func FilePatternIn(vs ...string) predicate.ApprovalRule
FilePatternIn applies the In predicate on the "file_pattern" field.
func FilePatternIsNil ¶
func FilePatternIsNil() predicate.ApprovalRule
FilePatternIsNil applies the IsNil predicate on the "file_pattern" field.
func FilePatternLT ¶
func FilePatternLT(v string) predicate.ApprovalRule
FilePatternLT applies the LT predicate on the "file_pattern" field.
func FilePatternLTE ¶
func FilePatternLTE(v string) predicate.ApprovalRule
FilePatternLTE applies the LTE predicate on the "file_pattern" field.
func FilePatternNEQ ¶
func FilePatternNEQ(v string) predicate.ApprovalRule
FilePatternNEQ applies the NEQ predicate on the "file_pattern" field.
func FilePatternNotIn ¶
func FilePatternNotIn(vs ...string) predicate.ApprovalRule
FilePatternNotIn applies the NotIn predicate on the "file_pattern" field.
func FilePatternNotNil ¶
func FilePatternNotNil() predicate.ApprovalRule
FilePatternNotNil applies the NotNil predicate on the "file_pattern" field.
func IDGTE ¶
func IDGTE(id int) predicate.ApprovalRule
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.ApprovalRule
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.ApprovalRule
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.ApprovalRule
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.ApprovalRule
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.ApprovalRule
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.ApprovalRule
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.ApprovalRule
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.ApprovalRule
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.ApprovalRule
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.ApprovalRule
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.ApprovalRule
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.ApprovalRule
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.ApprovalRule
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.ApprovalRule
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.ApprovalRule
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.ApprovalRule
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.ApprovalRule
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.ApprovalRule
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.ApprovalRule) predicate.ApprovalRule
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ApprovalRule) predicate.ApprovalRule
Or groups predicates with the OR operator between them.
func Priority ¶
func Priority(v int) predicate.ApprovalRule
Priority applies equality check predicate on the "priority" field. It's identical to PriorityEQ.
func PriorityEQ ¶
func PriorityEQ(v int) predicate.ApprovalRule
PriorityEQ applies the EQ predicate on the "priority" field.
func PriorityGT ¶
func PriorityGT(v int) predicate.ApprovalRule
PriorityGT applies the GT predicate on the "priority" field.
func PriorityGTE ¶
func PriorityGTE(v int) predicate.ApprovalRule
PriorityGTE applies the GTE predicate on the "priority" field.
func PriorityIn ¶
func PriorityIn(vs ...int) predicate.ApprovalRule
PriorityIn applies the In predicate on the "priority" field.
func PriorityLT ¶
func PriorityLT(v int) predicate.ApprovalRule
PriorityLT applies the LT predicate on the "priority" field.
func PriorityLTE ¶
func PriorityLTE(v int) predicate.ApprovalRule
PriorityLTE applies the LTE predicate on the "priority" field.
func PriorityNEQ ¶
func PriorityNEQ(v int) predicate.ApprovalRule
PriorityNEQ applies the NEQ predicate on the "priority" field.
func PriorityNotIn ¶
func PriorityNotIn(vs ...int) predicate.ApprovalRule
PriorityNotIn applies the NotIn predicate on the "priority" field.
func Reason ¶
func Reason(v string) predicate.ApprovalRule
Reason applies equality check predicate on the "reason" field. It's identical to ReasonEQ.
func ReasonContains ¶
func ReasonContains(v string) predicate.ApprovalRule
ReasonContains applies the Contains predicate on the "reason" field.
func ReasonContainsFold ¶
func ReasonContainsFold(v string) predicate.ApprovalRule
ReasonContainsFold applies the ContainsFold predicate on the "reason" field.
func ReasonEQ ¶
func ReasonEQ(v string) predicate.ApprovalRule
ReasonEQ applies the EQ predicate on the "reason" field.
func ReasonEqualFold ¶
func ReasonEqualFold(v string) predicate.ApprovalRule
ReasonEqualFold applies the EqualFold predicate on the "reason" field.
func ReasonGT ¶
func ReasonGT(v string) predicate.ApprovalRule
ReasonGT applies the GT predicate on the "reason" field.
func ReasonGTE ¶
func ReasonGTE(v string) predicate.ApprovalRule
ReasonGTE applies the GTE predicate on the "reason" field.
func ReasonHasPrefix ¶
func ReasonHasPrefix(v string) predicate.ApprovalRule
ReasonHasPrefix applies the HasPrefix predicate on the "reason" field.
func ReasonHasSuffix ¶
func ReasonHasSuffix(v string) predicate.ApprovalRule
ReasonHasSuffix applies the HasSuffix predicate on the "reason" field.
func ReasonIn ¶
func ReasonIn(vs ...string) predicate.ApprovalRule
ReasonIn applies the In predicate on the "reason" field.
func ReasonIsNil ¶
func ReasonIsNil() predicate.ApprovalRule
ReasonIsNil applies the IsNil predicate on the "reason" field.
func ReasonLT ¶
func ReasonLT(v string) predicate.ApprovalRule
ReasonLT applies the LT predicate on the "reason" field.
func ReasonLTE ¶
func ReasonLTE(v string) predicate.ApprovalRule
ReasonLTE applies the LTE predicate on the "reason" field.
func ReasonNEQ ¶
func ReasonNEQ(v string) predicate.ApprovalRule
ReasonNEQ applies the NEQ predicate on the "reason" field.
func ReasonNotIn ¶
func ReasonNotIn(vs ...string) predicate.ApprovalRule
ReasonNotIn applies the NotIn predicate on the "reason" field.
func ReasonNotNil ¶
func ReasonNotNil() predicate.ApprovalRule
ReasonNotNil applies the NotNil predicate on the "reason" field.
func RiskLevel ¶
func RiskLevel(v int) predicate.ApprovalRule
RiskLevel applies equality check predicate on the "risk_level" field. It's identical to RiskLevelEQ.
func RiskLevelEQ ¶
func RiskLevelEQ(v int) predicate.ApprovalRule
RiskLevelEQ applies the EQ predicate on the "risk_level" field.
func RiskLevelGT ¶
func RiskLevelGT(v int) predicate.ApprovalRule
RiskLevelGT applies the GT predicate on the "risk_level" field.
func RiskLevelGTE ¶
func RiskLevelGTE(v int) predicate.ApprovalRule
RiskLevelGTE applies the GTE predicate on the "risk_level" field.
func RiskLevelIn ¶
func RiskLevelIn(vs ...int) predicate.ApprovalRule
RiskLevelIn applies the In predicate on the "risk_level" field.
func RiskLevelLT ¶
func RiskLevelLT(v int) predicate.ApprovalRule
RiskLevelLT applies the LT predicate on the "risk_level" field.
func RiskLevelLTE ¶
func RiskLevelLTE(v int) predicate.ApprovalRule
RiskLevelLTE applies the LTE predicate on the "risk_level" field.
func RiskLevelNEQ ¶
func RiskLevelNEQ(v int) predicate.ApprovalRule
RiskLevelNEQ applies the NEQ predicate on the "risk_level" field.
func RiskLevelNotIn ¶
func RiskLevelNotIn(vs ...int) predicate.ApprovalRule
RiskLevelNotIn applies the NotIn predicate on the "risk_level" field.
func RuleID ¶
func RuleID(v string) predicate.ApprovalRule
RuleID applies equality check predicate on the "rule_id" field. It's identical to RuleIDEQ.
func RuleIDContains ¶
func RuleIDContains(v string) predicate.ApprovalRule
RuleIDContains applies the Contains predicate on the "rule_id" field.
func RuleIDContainsFold ¶
func RuleIDContainsFold(v string) predicate.ApprovalRule
RuleIDContainsFold applies the ContainsFold predicate on the "rule_id" field.
func RuleIDEQ ¶
func RuleIDEQ(v string) predicate.ApprovalRule
RuleIDEQ applies the EQ predicate on the "rule_id" field.
func RuleIDEqualFold ¶
func RuleIDEqualFold(v string) predicate.ApprovalRule
RuleIDEqualFold applies the EqualFold predicate on the "rule_id" field.
func RuleIDGT ¶
func RuleIDGT(v string) predicate.ApprovalRule
RuleIDGT applies the GT predicate on the "rule_id" field.
func RuleIDGTE ¶
func RuleIDGTE(v string) predicate.ApprovalRule
RuleIDGTE applies the GTE predicate on the "rule_id" field.
func RuleIDHasPrefix ¶
func RuleIDHasPrefix(v string) predicate.ApprovalRule
RuleIDHasPrefix applies the HasPrefix predicate on the "rule_id" field.
func RuleIDHasSuffix ¶
func RuleIDHasSuffix(v string) predicate.ApprovalRule
RuleIDHasSuffix applies the HasSuffix predicate on the "rule_id" field.
func RuleIDIn ¶
func RuleIDIn(vs ...string) predicate.ApprovalRule
RuleIDIn applies the In predicate on the "rule_id" field.
func RuleIDLT ¶
func RuleIDLT(v string) predicate.ApprovalRule
RuleIDLT applies the LT predicate on the "rule_id" field.
func RuleIDLTE ¶
func RuleIDLTE(v string) predicate.ApprovalRule
RuleIDLTE applies the LTE predicate on the "rule_id" field.
func RuleIDNEQ ¶
func RuleIDNEQ(v string) predicate.ApprovalRule
RuleIDNEQ applies the NEQ predicate on the "rule_id" field.
func RuleIDNotIn ¶
func RuleIDNotIn(vs ...string) predicate.ApprovalRule
RuleIDNotIn applies the NotIn predicate on the "rule_id" field.
func Source ¶
func Source(v string) predicate.ApprovalRule
Source applies equality check predicate on the "source" field. It's identical to SourceEQ.
func SourceContains ¶
func SourceContains(v string) predicate.ApprovalRule
SourceContains applies the Contains predicate on the "source" field.
func SourceContainsFold ¶
func SourceContainsFold(v string) predicate.ApprovalRule
SourceContainsFold applies the ContainsFold predicate on the "source" field.
func SourceEQ ¶
func SourceEQ(v string) predicate.ApprovalRule
SourceEQ applies the EQ predicate on the "source" field.
func SourceEqualFold ¶
func SourceEqualFold(v string) predicate.ApprovalRule
SourceEqualFold applies the EqualFold predicate on the "source" field.
func SourceGT ¶
func SourceGT(v string) predicate.ApprovalRule
SourceGT applies the GT predicate on the "source" field.
func SourceGTE ¶
func SourceGTE(v string) predicate.ApprovalRule
SourceGTE applies the GTE predicate on the "source" field.
func SourceHasPrefix ¶
func SourceHasPrefix(v string) predicate.ApprovalRule
SourceHasPrefix applies the HasPrefix predicate on the "source" field.
func SourceHasSuffix ¶
func SourceHasSuffix(v string) predicate.ApprovalRule
SourceHasSuffix applies the HasSuffix predicate on the "source" field.
func SourceIn ¶
func SourceIn(vs ...string) predicate.ApprovalRule
SourceIn applies the In predicate on the "source" field.
func SourceLT ¶
func SourceLT(v string) predicate.ApprovalRule
SourceLT applies the LT predicate on the "source" field.
func SourceLTE ¶
func SourceLTE(v string) predicate.ApprovalRule
SourceLTE applies the LTE predicate on the "source" field.
func SourceNEQ ¶
func SourceNEQ(v string) predicate.ApprovalRule
SourceNEQ applies the NEQ predicate on the "source" field.
func SourceNotIn ¶
func SourceNotIn(vs ...string) predicate.ApprovalRule
SourceNotIn applies the NotIn predicate on the "source" field.
func ToolCategory ¶
func ToolCategory(v string) predicate.ApprovalRule
ToolCategory applies equality check predicate on the "tool_category" field. It's identical to ToolCategoryEQ.
func ToolCategoryContains ¶
func ToolCategoryContains(v string) predicate.ApprovalRule
ToolCategoryContains applies the Contains predicate on the "tool_category" field.
func ToolCategoryContainsFold ¶
func ToolCategoryContainsFold(v string) predicate.ApprovalRule
ToolCategoryContainsFold applies the ContainsFold predicate on the "tool_category" field.
func ToolCategoryEQ ¶
func ToolCategoryEQ(v string) predicate.ApprovalRule
ToolCategoryEQ applies the EQ predicate on the "tool_category" field.
func ToolCategoryEqualFold ¶
func ToolCategoryEqualFold(v string) predicate.ApprovalRule
ToolCategoryEqualFold applies the EqualFold predicate on the "tool_category" field.
func ToolCategoryGT ¶
func ToolCategoryGT(v string) predicate.ApprovalRule
ToolCategoryGT applies the GT predicate on the "tool_category" field.
func ToolCategoryGTE ¶
func ToolCategoryGTE(v string) predicate.ApprovalRule
ToolCategoryGTE applies the GTE predicate on the "tool_category" field.
func ToolCategoryHasPrefix ¶
func ToolCategoryHasPrefix(v string) predicate.ApprovalRule
ToolCategoryHasPrefix applies the HasPrefix predicate on the "tool_category" field.
func ToolCategoryHasSuffix ¶
func ToolCategoryHasSuffix(v string) predicate.ApprovalRule
ToolCategoryHasSuffix applies the HasSuffix predicate on the "tool_category" field.
func ToolCategoryIn ¶
func ToolCategoryIn(vs ...string) predicate.ApprovalRule
ToolCategoryIn applies the In predicate on the "tool_category" field.
func ToolCategoryIsNil ¶
func ToolCategoryIsNil() predicate.ApprovalRule
ToolCategoryIsNil applies the IsNil predicate on the "tool_category" field.
func ToolCategoryLT ¶
func ToolCategoryLT(v string) predicate.ApprovalRule
ToolCategoryLT applies the LT predicate on the "tool_category" field.
func ToolCategoryLTE ¶
func ToolCategoryLTE(v string) predicate.ApprovalRule
ToolCategoryLTE applies the LTE predicate on the "tool_category" field.
func ToolCategoryNEQ ¶
func ToolCategoryNEQ(v string) predicate.ApprovalRule
ToolCategoryNEQ applies the NEQ predicate on the "tool_category" field.
func ToolCategoryNotIn ¶
func ToolCategoryNotIn(vs ...string) predicate.ApprovalRule
ToolCategoryNotIn applies the NotIn predicate on the "tool_category" field.
func ToolCategoryNotNil ¶
func ToolCategoryNotNil() predicate.ApprovalRule
ToolCategoryNotNil applies the NotNil predicate on the "tool_category" field.
func ToolName ¶
func ToolName(v string) predicate.ApprovalRule
ToolName applies equality check predicate on the "tool_name" field. It's identical to ToolNameEQ.
func ToolNameContains ¶
func ToolNameContains(v string) predicate.ApprovalRule
ToolNameContains applies the Contains predicate on the "tool_name" field.
func ToolNameContainsFold ¶
func ToolNameContainsFold(v string) predicate.ApprovalRule
ToolNameContainsFold applies the ContainsFold predicate on the "tool_name" field.
func ToolNameEQ ¶
func ToolNameEQ(v string) predicate.ApprovalRule
ToolNameEQ applies the EQ predicate on the "tool_name" field.
func ToolNameEqualFold ¶
func ToolNameEqualFold(v string) predicate.ApprovalRule
ToolNameEqualFold applies the EqualFold predicate on the "tool_name" field.
func ToolNameGT ¶
func ToolNameGT(v string) predicate.ApprovalRule
ToolNameGT applies the GT predicate on the "tool_name" field.
func ToolNameGTE ¶
func ToolNameGTE(v string) predicate.ApprovalRule
ToolNameGTE applies the GTE predicate on the "tool_name" field.
func ToolNameHasPrefix ¶
func ToolNameHasPrefix(v string) predicate.ApprovalRule
ToolNameHasPrefix applies the HasPrefix predicate on the "tool_name" field.
func ToolNameHasSuffix ¶
func ToolNameHasSuffix(v string) predicate.ApprovalRule
ToolNameHasSuffix applies the HasSuffix predicate on the "tool_name" field.
func ToolNameIn ¶
func ToolNameIn(vs ...string) predicate.ApprovalRule
ToolNameIn applies the In predicate on the "tool_name" field.
func ToolNameIsNil ¶
func ToolNameIsNil() predicate.ApprovalRule
ToolNameIsNil applies the IsNil predicate on the "tool_name" field.
func ToolNameLT ¶
func ToolNameLT(v string) predicate.ApprovalRule
ToolNameLT applies the LT predicate on the "tool_name" field.
func ToolNameLTE ¶
func ToolNameLTE(v string) predicate.ApprovalRule
ToolNameLTE applies the LTE predicate on the "tool_name" field.
func ToolNameNEQ ¶
func ToolNameNEQ(v string) predicate.ApprovalRule
ToolNameNEQ applies the NEQ predicate on the "tool_name" field.
func ToolNameNotIn ¶
func ToolNameNotIn(vs ...string) predicate.ApprovalRule
ToolNameNotIn applies the NotIn predicate on the "tool_name" field.
func ToolNameNotNil ¶
func ToolNameNotNil() predicate.ApprovalRule
ToolNameNotNil applies the NotNil predicate on the "tool_name" field.
func ToolPattern ¶
func ToolPattern(v string) predicate.ApprovalRule
ToolPattern applies equality check predicate on the "tool_pattern" field. It's identical to ToolPatternEQ.
func ToolPatternContains ¶
func ToolPatternContains(v string) predicate.ApprovalRule
ToolPatternContains applies the Contains predicate on the "tool_pattern" field.
func ToolPatternContainsFold ¶
func ToolPatternContainsFold(v string) predicate.ApprovalRule
ToolPatternContainsFold applies the ContainsFold predicate on the "tool_pattern" field.
func ToolPatternEQ ¶
func ToolPatternEQ(v string) predicate.ApprovalRule
ToolPatternEQ applies the EQ predicate on the "tool_pattern" field.
func ToolPatternEqualFold ¶
func ToolPatternEqualFold(v string) predicate.ApprovalRule
ToolPatternEqualFold applies the EqualFold predicate on the "tool_pattern" field.
func ToolPatternGT ¶
func ToolPatternGT(v string) predicate.ApprovalRule
ToolPatternGT applies the GT predicate on the "tool_pattern" field.
func ToolPatternGTE ¶
func ToolPatternGTE(v string) predicate.ApprovalRule
ToolPatternGTE applies the GTE predicate on the "tool_pattern" field.
func ToolPatternHasPrefix ¶
func ToolPatternHasPrefix(v string) predicate.ApprovalRule
ToolPatternHasPrefix applies the HasPrefix predicate on the "tool_pattern" field.
func ToolPatternHasSuffix ¶
func ToolPatternHasSuffix(v string) predicate.ApprovalRule
ToolPatternHasSuffix applies the HasSuffix predicate on the "tool_pattern" field.
func ToolPatternIn ¶
func ToolPatternIn(vs ...string) predicate.ApprovalRule
ToolPatternIn applies the In predicate on the "tool_pattern" field.
func ToolPatternIsNil ¶
func ToolPatternIsNil() predicate.ApprovalRule
ToolPatternIsNil applies the IsNil predicate on the "tool_pattern" field.
func ToolPatternLT ¶
func ToolPatternLT(v string) predicate.ApprovalRule
ToolPatternLT applies the LT predicate on the "tool_pattern" field.
func ToolPatternLTE ¶
func ToolPatternLTE(v string) predicate.ApprovalRule
ToolPatternLTE applies the LTE predicate on the "tool_pattern" field.
func ToolPatternNEQ ¶
func ToolPatternNEQ(v string) predicate.ApprovalRule
ToolPatternNEQ applies the NEQ predicate on the "tool_pattern" field.
func ToolPatternNotIn ¶
func ToolPatternNotIn(vs ...string) predicate.ApprovalRule
ToolPatternNotIn applies the NotIn predicate on the "tool_pattern" field.
func ToolPatternNotNil ¶
func ToolPatternNotNil() predicate.ApprovalRule
ToolPatternNotNil applies the NotNil predicate on the "tool_pattern" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.ApprovalRule
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.ApprovalRule
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.ApprovalRule
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.ApprovalRule
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.ApprovalRule
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.ApprovalRule
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.ApprovalRule
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.ApprovalRule
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.ApprovalRule
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ApprovalRule queries.
func ByAlternative ¶
func ByAlternative(opts ...sql.OrderTermOption) OrderOption
ByAlternative orders the results by the alternative field.
func ByCommandPattern ¶
func ByCommandPattern(opts ...sql.OrderTermOption) OrderOption
ByCommandPattern orders the results by the command_pattern field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDecision ¶
func ByDecision(opts ...sql.OrderTermOption) OrderOption
ByDecision orders the results by the decision field.
func ByEnabled ¶
func ByEnabled(opts ...sql.OrderTermOption) OrderOption
ByEnabled orders the results by the enabled field.
func ByFilePattern ¶
func ByFilePattern(opts ...sql.OrderTermOption) OrderOption
ByFilePattern orders the results by the file_pattern field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByPriority ¶
func ByPriority(opts ...sql.OrderTermOption) OrderOption
ByPriority orders the results by the priority field.
func ByReason ¶
func ByReason(opts ...sql.OrderTermOption) OrderOption
ByReason orders the results by the reason field.
func ByRiskLevel ¶
func ByRiskLevel(opts ...sql.OrderTermOption) OrderOption
ByRiskLevel orders the results by the risk_level field.
func ByRuleID ¶
func ByRuleID(opts ...sql.OrderTermOption) OrderOption
ByRuleID orders the results by the rule_id field.
func BySource ¶
func BySource(opts ...sql.OrderTermOption) OrderOption
BySource orders the results by the source field.
func ByToolCategory ¶
func ByToolCategory(opts ...sql.OrderTermOption) OrderOption
ByToolCategory orders the results by the tool_category field.
func ByToolName ¶
func ByToolName(opts ...sql.OrderTermOption) OrderOption
ByToolName orders the results by the tool_name field.
func ByToolPattern ¶
func ByToolPattern(opts ...sql.OrderTermOption) OrderOption
ByToolPattern orders the results by the tool_pattern field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.