Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ClaudeSession) predicate.ClaudeSession
- func AutoReattach(v bool) predicate.ClaudeSession
- func AutoReattachEQ(v bool) predicate.ClaudeSession
- func AutoReattachNEQ(v bool) predicate.ClaudeSession
- func ClaudeSessionID(v string) predicate.ClaudeSession
- func ClaudeSessionIDContains(v string) predicate.ClaudeSession
- func ClaudeSessionIDContainsFold(v string) predicate.ClaudeSession
- func ClaudeSessionIDEQ(v string) predicate.ClaudeSession
- func ClaudeSessionIDEqualFold(v string) predicate.ClaudeSession
- func ClaudeSessionIDGT(v string) predicate.ClaudeSession
- func ClaudeSessionIDGTE(v string) predicate.ClaudeSession
- func ClaudeSessionIDHasPrefix(v string) predicate.ClaudeSession
- func ClaudeSessionIDHasSuffix(v string) predicate.ClaudeSession
- func ClaudeSessionIDIn(vs ...string) predicate.ClaudeSession
- func ClaudeSessionIDLT(v string) predicate.ClaudeSession
- func ClaudeSessionIDLTE(v string) predicate.ClaudeSession
- func ClaudeSessionIDNEQ(v string) predicate.ClaudeSession
- func ClaudeSessionIDNotIn(vs ...string) predicate.ClaudeSession
- func ConversationID(v string) predicate.ClaudeSession
- func ConversationIDContains(v string) predicate.ClaudeSession
- func ConversationIDContainsFold(v string) predicate.ClaudeSession
- func ConversationIDEQ(v string) predicate.ClaudeSession
- func ConversationIDEqualFold(v string) predicate.ClaudeSession
- func ConversationIDGT(v string) predicate.ClaudeSession
- func ConversationIDGTE(v string) predicate.ClaudeSession
- func ConversationIDHasPrefix(v string) predicate.ClaudeSession
- func ConversationIDHasSuffix(v string) predicate.ClaudeSession
- func ConversationIDIn(vs ...string) predicate.ClaudeSession
- func ConversationIDIsNil() predicate.ClaudeSession
- func ConversationIDLT(v string) predicate.ClaudeSession
- func ConversationIDLTE(v string) predicate.ClaudeSession
- func ConversationIDNEQ(v string) predicate.ClaudeSession
- func ConversationIDNotIn(vs ...string) predicate.ClaudeSession
- func ConversationIDNotNil() predicate.ClaudeSession
- func CreateNewOnMissing(v bool) predicate.ClaudeSession
- func CreateNewOnMissingEQ(v bool) predicate.ClaudeSession
- func CreateNewOnMissingNEQ(v bool) predicate.ClaudeSession
- func HasMetadata() predicate.ClaudeSession
- func HasMetadataWith(preds ...predicate.ClaudeMetadata) predicate.ClaudeSession
- func HasSession() predicate.ClaudeSession
- func HasSessionWith(preds ...predicate.Session) predicate.ClaudeSession
- func ID(id int) predicate.ClaudeSession
- func IDEQ(id int) predicate.ClaudeSession
- func IDGT(id int) predicate.ClaudeSession
- func IDGTE(id int) predicate.ClaudeSession
- func IDIn(ids ...int) predicate.ClaudeSession
- func IDLT(id int) predicate.ClaudeSession
- func IDLTE(id int) predicate.ClaudeSession
- func IDNEQ(id int) predicate.ClaudeSession
- func IDNotIn(ids ...int) predicate.ClaudeSession
- func LastAttached(v time.Time) predicate.ClaudeSession
- func LastAttachedEQ(v time.Time) predicate.ClaudeSession
- func LastAttachedGT(v time.Time) predicate.ClaudeSession
- func LastAttachedGTE(v time.Time) predicate.ClaudeSession
- func LastAttachedIn(vs ...time.Time) predicate.ClaudeSession
- func LastAttachedIsNil() predicate.ClaudeSession
- func LastAttachedLT(v time.Time) predicate.ClaudeSession
- func LastAttachedLTE(v time.Time) predicate.ClaudeSession
- func LastAttachedNEQ(v time.Time) predicate.ClaudeSession
- func LastAttachedNotIn(vs ...time.Time) predicate.ClaudeSession
- func LastAttachedNotNil() predicate.ClaudeSession
- func Not(p predicate.ClaudeSession) predicate.ClaudeSession
- func Or(predicates ...predicate.ClaudeSession) predicate.ClaudeSession
- func PreferredSessionName(v string) predicate.ClaudeSession
- func PreferredSessionNameContains(v string) predicate.ClaudeSession
- func PreferredSessionNameContainsFold(v string) predicate.ClaudeSession
- func PreferredSessionNameEQ(v string) predicate.ClaudeSession
- func PreferredSessionNameEqualFold(v string) predicate.ClaudeSession
- func PreferredSessionNameGT(v string) predicate.ClaudeSession
- func PreferredSessionNameGTE(v string) predicate.ClaudeSession
- func PreferredSessionNameHasPrefix(v string) predicate.ClaudeSession
- func PreferredSessionNameHasSuffix(v string) predicate.ClaudeSession
- func PreferredSessionNameIn(vs ...string) predicate.ClaudeSession
- func PreferredSessionNameIsNil() predicate.ClaudeSession
- func PreferredSessionNameLT(v string) predicate.ClaudeSession
- func PreferredSessionNameLTE(v string) predicate.ClaudeSession
- func PreferredSessionNameNEQ(v string) predicate.ClaudeSession
- func PreferredSessionNameNotIn(vs ...string) predicate.ClaudeSession
- func PreferredSessionNameNotNil() predicate.ClaudeSession
- func ProjectName(v string) predicate.ClaudeSession
- func ProjectNameContains(v string) predicate.ClaudeSession
- func ProjectNameContainsFold(v string) predicate.ClaudeSession
- func ProjectNameEQ(v string) predicate.ClaudeSession
- func ProjectNameEqualFold(v string) predicate.ClaudeSession
- func ProjectNameGT(v string) predicate.ClaudeSession
- func ProjectNameGTE(v string) predicate.ClaudeSession
- func ProjectNameHasPrefix(v string) predicate.ClaudeSession
- func ProjectNameHasSuffix(v string) predicate.ClaudeSession
- func ProjectNameIn(vs ...string) predicate.ClaudeSession
- func ProjectNameIsNil() predicate.ClaudeSession
- func ProjectNameLT(v string) predicate.ClaudeSession
- func ProjectNameLTE(v string) predicate.ClaudeSession
- func ProjectNameNEQ(v string) predicate.ClaudeSession
- func ProjectNameNotIn(vs ...string) predicate.ClaudeSession
- func ProjectNameNotNil() predicate.ClaudeSession
- func SessionTimeoutMinutes(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesEQ(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesGT(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesGTE(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesIn(vs ...int) predicate.ClaudeSession
- func SessionTimeoutMinutesLT(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesLTE(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesNEQ(v int) predicate.ClaudeSession
- func SessionTimeoutMinutesNotIn(vs ...int) predicate.ClaudeSession
- func ShowSessionSelector(v bool) predicate.ClaudeSession
- func ShowSessionSelectorEQ(v bool) predicate.ClaudeSession
- func ShowSessionSelectorNEQ(v bool) predicate.ClaudeSession
- func ValidColumn(column string) bool
- type OrderOption
- func ByAutoReattach(opts ...sql.OrderTermOption) OrderOption
- func ByClaudeSessionID(opts ...sql.OrderTermOption) OrderOption
- func ByConversationID(opts ...sql.OrderTermOption) OrderOption
- func ByCreateNewOnMissing(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastAttached(opts ...sql.OrderTermOption) OrderOption
- func ByMetadata(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMetadataCount(opts ...sql.OrderTermOption) OrderOption
- func ByPreferredSessionName(opts ...sql.OrderTermOption) OrderOption
- func ByProjectName(opts ...sql.OrderTermOption) OrderOption
- func BySessionField(field string, opts ...sql.OrderTermOption) OrderOption
- func BySessionTimeoutMinutes(opts ...sql.OrderTermOption) OrderOption
- func ByShowSessionSelector(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the claudesession type in the database. Label = "claude_session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldClaudeSessionID holds the string denoting the claude_session_id field in the database. FieldClaudeSessionID = "claude_session_id" // FieldConversationID holds the string denoting the conversation_id field in the database. FieldConversationID = "conversation_id" // FieldProjectName holds the string denoting the project_name field in the database. FieldProjectName = "project_name" // FieldLastAttached holds the string denoting the last_attached field in the database. FieldLastAttached = "last_attached" // FieldAutoReattach holds the string denoting the auto_reattach field in the database. FieldAutoReattach = "auto_reattach" // FieldPreferredSessionName holds the string denoting the preferred_session_name field in the database. FieldPreferredSessionName = "preferred_session_name" // FieldCreateNewOnMissing holds the string denoting the create_new_on_missing field in the database. FieldCreateNewOnMissing = "create_new_on_missing" // FieldShowSessionSelector holds the string denoting the show_session_selector field in the database. FieldShowSessionSelector = "show_session_selector" // FieldSessionTimeoutMinutes holds the string denoting the session_timeout_minutes field in the database. FieldSessionTimeoutMinutes = "session_timeout_minutes" // EdgeSession holds the string denoting the session edge name in mutations. EdgeSession = "session" // EdgeMetadata holds the string denoting the metadata edge name in mutations. EdgeMetadata = "metadata" // Table holds the table name of the claudesession in the database. Table = "claude_sessions" // SessionTable is the table that holds the session relation/edge. SessionTable = "claude_sessions" // SessionInverseTable is the table name for the Session entity. // It exists in this package in order to avoid circular dependency with the "session" package. SessionInverseTable = "sessions" // SessionColumn is the table column denoting the session relation/edge. SessionColumn = "session_claude_session" // MetadataTable is the table that holds the metadata relation/edge. MetadataTable = "claude_metadata" // MetadataInverseTable is the table name for the ClaudeMetadata entity. // It exists in this package in order to avoid circular dependency with the "claudemetadata" package. MetadataInverseTable = "claude_metadata" // MetadataColumn is the table column denoting the metadata relation/edge. MetadataColumn = "claude_session_metadata" )
Variables ¶
var ( // ClaudeSessionIDValidator is a validator for the "claude_session_id" field. It is called by the builders before save. ClaudeSessionIDValidator func(string) error // DefaultAutoReattach holds the default value on creation for the "auto_reattach" field. DefaultAutoReattach bool // DefaultCreateNewOnMissing holds the default value on creation for the "create_new_on_missing" field. DefaultCreateNewOnMissing bool // DefaultShowSessionSelector holds the default value on creation for the "show_session_selector" field. DefaultShowSessionSelector bool // DefaultSessionTimeoutMinutes holds the default value on creation for the "session_timeout_minutes" field. DefaultSessionTimeoutMinutes int )
var Columns = []string{ FieldID, FieldClaudeSessionID, FieldConversationID, FieldProjectName, FieldLastAttached, FieldAutoReattach, FieldPreferredSessionName, FieldCreateNewOnMissing, FieldShowSessionSelector, FieldSessionTimeoutMinutes, }
Columns holds all SQL columns for claudesession fields.
var ForeignKeys = []string{
"session_claude_session",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "claude_sessions" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.ClaudeSession) predicate.ClaudeSession
And groups predicates with the AND operator between them.
func AutoReattach ¶
func AutoReattach(v bool) predicate.ClaudeSession
AutoReattach applies equality check predicate on the "auto_reattach" field. It's identical to AutoReattachEQ.
func AutoReattachEQ ¶
func AutoReattachEQ(v bool) predicate.ClaudeSession
AutoReattachEQ applies the EQ predicate on the "auto_reattach" field.
func AutoReattachNEQ ¶
func AutoReattachNEQ(v bool) predicate.ClaudeSession
AutoReattachNEQ applies the NEQ predicate on the "auto_reattach" field.
func ClaudeSessionID ¶
func ClaudeSessionID(v string) predicate.ClaudeSession
ClaudeSessionID applies equality check predicate on the "claude_session_id" field. It's identical to ClaudeSessionIDEQ.
func ClaudeSessionIDContains ¶
func ClaudeSessionIDContains(v string) predicate.ClaudeSession
ClaudeSessionIDContains applies the Contains predicate on the "claude_session_id" field.
func ClaudeSessionIDContainsFold ¶
func ClaudeSessionIDContainsFold(v string) predicate.ClaudeSession
ClaudeSessionIDContainsFold applies the ContainsFold predicate on the "claude_session_id" field.
func ClaudeSessionIDEQ ¶
func ClaudeSessionIDEQ(v string) predicate.ClaudeSession
ClaudeSessionIDEQ applies the EQ predicate on the "claude_session_id" field.
func ClaudeSessionIDEqualFold ¶
func ClaudeSessionIDEqualFold(v string) predicate.ClaudeSession
ClaudeSessionIDEqualFold applies the EqualFold predicate on the "claude_session_id" field.
func ClaudeSessionIDGT ¶
func ClaudeSessionIDGT(v string) predicate.ClaudeSession
ClaudeSessionIDGT applies the GT predicate on the "claude_session_id" field.
func ClaudeSessionIDGTE ¶
func ClaudeSessionIDGTE(v string) predicate.ClaudeSession
ClaudeSessionIDGTE applies the GTE predicate on the "claude_session_id" field.
func ClaudeSessionIDHasPrefix ¶
func ClaudeSessionIDHasPrefix(v string) predicate.ClaudeSession
ClaudeSessionIDHasPrefix applies the HasPrefix predicate on the "claude_session_id" field.
func ClaudeSessionIDHasSuffix ¶
func ClaudeSessionIDHasSuffix(v string) predicate.ClaudeSession
ClaudeSessionIDHasSuffix applies the HasSuffix predicate on the "claude_session_id" field.
func ClaudeSessionIDIn ¶
func ClaudeSessionIDIn(vs ...string) predicate.ClaudeSession
ClaudeSessionIDIn applies the In predicate on the "claude_session_id" field.
func ClaudeSessionIDLT ¶
func ClaudeSessionIDLT(v string) predicate.ClaudeSession
ClaudeSessionIDLT applies the LT predicate on the "claude_session_id" field.
func ClaudeSessionIDLTE ¶
func ClaudeSessionIDLTE(v string) predicate.ClaudeSession
ClaudeSessionIDLTE applies the LTE predicate on the "claude_session_id" field.
func ClaudeSessionIDNEQ ¶
func ClaudeSessionIDNEQ(v string) predicate.ClaudeSession
ClaudeSessionIDNEQ applies the NEQ predicate on the "claude_session_id" field.
func ClaudeSessionIDNotIn ¶
func ClaudeSessionIDNotIn(vs ...string) predicate.ClaudeSession
ClaudeSessionIDNotIn applies the NotIn predicate on the "claude_session_id" field.
func ConversationID ¶
func ConversationID(v string) predicate.ClaudeSession
ConversationID applies equality check predicate on the "conversation_id" field. It's identical to ConversationIDEQ.
func ConversationIDContains ¶
func ConversationIDContains(v string) predicate.ClaudeSession
ConversationIDContains applies the Contains predicate on the "conversation_id" field.
func ConversationIDContainsFold ¶
func ConversationIDContainsFold(v string) predicate.ClaudeSession
ConversationIDContainsFold applies the ContainsFold predicate on the "conversation_id" field.
func ConversationIDEQ ¶
func ConversationIDEQ(v string) predicate.ClaudeSession
ConversationIDEQ applies the EQ predicate on the "conversation_id" field.
func ConversationIDEqualFold ¶
func ConversationIDEqualFold(v string) predicate.ClaudeSession
ConversationIDEqualFold applies the EqualFold predicate on the "conversation_id" field.
func ConversationIDGT ¶
func ConversationIDGT(v string) predicate.ClaudeSession
ConversationIDGT applies the GT predicate on the "conversation_id" field.
func ConversationIDGTE ¶
func ConversationIDGTE(v string) predicate.ClaudeSession
ConversationIDGTE applies the GTE predicate on the "conversation_id" field.
func ConversationIDHasPrefix ¶
func ConversationIDHasPrefix(v string) predicate.ClaudeSession
ConversationIDHasPrefix applies the HasPrefix predicate on the "conversation_id" field.
func ConversationIDHasSuffix ¶
func ConversationIDHasSuffix(v string) predicate.ClaudeSession
ConversationIDHasSuffix applies the HasSuffix predicate on the "conversation_id" field.
func ConversationIDIn ¶
func ConversationIDIn(vs ...string) predicate.ClaudeSession
ConversationIDIn applies the In predicate on the "conversation_id" field.
func ConversationIDIsNil ¶
func ConversationIDIsNil() predicate.ClaudeSession
ConversationIDIsNil applies the IsNil predicate on the "conversation_id" field.
func ConversationIDLT ¶
func ConversationIDLT(v string) predicate.ClaudeSession
ConversationIDLT applies the LT predicate on the "conversation_id" field.
func ConversationIDLTE ¶
func ConversationIDLTE(v string) predicate.ClaudeSession
ConversationIDLTE applies the LTE predicate on the "conversation_id" field.
func ConversationIDNEQ ¶
func ConversationIDNEQ(v string) predicate.ClaudeSession
ConversationIDNEQ applies the NEQ predicate on the "conversation_id" field.
func ConversationIDNotIn ¶
func ConversationIDNotIn(vs ...string) predicate.ClaudeSession
ConversationIDNotIn applies the NotIn predicate on the "conversation_id" field.
func ConversationIDNotNil ¶
func ConversationIDNotNil() predicate.ClaudeSession
ConversationIDNotNil applies the NotNil predicate on the "conversation_id" field.
func CreateNewOnMissing ¶
func CreateNewOnMissing(v bool) predicate.ClaudeSession
CreateNewOnMissing applies equality check predicate on the "create_new_on_missing" field. It's identical to CreateNewOnMissingEQ.
func CreateNewOnMissingEQ ¶
func CreateNewOnMissingEQ(v bool) predicate.ClaudeSession
CreateNewOnMissingEQ applies the EQ predicate on the "create_new_on_missing" field.
func CreateNewOnMissingNEQ ¶
func CreateNewOnMissingNEQ(v bool) predicate.ClaudeSession
CreateNewOnMissingNEQ applies the NEQ predicate on the "create_new_on_missing" field.
func HasMetadata ¶
func HasMetadata() predicate.ClaudeSession
HasMetadata applies the HasEdge predicate on the "metadata" edge.
func HasMetadataWith ¶
func HasMetadataWith(preds ...predicate.ClaudeMetadata) predicate.ClaudeSession
HasMetadataWith applies the HasEdge predicate on the "metadata" edge with a given conditions (other predicates).
func HasSession ¶
func HasSession() predicate.ClaudeSession
HasSession applies the HasEdge predicate on the "session" edge.
func HasSessionWith ¶
func HasSessionWith(preds ...predicate.Session) predicate.ClaudeSession
HasSessionWith applies the HasEdge predicate on the "session" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.ClaudeSession
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.ClaudeSession
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.ClaudeSession
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.ClaudeSession
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.ClaudeSession
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.ClaudeSession
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.ClaudeSession
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.ClaudeSession
IDNotIn applies the NotIn predicate on the ID field.
func LastAttached ¶
func LastAttached(v time.Time) predicate.ClaudeSession
LastAttached applies equality check predicate on the "last_attached" field. It's identical to LastAttachedEQ.
func LastAttachedEQ ¶
func LastAttachedEQ(v time.Time) predicate.ClaudeSession
LastAttachedEQ applies the EQ predicate on the "last_attached" field.
func LastAttachedGT ¶
func LastAttachedGT(v time.Time) predicate.ClaudeSession
LastAttachedGT applies the GT predicate on the "last_attached" field.
func LastAttachedGTE ¶
func LastAttachedGTE(v time.Time) predicate.ClaudeSession
LastAttachedGTE applies the GTE predicate on the "last_attached" field.
func LastAttachedIn ¶
func LastAttachedIn(vs ...time.Time) predicate.ClaudeSession
LastAttachedIn applies the In predicate on the "last_attached" field.
func LastAttachedIsNil ¶
func LastAttachedIsNil() predicate.ClaudeSession
LastAttachedIsNil applies the IsNil predicate on the "last_attached" field.
func LastAttachedLT ¶
func LastAttachedLT(v time.Time) predicate.ClaudeSession
LastAttachedLT applies the LT predicate on the "last_attached" field.
func LastAttachedLTE ¶
func LastAttachedLTE(v time.Time) predicate.ClaudeSession
LastAttachedLTE applies the LTE predicate on the "last_attached" field.
func LastAttachedNEQ ¶
func LastAttachedNEQ(v time.Time) predicate.ClaudeSession
LastAttachedNEQ applies the NEQ predicate on the "last_attached" field.
func LastAttachedNotIn ¶
func LastAttachedNotIn(vs ...time.Time) predicate.ClaudeSession
LastAttachedNotIn applies the NotIn predicate on the "last_attached" field.
func LastAttachedNotNil ¶
func LastAttachedNotNil() predicate.ClaudeSession
LastAttachedNotNil applies the NotNil predicate on the "last_attached" field.
func Not ¶
func Not(p predicate.ClaudeSession) predicate.ClaudeSession
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ClaudeSession) predicate.ClaudeSession
Or groups predicates with the OR operator between them.
func PreferredSessionName ¶
func PreferredSessionName(v string) predicate.ClaudeSession
PreferredSessionName applies equality check predicate on the "preferred_session_name" field. It's identical to PreferredSessionNameEQ.
func PreferredSessionNameContains ¶
func PreferredSessionNameContains(v string) predicate.ClaudeSession
PreferredSessionNameContains applies the Contains predicate on the "preferred_session_name" field.
func PreferredSessionNameContainsFold ¶
func PreferredSessionNameContainsFold(v string) predicate.ClaudeSession
PreferredSessionNameContainsFold applies the ContainsFold predicate on the "preferred_session_name" field.
func PreferredSessionNameEQ ¶
func PreferredSessionNameEQ(v string) predicate.ClaudeSession
PreferredSessionNameEQ applies the EQ predicate on the "preferred_session_name" field.
func PreferredSessionNameEqualFold ¶
func PreferredSessionNameEqualFold(v string) predicate.ClaudeSession
PreferredSessionNameEqualFold applies the EqualFold predicate on the "preferred_session_name" field.
func PreferredSessionNameGT ¶
func PreferredSessionNameGT(v string) predicate.ClaudeSession
PreferredSessionNameGT applies the GT predicate on the "preferred_session_name" field.
func PreferredSessionNameGTE ¶
func PreferredSessionNameGTE(v string) predicate.ClaudeSession
PreferredSessionNameGTE applies the GTE predicate on the "preferred_session_name" field.
func PreferredSessionNameHasPrefix ¶
func PreferredSessionNameHasPrefix(v string) predicate.ClaudeSession
PreferredSessionNameHasPrefix applies the HasPrefix predicate on the "preferred_session_name" field.
func PreferredSessionNameHasSuffix ¶
func PreferredSessionNameHasSuffix(v string) predicate.ClaudeSession
PreferredSessionNameHasSuffix applies the HasSuffix predicate on the "preferred_session_name" field.
func PreferredSessionNameIn ¶
func PreferredSessionNameIn(vs ...string) predicate.ClaudeSession
PreferredSessionNameIn applies the In predicate on the "preferred_session_name" field.
func PreferredSessionNameIsNil ¶
func PreferredSessionNameIsNil() predicate.ClaudeSession
PreferredSessionNameIsNil applies the IsNil predicate on the "preferred_session_name" field.
func PreferredSessionNameLT ¶
func PreferredSessionNameLT(v string) predicate.ClaudeSession
PreferredSessionNameLT applies the LT predicate on the "preferred_session_name" field.
func PreferredSessionNameLTE ¶
func PreferredSessionNameLTE(v string) predicate.ClaudeSession
PreferredSessionNameLTE applies the LTE predicate on the "preferred_session_name" field.
func PreferredSessionNameNEQ ¶
func PreferredSessionNameNEQ(v string) predicate.ClaudeSession
PreferredSessionNameNEQ applies the NEQ predicate on the "preferred_session_name" field.
func PreferredSessionNameNotIn ¶
func PreferredSessionNameNotIn(vs ...string) predicate.ClaudeSession
PreferredSessionNameNotIn applies the NotIn predicate on the "preferred_session_name" field.
func PreferredSessionNameNotNil ¶
func PreferredSessionNameNotNil() predicate.ClaudeSession
PreferredSessionNameNotNil applies the NotNil predicate on the "preferred_session_name" field.
func ProjectName ¶
func ProjectName(v string) predicate.ClaudeSession
ProjectName applies equality check predicate on the "project_name" field. It's identical to ProjectNameEQ.
func ProjectNameContains ¶
func ProjectNameContains(v string) predicate.ClaudeSession
ProjectNameContains applies the Contains predicate on the "project_name" field.
func ProjectNameContainsFold ¶
func ProjectNameContainsFold(v string) predicate.ClaudeSession
ProjectNameContainsFold applies the ContainsFold predicate on the "project_name" field.
func ProjectNameEQ ¶
func ProjectNameEQ(v string) predicate.ClaudeSession
ProjectNameEQ applies the EQ predicate on the "project_name" field.
func ProjectNameEqualFold ¶
func ProjectNameEqualFold(v string) predicate.ClaudeSession
ProjectNameEqualFold applies the EqualFold predicate on the "project_name" field.
func ProjectNameGT ¶
func ProjectNameGT(v string) predicate.ClaudeSession
ProjectNameGT applies the GT predicate on the "project_name" field.
func ProjectNameGTE ¶
func ProjectNameGTE(v string) predicate.ClaudeSession
ProjectNameGTE applies the GTE predicate on the "project_name" field.
func ProjectNameHasPrefix ¶
func ProjectNameHasPrefix(v string) predicate.ClaudeSession
ProjectNameHasPrefix applies the HasPrefix predicate on the "project_name" field.
func ProjectNameHasSuffix ¶
func ProjectNameHasSuffix(v string) predicate.ClaudeSession
ProjectNameHasSuffix applies the HasSuffix predicate on the "project_name" field.
func ProjectNameIn ¶
func ProjectNameIn(vs ...string) predicate.ClaudeSession
ProjectNameIn applies the In predicate on the "project_name" field.
func ProjectNameIsNil ¶
func ProjectNameIsNil() predicate.ClaudeSession
ProjectNameIsNil applies the IsNil predicate on the "project_name" field.
func ProjectNameLT ¶
func ProjectNameLT(v string) predicate.ClaudeSession
ProjectNameLT applies the LT predicate on the "project_name" field.
func ProjectNameLTE ¶
func ProjectNameLTE(v string) predicate.ClaudeSession
ProjectNameLTE applies the LTE predicate on the "project_name" field.
func ProjectNameNEQ ¶
func ProjectNameNEQ(v string) predicate.ClaudeSession
ProjectNameNEQ applies the NEQ predicate on the "project_name" field.
func ProjectNameNotIn ¶
func ProjectNameNotIn(vs ...string) predicate.ClaudeSession
ProjectNameNotIn applies the NotIn predicate on the "project_name" field.
func ProjectNameNotNil ¶
func ProjectNameNotNil() predicate.ClaudeSession
ProjectNameNotNil applies the NotNil predicate on the "project_name" field.
func SessionTimeoutMinutes ¶
func SessionTimeoutMinutes(v int) predicate.ClaudeSession
SessionTimeoutMinutes applies equality check predicate on the "session_timeout_minutes" field. It's identical to SessionTimeoutMinutesEQ.
func SessionTimeoutMinutesEQ ¶
func SessionTimeoutMinutesEQ(v int) predicate.ClaudeSession
SessionTimeoutMinutesEQ applies the EQ predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesGT ¶
func SessionTimeoutMinutesGT(v int) predicate.ClaudeSession
SessionTimeoutMinutesGT applies the GT predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesGTE ¶
func SessionTimeoutMinutesGTE(v int) predicate.ClaudeSession
SessionTimeoutMinutesGTE applies the GTE predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesIn ¶
func SessionTimeoutMinutesIn(vs ...int) predicate.ClaudeSession
SessionTimeoutMinutesIn applies the In predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesLT ¶
func SessionTimeoutMinutesLT(v int) predicate.ClaudeSession
SessionTimeoutMinutesLT applies the LT predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesLTE ¶
func SessionTimeoutMinutesLTE(v int) predicate.ClaudeSession
SessionTimeoutMinutesLTE applies the LTE predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesNEQ ¶
func SessionTimeoutMinutesNEQ(v int) predicate.ClaudeSession
SessionTimeoutMinutesNEQ applies the NEQ predicate on the "session_timeout_minutes" field.
func SessionTimeoutMinutesNotIn ¶
func SessionTimeoutMinutesNotIn(vs ...int) predicate.ClaudeSession
SessionTimeoutMinutesNotIn applies the NotIn predicate on the "session_timeout_minutes" field.
func ShowSessionSelector ¶
func ShowSessionSelector(v bool) predicate.ClaudeSession
ShowSessionSelector applies equality check predicate on the "show_session_selector" field. It's identical to ShowSessionSelectorEQ.
func ShowSessionSelectorEQ ¶
func ShowSessionSelectorEQ(v bool) predicate.ClaudeSession
ShowSessionSelectorEQ applies the EQ predicate on the "show_session_selector" field.
func ShowSessionSelectorNEQ ¶
func ShowSessionSelectorNEQ(v bool) predicate.ClaudeSession
ShowSessionSelectorNEQ applies the NEQ predicate on the "show_session_selector" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ClaudeSession queries.
func ByAutoReattach ¶
func ByAutoReattach(opts ...sql.OrderTermOption) OrderOption
ByAutoReattach orders the results by the auto_reattach field.
func ByClaudeSessionID ¶
func ByClaudeSessionID(opts ...sql.OrderTermOption) OrderOption
ByClaudeSessionID orders the results by the claude_session_id field.
func ByConversationID ¶
func ByConversationID(opts ...sql.OrderTermOption) OrderOption
ByConversationID orders the results by the conversation_id field.
func ByCreateNewOnMissing ¶
func ByCreateNewOnMissing(opts ...sql.OrderTermOption) OrderOption
ByCreateNewOnMissing orders the results by the create_new_on_missing field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastAttached ¶
func ByLastAttached(opts ...sql.OrderTermOption) OrderOption
ByLastAttached orders the results by the last_attached field.
func ByMetadata ¶
func ByMetadata(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMetadata orders the results by metadata terms.
func ByMetadataCount ¶
func ByMetadataCount(opts ...sql.OrderTermOption) OrderOption
ByMetadataCount orders the results by metadata count.
func ByPreferredSessionName ¶
func ByPreferredSessionName(opts ...sql.OrderTermOption) OrderOption
ByPreferredSessionName orders the results by the preferred_session_name field.
func ByProjectName ¶
func ByProjectName(opts ...sql.OrderTermOption) OrderOption
ByProjectName orders the results by the project_name field.
func BySessionField ¶
func BySessionField(field string, opts ...sql.OrderTermOption) OrderOption
BySessionField orders the results by session field.
func BySessionTimeoutMinutes ¶
func BySessionTimeoutMinutes(opts ...sql.OrderTermOption) OrderOption
BySessionTimeoutMinutes orders the results by the session_timeout_minutes field.
func ByShowSessionSelector ¶
func ByShowSessionSelector(opts ...sql.OrderTermOption) OrderOption
ByShowSessionSelector orders the results by the show_session_selector field.