Documentation
¶
Index ¶
- func FixedError(err error) ent.Hook
- func If(hk ent.Hook, cond Condition) ent.Hook
- func On(hk ent.Hook, op ent.Op) ent.Hook
- func Reject(op ent.Op) ent.Hook
- func Unless(hk ent.Hook, op ent.Op) ent.Hook
- type AnalyticsEventFunc
- type ApprovalRuleFunc
- type BacklogItemDependencyFunc
- type BacklogItemFunc
- type BacklogProgressNoteFunc
- type BacklogStatusEventFunc
- type BacklogStuckStateFunc
- type Chain
- type ClassificationAnalyticsFunc
- type ClaudeMetadataFunc
- type ClaudeSessionFunc
- type Condition
- func And(first, second Condition, rest ...Condition) Condition
- func HasAddedFields(field string, fields ...string) Condition
- func HasClearedFields(field string, fields ...string) Condition
- func HasFields(field string, fields ...string) Condition
- func HasOp(op ent.Op) Condition
- func Not(cond Condition) Condition
- func Or(first, second Condition, rest ...Condition) Condition
- type DiffStatsFunc
- type ErrorEventFunc
- type EscapeEventFunc
- type ItemSessionFunc
- type ItemSourceFunc
- type PipelineModeFunc
- type ProjectFunc
- type ReviewVerdictFunc
- type SessionFunc
- type SessionGoalFunc
- type SessionSummaryFunc
- type ShellFunc
- type SourceSyncEventFunc
- type TagFunc
- type TriggerFireEventFunc
- type WorkflowFunc
- type WorktreeFunc
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func If ¶
If executes the given hook under condition.
hook.If(ComputeAverage, And(HasFields(...), HasAddedFields(...)))
func On ¶
On executes the given hook only for the given operation.
hook.On(Log, ent.Delete|ent.Create)
Types ¶
type AnalyticsEventFunc ¶ added in v1.35.0
The AnalyticsEventFunc type is an adapter to allow the use of ordinary function as AnalyticsEvent mutator.
type ApprovalRuleFunc ¶ added in v1.12.0
The ApprovalRuleFunc type is an adapter to allow the use of ordinary function as ApprovalRule mutator.
type BacklogItemDependencyFunc ¶ added in v1.43.0
type BacklogItemDependencyFunc func(context.Context, *ent.BacklogItemDependencyMutation) (ent.Value, error)
The BacklogItemDependencyFunc type is an adapter to allow the use of ordinary function as BacklogItemDependency mutator.
type BacklogItemFunc ¶ added in v1.35.0
The BacklogItemFunc type is an adapter to allow the use of ordinary function as BacklogItem mutator.
type BacklogProgressNoteFunc ¶ added in v1.38.0
type BacklogProgressNoteFunc func(context.Context, *ent.BacklogProgressNoteMutation) (ent.Value, error)
The BacklogProgressNoteFunc type is an adapter to allow the use of ordinary function as BacklogProgressNote mutator.
type BacklogStatusEventFunc ¶ added in v1.35.0
type BacklogStatusEventFunc func(context.Context, *ent.BacklogStatusEventMutation) (ent.Value, error)
The BacklogStatusEventFunc type is an adapter to allow the use of ordinary function as BacklogStatusEvent mutator.
type BacklogStuckStateFunc ¶ added in v1.38.0
The BacklogStuckStateFunc type is an adapter to allow the use of ordinary function as BacklogStuckState mutator.
type Chain ¶
type Chain struct {
// contains filtered or unexported fields
}
Chain acts as a list of hooks and is effectively immutable. Once created, it will always hold the same set of hooks in the same order.
func (Chain) Append ¶
Append extends a chain, adding the specified hook as the last ones in the mutation flow.
type ClassificationAnalyticsFunc ¶ added in v1.12.0
type ClassificationAnalyticsFunc func(context.Context, *ent.ClassificationAnalyticsMutation) (ent.Value, error)
The ClassificationAnalyticsFunc type is an adapter to allow the use of ordinary function as ClassificationAnalytics mutator.
type ClaudeMetadataFunc ¶
The ClaudeMetadataFunc type is an adapter to allow the use of ordinary function as ClaudeMetadata mutator.
type ClaudeSessionFunc ¶
The ClaudeSessionFunc type is an adapter to allow the use of ordinary function as ClaudeSession mutator.
type Condition ¶
Condition is a hook condition function.
func HasAddedFields ¶
HasAddedFields is a condition validating `.AddedField` on fields.
func HasClearedFields ¶
HasClearedFields is a condition validating `.FieldCleared` on fields.
type DiffStatsFunc ¶
The DiffStatsFunc type is an adapter to allow the use of ordinary function as DiffStats mutator.
type ErrorEventFunc ¶ added in v1.35.0
The ErrorEventFunc type is an adapter to allow the use of ordinary function as ErrorEvent mutator.
type EscapeEventFunc ¶ added in v1.35.0
The EscapeEventFunc type is an adapter to allow the use of ordinary function as EscapeEvent mutator.
type ItemSessionFunc ¶ added in v1.35.0
The ItemSessionFunc type is an adapter to allow the use of ordinary function as ItemSession mutator.
type ItemSourceFunc ¶ added in v1.35.0
The ItemSourceFunc type is an adapter to allow the use of ordinary function as ItemSource mutator.
type PipelineModeFunc ¶ added in v1.38.0
The PipelineModeFunc type is an adapter to allow the use of ordinary function as PipelineMode mutator.
type ProjectFunc ¶ added in v1.23.0
The ProjectFunc type is an adapter to allow the use of ordinary function as Project mutator.
type ReviewVerdictFunc ¶ added in v1.35.0
The ReviewVerdictFunc type is an adapter to allow the use of ordinary function as ReviewVerdict mutator.
type SessionFunc ¶
The SessionFunc type is an adapter to allow the use of ordinary function as Session mutator.
type SessionGoalFunc ¶ added in v1.35.0
The SessionGoalFunc type is an adapter to allow the use of ordinary function as SessionGoal mutator.
type SessionSummaryFunc ¶ added in v1.41.0
The SessionSummaryFunc type is an adapter to allow the use of ordinary function as SessionSummary mutator.
type ShellFunc ¶ added in v1.35.0
The ShellFunc type is an adapter to allow the use of ordinary function as Shell mutator.
type SourceSyncEventFunc ¶ added in v1.35.0
The SourceSyncEventFunc type is an adapter to allow the use of ordinary function as SourceSyncEvent mutator.
type TriggerFireEventFunc ¶ added in v1.43.0
The TriggerFireEventFunc type is an adapter to allow the use of ordinary function as TriggerFireEvent mutator.
type WorkflowFunc ¶ added in v1.35.0
The WorkflowFunc type is an adapter to allow the use of ordinary function as Workflow mutator.
type WorktreeFunc ¶
The WorktreeFunc type is an adapter to allow the use of ordinary function as Worktree mutator.