Documentation
¶
Index ¶
- func FixedError(err error) ent.Hook
- func If(hk ent.Hook, cond Condition) ent.Hook
- func On(hk ent.Hook, op ent.Op) ent.Hook
- func Reject(op ent.Op) ent.Hook
- func Unless(hk ent.Hook, op ent.Op) ent.Hook
- type ApprovalRuleFunc
- type Chain
- type ClassificationAnalyticsFunc
- type ClaudeMetadataFunc
- type ClaudeSessionFunc
- type Condition
- func And(first, second Condition, rest ...Condition) Condition
- func HasAddedFields(field string, fields ...string) Condition
- func HasClearedFields(field string, fields ...string) Condition
- func HasFields(field string, fields ...string) Condition
- func HasOp(op ent.Op) Condition
- func Not(cond Condition) Condition
- func Or(first, second Condition, rest ...Condition) Condition
- type DiffStatsFunc
- type SessionFunc
- type TagFunc
- type WorktreeFunc
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func If ¶
If executes the given hook under condition.
hook.If(ComputeAverage, And(HasFields(...), HasAddedFields(...)))
func On ¶
On executes the given hook only for the given operation.
hook.On(Log, ent.Delete|ent.Create)
Types ¶
type ApprovalRuleFunc ¶ added in v1.12.0
The ApprovalRuleFunc type is an adapter to allow the use of ordinary function as ApprovalRule mutator.
type Chain ¶
type Chain struct {
// contains filtered or unexported fields
}
Chain acts as a list of hooks and is effectively immutable. Once created, it will always hold the same set of hooks in the same order.
func (Chain) Append ¶
Append extends a chain, adding the specified hook as the last ones in the mutation flow.
type ClassificationAnalyticsFunc ¶ added in v1.12.0
type ClassificationAnalyticsFunc func(context.Context, *ent.ClassificationAnalyticsMutation) (ent.Value, error)
The ClassificationAnalyticsFunc type is an adapter to allow the use of ordinary function as ClassificationAnalytics mutator.
type ClaudeMetadataFunc ¶
The ClaudeMetadataFunc type is an adapter to allow the use of ordinary function as ClaudeMetadata mutator.
type ClaudeSessionFunc ¶
The ClaudeSessionFunc type is an adapter to allow the use of ordinary function as ClaudeSession mutator.
type Condition ¶
Condition is a hook condition function.
func HasAddedFields ¶
HasAddedFields is a condition validating `.AddedField` on fields.
func HasClearedFields ¶
HasClearedFields is a condition validating `.FieldCleared` on fields.
type DiffStatsFunc ¶
The DiffStatsFunc type is an adapter to allow the use of ordinary function as DiffStats mutator.
type SessionFunc ¶
The SessionFunc type is an adapter to allow the use of ordinary function as Session mutator.
type WorktreeFunc ¶
The WorktreeFunc type is an adapter to allow the use of ordinary function as Worktree mutator.