Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ReviewVerdict) predicate.ReviewVerdict
- func CreatedAt(v time.Time) predicate.ReviewVerdict
- func CreatedAtEQ(v time.Time) predicate.ReviewVerdict
- func CreatedAtGT(v time.Time) predicate.ReviewVerdict
- func CreatedAtGTE(v time.Time) predicate.ReviewVerdict
- func CreatedAtIn(vs ...time.Time) predicate.ReviewVerdict
- func CreatedAtLT(v time.Time) predicate.ReviewVerdict
- func CreatedAtLTE(v time.Time) predicate.ReviewVerdict
- func CreatedAtNEQ(v time.Time) predicate.ReviewVerdict
- func CreatedAtNotIn(vs ...time.Time) predicate.ReviewVerdict
- func DiffHash(v string) predicate.ReviewVerdict
- func DiffHashContains(v string) predicate.ReviewVerdict
- func DiffHashContainsFold(v string) predicate.ReviewVerdict
- func DiffHashEQ(v string) predicate.ReviewVerdict
- func DiffHashEqualFold(v string) predicate.ReviewVerdict
- func DiffHashGT(v string) predicate.ReviewVerdict
- func DiffHashGTE(v string) predicate.ReviewVerdict
- func DiffHashHasPrefix(v string) predicate.ReviewVerdict
- func DiffHashHasSuffix(v string) predicate.ReviewVerdict
- func DiffHashIn(vs ...string) predicate.ReviewVerdict
- func DiffHashIsNil() predicate.ReviewVerdict
- func DiffHashLT(v string) predicate.ReviewVerdict
- func DiffHashLTE(v string) predicate.ReviewVerdict
- func DiffHashNEQ(v string) predicate.ReviewVerdict
- func DiffHashNotIn(vs ...string) predicate.ReviewVerdict
- func DiffHashNotNil() predicate.ReviewVerdict
- func DiffTokenCount(v int) predicate.ReviewVerdict
- func DiffTokenCountEQ(v int) predicate.ReviewVerdict
- func DiffTokenCountGT(v int) predicate.ReviewVerdict
- func DiffTokenCountGTE(v int) predicate.ReviewVerdict
- func DiffTokenCountIn(vs ...int) predicate.ReviewVerdict
- func DiffTokenCountIsNil() predicate.ReviewVerdict
- func DiffTokenCountLT(v int) predicate.ReviewVerdict
- func DiffTokenCountLTE(v int) predicate.ReviewVerdict
- func DiffTokenCountNEQ(v int) predicate.ReviewVerdict
- func DiffTokenCountNotIn(vs ...int) predicate.ReviewVerdict
- func DiffTokenCountNotNil() predicate.ReviewVerdict
- func DiffTruncated(v bool) predicate.ReviewVerdict
- func DiffTruncatedEQ(v bool) predicate.ReviewVerdict
- func DiffTruncatedNEQ(v bool) predicate.ReviewVerdict
- func HasItemSession() predicate.ReviewVerdict
- func HasItemSessionWith(preds ...predicate.ItemSession) predicate.ReviewVerdict
- func ID(id uuid.UUID) predicate.ReviewVerdict
- func IDEQ(id uuid.UUID) predicate.ReviewVerdict
- func IDGT(id uuid.UUID) predicate.ReviewVerdict
- func IDGTE(id uuid.UUID) predicate.ReviewVerdict
- func IDIn(ids ...uuid.UUID) predicate.ReviewVerdict
- func IDLT(id uuid.UUID) predicate.ReviewVerdict
- func IDLTE(id uuid.UUID) predicate.ReviewVerdict
- func IDNEQ(id uuid.UUID) predicate.ReviewVerdict
- func IDNotIn(ids ...uuid.UUID) predicate.ReviewVerdict
- func Not(p predicate.ReviewVerdict) predicate.ReviewVerdict
- func Or(predicates ...predicate.ReviewVerdict) predicate.ReviewVerdict
- func OverallOutcome(v string) predicate.ReviewVerdict
- func OverallOutcomeContains(v string) predicate.ReviewVerdict
- func OverallOutcomeContainsFold(v string) predicate.ReviewVerdict
- func OverallOutcomeEQ(v string) predicate.ReviewVerdict
- func OverallOutcomeEqualFold(v string) predicate.ReviewVerdict
- func OverallOutcomeGT(v string) predicate.ReviewVerdict
- func OverallOutcomeGTE(v string) predicate.ReviewVerdict
- func OverallOutcomeHasPrefix(v string) predicate.ReviewVerdict
- func OverallOutcomeHasSuffix(v string) predicate.ReviewVerdict
- func OverallOutcomeIn(vs ...string) predicate.ReviewVerdict
- func OverallOutcomeLT(v string) predicate.ReviewVerdict
- func OverallOutcomeLTE(v string) predicate.ReviewVerdict
- func OverallOutcomeNEQ(v string) predicate.ReviewVerdict
- func OverallOutcomeNotIn(vs ...string) predicate.ReviewVerdict
- func OverrideAt(v time.Time) predicate.ReviewVerdict
- func OverrideAtEQ(v time.Time) predicate.ReviewVerdict
- func OverrideAtGT(v time.Time) predicate.ReviewVerdict
- func OverrideAtGTE(v time.Time) predicate.ReviewVerdict
- func OverrideAtIn(vs ...time.Time) predicate.ReviewVerdict
- func OverrideAtIsNil() predicate.ReviewVerdict
- func OverrideAtLT(v time.Time) predicate.ReviewVerdict
- func OverrideAtLTE(v time.Time) predicate.ReviewVerdict
- func OverrideAtNEQ(v time.Time) predicate.ReviewVerdict
- func OverrideAtNotIn(vs ...time.Time) predicate.ReviewVerdict
- func OverrideAtNotNil() predicate.ReviewVerdict
- func OverrideBy(v string) predicate.ReviewVerdict
- func OverrideByContains(v string) predicate.ReviewVerdict
- func OverrideByContainsFold(v string) predicate.ReviewVerdict
- func OverrideByEQ(v string) predicate.ReviewVerdict
- func OverrideByEqualFold(v string) predicate.ReviewVerdict
- func OverrideByGT(v string) predicate.ReviewVerdict
- func OverrideByGTE(v string) predicate.ReviewVerdict
- func OverrideByHasPrefix(v string) predicate.ReviewVerdict
- func OverrideByHasSuffix(v string) predicate.ReviewVerdict
- func OverrideByIn(vs ...string) predicate.ReviewVerdict
- func OverrideByIsNil() predicate.ReviewVerdict
- func OverrideByLT(v string) predicate.ReviewVerdict
- func OverrideByLTE(v string) predicate.ReviewVerdict
- func OverrideByNEQ(v string) predicate.ReviewVerdict
- func OverrideByNotIn(vs ...string) predicate.ReviewVerdict
- func OverrideByNotNil() predicate.ReviewVerdict
- func OverrideReason(v string) predicate.ReviewVerdict
- func OverrideReasonContains(v string) predicate.ReviewVerdict
- func OverrideReasonContainsFold(v string) predicate.ReviewVerdict
- func OverrideReasonEQ(v string) predicate.ReviewVerdict
- func OverrideReasonEqualFold(v string) predicate.ReviewVerdict
- func OverrideReasonGT(v string) predicate.ReviewVerdict
- func OverrideReasonGTE(v string) predicate.ReviewVerdict
- func OverrideReasonHasPrefix(v string) predicate.ReviewVerdict
- func OverrideReasonHasSuffix(v string) predicate.ReviewVerdict
- func OverrideReasonIn(vs ...string) predicate.ReviewVerdict
- func OverrideReasonIsNil() predicate.ReviewVerdict
- func OverrideReasonLT(v string) predicate.ReviewVerdict
- func OverrideReasonLTE(v string) predicate.ReviewVerdict
- func OverrideReasonNEQ(v string) predicate.ReviewVerdict
- func OverrideReasonNotIn(vs ...string) predicate.ReviewVerdict
- func OverrideReasonNotNil() predicate.ReviewVerdict
- func PerCriterion(v string) predicate.ReviewVerdict
- func PerCriterionContains(v string) predicate.ReviewVerdict
- func PerCriterionContainsFold(v string) predicate.ReviewVerdict
- func PerCriterionEQ(v string) predicate.ReviewVerdict
- func PerCriterionEqualFold(v string) predicate.ReviewVerdict
- func PerCriterionGT(v string) predicate.ReviewVerdict
- func PerCriterionGTE(v string) predicate.ReviewVerdict
- func PerCriterionHasPrefix(v string) predicate.ReviewVerdict
- func PerCriterionHasSuffix(v string) predicate.ReviewVerdict
- func PerCriterionIn(vs ...string) predicate.ReviewVerdict
- func PerCriterionIsNil() predicate.ReviewVerdict
- func PerCriterionLT(v string) predicate.ReviewVerdict
- func PerCriterionLTE(v string) predicate.ReviewVerdict
- func PerCriterionNEQ(v string) predicate.ReviewVerdict
- func PerCriterionNotIn(vs ...string) predicate.ReviewVerdict
- func PerCriterionNotNil() predicate.ReviewVerdict
- func PromptHash(v string) predicate.ReviewVerdict
- func PromptHashContains(v string) predicate.ReviewVerdict
- func PromptHashContainsFold(v string) predicate.ReviewVerdict
- func PromptHashEQ(v string) predicate.ReviewVerdict
- func PromptHashEqualFold(v string) predicate.ReviewVerdict
- func PromptHashGT(v string) predicate.ReviewVerdict
- func PromptHashGTE(v string) predicate.ReviewVerdict
- func PromptHashHasPrefix(v string) predicate.ReviewVerdict
- func PromptHashHasSuffix(v string) predicate.ReviewVerdict
- func PromptHashIn(vs ...string) predicate.ReviewVerdict
- func PromptHashIsNil() predicate.ReviewVerdict
- func PromptHashLT(v string) predicate.ReviewVerdict
- func PromptHashLTE(v string) predicate.ReviewVerdict
- func PromptHashNEQ(v string) predicate.ReviewVerdict
- func PromptHashNotIn(vs ...string) predicate.ReviewVerdict
- func PromptHashNotNil() predicate.ReviewVerdict
- func Summary(v string) predicate.ReviewVerdict
- func SummaryContains(v string) predicate.ReviewVerdict
- func SummaryContainsFold(v string) predicate.ReviewVerdict
- func SummaryEQ(v string) predicate.ReviewVerdict
- func SummaryEqualFold(v string) predicate.ReviewVerdict
- func SummaryGT(v string) predicate.ReviewVerdict
- func SummaryGTE(v string) predicate.ReviewVerdict
- func SummaryHasPrefix(v string) predicate.ReviewVerdict
- func SummaryHasSuffix(v string) predicate.ReviewVerdict
- func SummaryIn(vs ...string) predicate.ReviewVerdict
- func SummaryIsNil() predicate.ReviewVerdict
- func SummaryLT(v string) predicate.ReviewVerdict
- func SummaryLTE(v string) predicate.ReviewVerdict
- func SummaryNEQ(v string) predicate.ReviewVerdict
- func SummaryNotIn(vs ...string) predicate.ReviewVerdict
- func SummaryNotNil() predicate.ReviewVerdict
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDiffHash(opts ...sql.OrderTermOption) OrderOption
- func ByDiffTokenCount(opts ...sql.OrderTermOption) OrderOption
- func ByDiffTruncated(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByItemSessionField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByOverallOutcome(opts ...sql.OrderTermOption) OrderOption
- func ByOverrideAt(opts ...sql.OrderTermOption) OrderOption
- func ByOverrideBy(opts ...sql.OrderTermOption) OrderOption
- func ByOverrideReason(opts ...sql.OrderTermOption) OrderOption
- func ByPerCriterion(opts ...sql.OrderTermOption) OrderOption
- func ByPromptHash(opts ...sql.OrderTermOption) OrderOption
- func BySummary(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the reviewverdict type in the database. Label = "review_verdict" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldOverallOutcome holds the string denoting the overall_outcome field in the database. FieldOverallOutcome = "overall_outcome" // FieldPerCriterion holds the string denoting the per_criterion field in the database. FieldPerCriterion = "per_criterion" // FieldSummary holds the string denoting the summary field in the database. FieldSummary = "summary" // FieldDiffHash holds the string denoting the diff_hash field in the database. FieldDiffHash = "diff_hash" // FieldPromptHash holds the string denoting the prompt_hash field in the database. FieldPromptHash = "prompt_hash" // FieldDiffTokenCount holds the string denoting the diff_token_count field in the database. FieldDiffTokenCount = "diff_token_count" // FieldDiffTruncated holds the string denoting the diff_truncated field in the database. FieldDiffTruncated = "diff_truncated" // FieldOverrideBy holds the string denoting the override_by field in the database. FieldOverrideBy = "override_by" // FieldOverrideReason holds the string denoting the override_reason field in the database. FieldOverrideReason = "override_reason" // FieldOverrideAt holds the string denoting the override_at field in the database. FieldOverrideAt = "override_at" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeItemSession holds the string denoting the item_session edge name in mutations. EdgeItemSession = "item_session" // Table holds the table name of the reviewverdict in the database. Table = "review_verdicts" // ItemSessionTable is the table that holds the item_session relation/edge. ItemSessionTable = "review_verdicts" // ItemSessionInverseTable is the table name for the ItemSession entity. // It exists in this package in order to avoid circular dependency with the "itemsession" package. ItemSessionInverseTable = "item_sessions" // ItemSessionColumn is the table column denoting the item_session relation/edge. ItemSessionColumn = "item_session_review_verdict" )
Variables ¶
var ( // DefaultDiffTruncated holds the default value on creation for the "diff_truncated" field. DefaultDiffTruncated bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldOverallOutcome, FieldPerCriterion, FieldSummary, FieldDiffHash, FieldPromptHash, FieldDiffTokenCount, FieldDiffTruncated, FieldOverrideBy, FieldOverrideReason, FieldOverrideAt, FieldCreatedAt, }
Columns holds all SQL columns for reviewverdict fields.
var ForeignKeys = []string{
"item_session_review_verdict",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "review_verdicts" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.ReviewVerdict) predicate.ReviewVerdict
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.ReviewVerdict
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.ReviewVerdict
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.ReviewVerdict
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.ReviewVerdict
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.ReviewVerdict
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.ReviewVerdict
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.ReviewVerdict
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.ReviewVerdict
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.ReviewVerdict
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DiffHash ¶
func DiffHash(v string) predicate.ReviewVerdict
DiffHash applies equality check predicate on the "diff_hash" field. It's identical to DiffHashEQ.
func DiffHashContains ¶
func DiffHashContains(v string) predicate.ReviewVerdict
DiffHashContains applies the Contains predicate on the "diff_hash" field.
func DiffHashContainsFold ¶
func DiffHashContainsFold(v string) predicate.ReviewVerdict
DiffHashContainsFold applies the ContainsFold predicate on the "diff_hash" field.
func DiffHashEQ ¶
func DiffHashEQ(v string) predicate.ReviewVerdict
DiffHashEQ applies the EQ predicate on the "diff_hash" field.
func DiffHashEqualFold ¶
func DiffHashEqualFold(v string) predicate.ReviewVerdict
DiffHashEqualFold applies the EqualFold predicate on the "diff_hash" field.
func DiffHashGT ¶
func DiffHashGT(v string) predicate.ReviewVerdict
DiffHashGT applies the GT predicate on the "diff_hash" field.
func DiffHashGTE ¶
func DiffHashGTE(v string) predicate.ReviewVerdict
DiffHashGTE applies the GTE predicate on the "diff_hash" field.
func DiffHashHasPrefix ¶
func DiffHashHasPrefix(v string) predicate.ReviewVerdict
DiffHashHasPrefix applies the HasPrefix predicate on the "diff_hash" field.
func DiffHashHasSuffix ¶
func DiffHashHasSuffix(v string) predicate.ReviewVerdict
DiffHashHasSuffix applies the HasSuffix predicate on the "diff_hash" field.
func DiffHashIn ¶
func DiffHashIn(vs ...string) predicate.ReviewVerdict
DiffHashIn applies the In predicate on the "diff_hash" field.
func DiffHashIsNil ¶
func DiffHashIsNil() predicate.ReviewVerdict
DiffHashIsNil applies the IsNil predicate on the "diff_hash" field.
func DiffHashLT ¶
func DiffHashLT(v string) predicate.ReviewVerdict
DiffHashLT applies the LT predicate on the "diff_hash" field.
func DiffHashLTE ¶
func DiffHashLTE(v string) predicate.ReviewVerdict
DiffHashLTE applies the LTE predicate on the "diff_hash" field.
func DiffHashNEQ ¶
func DiffHashNEQ(v string) predicate.ReviewVerdict
DiffHashNEQ applies the NEQ predicate on the "diff_hash" field.
func DiffHashNotIn ¶
func DiffHashNotIn(vs ...string) predicate.ReviewVerdict
DiffHashNotIn applies the NotIn predicate on the "diff_hash" field.
func DiffHashNotNil ¶
func DiffHashNotNil() predicate.ReviewVerdict
DiffHashNotNil applies the NotNil predicate on the "diff_hash" field.
func DiffTokenCount ¶
func DiffTokenCount(v int) predicate.ReviewVerdict
DiffTokenCount applies equality check predicate on the "diff_token_count" field. It's identical to DiffTokenCountEQ.
func DiffTokenCountEQ ¶
func DiffTokenCountEQ(v int) predicate.ReviewVerdict
DiffTokenCountEQ applies the EQ predicate on the "diff_token_count" field.
func DiffTokenCountGT ¶
func DiffTokenCountGT(v int) predicate.ReviewVerdict
DiffTokenCountGT applies the GT predicate on the "diff_token_count" field.
func DiffTokenCountGTE ¶
func DiffTokenCountGTE(v int) predicate.ReviewVerdict
DiffTokenCountGTE applies the GTE predicate on the "diff_token_count" field.
func DiffTokenCountIn ¶
func DiffTokenCountIn(vs ...int) predicate.ReviewVerdict
DiffTokenCountIn applies the In predicate on the "diff_token_count" field.
func DiffTokenCountIsNil ¶
func DiffTokenCountIsNil() predicate.ReviewVerdict
DiffTokenCountIsNil applies the IsNil predicate on the "diff_token_count" field.
func DiffTokenCountLT ¶
func DiffTokenCountLT(v int) predicate.ReviewVerdict
DiffTokenCountLT applies the LT predicate on the "diff_token_count" field.
func DiffTokenCountLTE ¶
func DiffTokenCountLTE(v int) predicate.ReviewVerdict
DiffTokenCountLTE applies the LTE predicate on the "diff_token_count" field.
func DiffTokenCountNEQ ¶
func DiffTokenCountNEQ(v int) predicate.ReviewVerdict
DiffTokenCountNEQ applies the NEQ predicate on the "diff_token_count" field.
func DiffTokenCountNotIn ¶
func DiffTokenCountNotIn(vs ...int) predicate.ReviewVerdict
DiffTokenCountNotIn applies the NotIn predicate on the "diff_token_count" field.
func DiffTokenCountNotNil ¶
func DiffTokenCountNotNil() predicate.ReviewVerdict
DiffTokenCountNotNil applies the NotNil predicate on the "diff_token_count" field.
func DiffTruncated ¶
func DiffTruncated(v bool) predicate.ReviewVerdict
DiffTruncated applies equality check predicate on the "diff_truncated" field. It's identical to DiffTruncatedEQ.
func DiffTruncatedEQ ¶
func DiffTruncatedEQ(v bool) predicate.ReviewVerdict
DiffTruncatedEQ applies the EQ predicate on the "diff_truncated" field.
func DiffTruncatedNEQ ¶
func DiffTruncatedNEQ(v bool) predicate.ReviewVerdict
DiffTruncatedNEQ applies the NEQ predicate on the "diff_truncated" field.
func HasItemSession ¶
func HasItemSession() predicate.ReviewVerdict
HasItemSession applies the HasEdge predicate on the "item_session" edge.
func HasItemSessionWith ¶
func HasItemSessionWith(preds ...predicate.ItemSession) predicate.ReviewVerdict
HasItemSessionWith applies the HasEdge predicate on the "item_session" edge with a given conditions (other predicates).
func ID ¶
func ID(id uuid.UUID) predicate.ReviewVerdict
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.ReviewVerdict
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.ReviewVerdict
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.ReviewVerdict
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.ReviewVerdict
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.ReviewVerdict
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.ReviewVerdict
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.ReviewVerdict
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.ReviewVerdict
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.ReviewVerdict) predicate.ReviewVerdict
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ReviewVerdict) predicate.ReviewVerdict
Or groups predicates with the OR operator between them.
func OverallOutcome ¶
func OverallOutcome(v string) predicate.ReviewVerdict
OverallOutcome applies equality check predicate on the "overall_outcome" field. It's identical to OverallOutcomeEQ.
func OverallOutcomeContains ¶
func OverallOutcomeContains(v string) predicate.ReviewVerdict
OverallOutcomeContains applies the Contains predicate on the "overall_outcome" field.
func OverallOutcomeContainsFold ¶
func OverallOutcomeContainsFold(v string) predicate.ReviewVerdict
OverallOutcomeContainsFold applies the ContainsFold predicate on the "overall_outcome" field.
func OverallOutcomeEQ ¶
func OverallOutcomeEQ(v string) predicate.ReviewVerdict
OverallOutcomeEQ applies the EQ predicate on the "overall_outcome" field.
func OverallOutcomeEqualFold ¶
func OverallOutcomeEqualFold(v string) predicate.ReviewVerdict
OverallOutcomeEqualFold applies the EqualFold predicate on the "overall_outcome" field.
func OverallOutcomeGT ¶
func OverallOutcomeGT(v string) predicate.ReviewVerdict
OverallOutcomeGT applies the GT predicate on the "overall_outcome" field.
func OverallOutcomeGTE ¶
func OverallOutcomeGTE(v string) predicate.ReviewVerdict
OverallOutcomeGTE applies the GTE predicate on the "overall_outcome" field.
func OverallOutcomeHasPrefix ¶
func OverallOutcomeHasPrefix(v string) predicate.ReviewVerdict
OverallOutcomeHasPrefix applies the HasPrefix predicate on the "overall_outcome" field.
func OverallOutcomeHasSuffix ¶
func OverallOutcomeHasSuffix(v string) predicate.ReviewVerdict
OverallOutcomeHasSuffix applies the HasSuffix predicate on the "overall_outcome" field.
func OverallOutcomeIn ¶
func OverallOutcomeIn(vs ...string) predicate.ReviewVerdict
OverallOutcomeIn applies the In predicate on the "overall_outcome" field.
func OverallOutcomeLT ¶
func OverallOutcomeLT(v string) predicate.ReviewVerdict
OverallOutcomeLT applies the LT predicate on the "overall_outcome" field.
func OverallOutcomeLTE ¶
func OverallOutcomeLTE(v string) predicate.ReviewVerdict
OverallOutcomeLTE applies the LTE predicate on the "overall_outcome" field.
func OverallOutcomeNEQ ¶
func OverallOutcomeNEQ(v string) predicate.ReviewVerdict
OverallOutcomeNEQ applies the NEQ predicate on the "overall_outcome" field.
func OverallOutcomeNotIn ¶
func OverallOutcomeNotIn(vs ...string) predicate.ReviewVerdict
OverallOutcomeNotIn applies the NotIn predicate on the "overall_outcome" field.
func OverrideAt ¶
func OverrideAt(v time.Time) predicate.ReviewVerdict
OverrideAt applies equality check predicate on the "override_at" field. It's identical to OverrideAtEQ.
func OverrideAtEQ ¶
func OverrideAtEQ(v time.Time) predicate.ReviewVerdict
OverrideAtEQ applies the EQ predicate on the "override_at" field.
func OverrideAtGT ¶
func OverrideAtGT(v time.Time) predicate.ReviewVerdict
OverrideAtGT applies the GT predicate on the "override_at" field.
func OverrideAtGTE ¶
func OverrideAtGTE(v time.Time) predicate.ReviewVerdict
OverrideAtGTE applies the GTE predicate on the "override_at" field.
func OverrideAtIn ¶
func OverrideAtIn(vs ...time.Time) predicate.ReviewVerdict
OverrideAtIn applies the In predicate on the "override_at" field.
func OverrideAtIsNil ¶
func OverrideAtIsNil() predicate.ReviewVerdict
OverrideAtIsNil applies the IsNil predicate on the "override_at" field.
func OverrideAtLT ¶
func OverrideAtLT(v time.Time) predicate.ReviewVerdict
OverrideAtLT applies the LT predicate on the "override_at" field.
func OverrideAtLTE ¶
func OverrideAtLTE(v time.Time) predicate.ReviewVerdict
OverrideAtLTE applies the LTE predicate on the "override_at" field.
func OverrideAtNEQ ¶
func OverrideAtNEQ(v time.Time) predicate.ReviewVerdict
OverrideAtNEQ applies the NEQ predicate on the "override_at" field.
func OverrideAtNotIn ¶
func OverrideAtNotIn(vs ...time.Time) predicate.ReviewVerdict
OverrideAtNotIn applies the NotIn predicate on the "override_at" field.
func OverrideAtNotNil ¶
func OverrideAtNotNil() predicate.ReviewVerdict
OverrideAtNotNil applies the NotNil predicate on the "override_at" field.
func OverrideBy ¶
func OverrideBy(v string) predicate.ReviewVerdict
OverrideBy applies equality check predicate on the "override_by" field. It's identical to OverrideByEQ.
func OverrideByContains ¶
func OverrideByContains(v string) predicate.ReviewVerdict
OverrideByContains applies the Contains predicate on the "override_by" field.
func OverrideByContainsFold ¶
func OverrideByContainsFold(v string) predicate.ReviewVerdict
OverrideByContainsFold applies the ContainsFold predicate on the "override_by" field.
func OverrideByEQ ¶
func OverrideByEQ(v string) predicate.ReviewVerdict
OverrideByEQ applies the EQ predicate on the "override_by" field.
func OverrideByEqualFold ¶
func OverrideByEqualFold(v string) predicate.ReviewVerdict
OverrideByEqualFold applies the EqualFold predicate on the "override_by" field.
func OverrideByGT ¶
func OverrideByGT(v string) predicate.ReviewVerdict
OverrideByGT applies the GT predicate on the "override_by" field.
func OverrideByGTE ¶
func OverrideByGTE(v string) predicate.ReviewVerdict
OverrideByGTE applies the GTE predicate on the "override_by" field.
func OverrideByHasPrefix ¶
func OverrideByHasPrefix(v string) predicate.ReviewVerdict
OverrideByHasPrefix applies the HasPrefix predicate on the "override_by" field.
func OverrideByHasSuffix ¶
func OverrideByHasSuffix(v string) predicate.ReviewVerdict
OverrideByHasSuffix applies the HasSuffix predicate on the "override_by" field.
func OverrideByIn ¶
func OverrideByIn(vs ...string) predicate.ReviewVerdict
OverrideByIn applies the In predicate on the "override_by" field.
func OverrideByIsNil ¶
func OverrideByIsNil() predicate.ReviewVerdict
OverrideByIsNil applies the IsNil predicate on the "override_by" field.
func OverrideByLT ¶
func OverrideByLT(v string) predicate.ReviewVerdict
OverrideByLT applies the LT predicate on the "override_by" field.
func OverrideByLTE ¶
func OverrideByLTE(v string) predicate.ReviewVerdict
OverrideByLTE applies the LTE predicate on the "override_by" field.
func OverrideByNEQ ¶
func OverrideByNEQ(v string) predicate.ReviewVerdict
OverrideByNEQ applies the NEQ predicate on the "override_by" field.
func OverrideByNotIn ¶
func OverrideByNotIn(vs ...string) predicate.ReviewVerdict
OverrideByNotIn applies the NotIn predicate on the "override_by" field.
func OverrideByNotNil ¶
func OverrideByNotNil() predicate.ReviewVerdict
OverrideByNotNil applies the NotNil predicate on the "override_by" field.
func OverrideReason ¶
func OverrideReason(v string) predicate.ReviewVerdict
OverrideReason applies equality check predicate on the "override_reason" field. It's identical to OverrideReasonEQ.
func OverrideReasonContains ¶
func OverrideReasonContains(v string) predicate.ReviewVerdict
OverrideReasonContains applies the Contains predicate on the "override_reason" field.
func OverrideReasonContainsFold ¶
func OverrideReasonContainsFold(v string) predicate.ReviewVerdict
OverrideReasonContainsFold applies the ContainsFold predicate on the "override_reason" field.
func OverrideReasonEQ ¶
func OverrideReasonEQ(v string) predicate.ReviewVerdict
OverrideReasonEQ applies the EQ predicate on the "override_reason" field.
func OverrideReasonEqualFold ¶
func OverrideReasonEqualFold(v string) predicate.ReviewVerdict
OverrideReasonEqualFold applies the EqualFold predicate on the "override_reason" field.
func OverrideReasonGT ¶
func OverrideReasonGT(v string) predicate.ReviewVerdict
OverrideReasonGT applies the GT predicate on the "override_reason" field.
func OverrideReasonGTE ¶
func OverrideReasonGTE(v string) predicate.ReviewVerdict
OverrideReasonGTE applies the GTE predicate on the "override_reason" field.
func OverrideReasonHasPrefix ¶
func OverrideReasonHasPrefix(v string) predicate.ReviewVerdict
OverrideReasonHasPrefix applies the HasPrefix predicate on the "override_reason" field.
func OverrideReasonHasSuffix ¶
func OverrideReasonHasSuffix(v string) predicate.ReviewVerdict
OverrideReasonHasSuffix applies the HasSuffix predicate on the "override_reason" field.
func OverrideReasonIn ¶
func OverrideReasonIn(vs ...string) predicate.ReviewVerdict
OverrideReasonIn applies the In predicate on the "override_reason" field.
func OverrideReasonIsNil ¶
func OverrideReasonIsNil() predicate.ReviewVerdict
OverrideReasonIsNil applies the IsNil predicate on the "override_reason" field.
func OverrideReasonLT ¶
func OverrideReasonLT(v string) predicate.ReviewVerdict
OverrideReasonLT applies the LT predicate on the "override_reason" field.
func OverrideReasonLTE ¶
func OverrideReasonLTE(v string) predicate.ReviewVerdict
OverrideReasonLTE applies the LTE predicate on the "override_reason" field.
func OverrideReasonNEQ ¶
func OverrideReasonNEQ(v string) predicate.ReviewVerdict
OverrideReasonNEQ applies the NEQ predicate on the "override_reason" field.
func OverrideReasonNotIn ¶
func OverrideReasonNotIn(vs ...string) predicate.ReviewVerdict
OverrideReasonNotIn applies the NotIn predicate on the "override_reason" field.
func OverrideReasonNotNil ¶
func OverrideReasonNotNil() predicate.ReviewVerdict
OverrideReasonNotNil applies the NotNil predicate on the "override_reason" field.
func PerCriterion ¶
func PerCriterion(v string) predicate.ReviewVerdict
PerCriterion applies equality check predicate on the "per_criterion" field. It's identical to PerCriterionEQ.
func PerCriterionContains ¶
func PerCriterionContains(v string) predicate.ReviewVerdict
PerCriterionContains applies the Contains predicate on the "per_criterion" field.
func PerCriterionContainsFold ¶
func PerCriterionContainsFold(v string) predicate.ReviewVerdict
PerCriterionContainsFold applies the ContainsFold predicate on the "per_criterion" field.
func PerCriterionEQ ¶
func PerCriterionEQ(v string) predicate.ReviewVerdict
PerCriterionEQ applies the EQ predicate on the "per_criterion" field.
func PerCriterionEqualFold ¶
func PerCriterionEqualFold(v string) predicate.ReviewVerdict
PerCriterionEqualFold applies the EqualFold predicate on the "per_criterion" field.
func PerCriterionGT ¶
func PerCriterionGT(v string) predicate.ReviewVerdict
PerCriterionGT applies the GT predicate on the "per_criterion" field.
func PerCriterionGTE ¶
func PerCriterionGTE(v string) predicate.ReviewVerdict
PerCriterionGTE applies the GTE predicate on the "per_criterion" field.
func PerCriterionHasPrefix ¶
func PerCriterionHasPrefix(v string) predicate.ReviewVerdict
PerCriterionHasPrefix applies the HasPrefix predicate on the "per_criterion" field.
func PerCriterionHasSuffix ¶
func PerCriterionHasSuffix(v string) predicate.ReviewVerdict
PerCriterionHasSuffix applies the HasSuffix predicate on the "per_criterion" field.
func PerCriterionIn ¶
func PerCriterionIn(vs ...string) predicate.ReviewVerdict
PerCriterionIn applies the In predicate on the "per_criterion" field.
func PerCriterionIsNil ¶
func PerCriterionIsNil() predicate.ReviewVerdict
PerCriterionIsNil applies the IsNil predicate on the "per_criterion" field.
func PerCriterionLT ¶
func PerCriterionLT(v string) predicate.ReviewVerdict
PerCriterionLT applies the LT predicate on the "per_criterion" field.
func PerCriterionLTE ¶
func PerCriterionLTE(v string) predicate.ReviewVerdict
PerCriterionLTE applies the LTE predicate on the "per_criterion" field.
func PerCriterionNEQ ¶
func PerCriterionNEQ(v string) predicate.ReviewVerdict
PerCriterionNEQ applies the NEQ predicate on the "per_criterion" field.
func PerCriterionNotIn ¶
func PerCriterionNotIn(vs ...string) predicate.ReviewVerdict
PerCriterionNotIn applies the NotIn predicate on the "per_criterion" field.
func PerCriterionNotNil ¶
func PerCriterionNotNil() predicate.ReviewVerdict
PerCriterionNotNil applies the NotNil predicate on the "per_criterion" field.
func PromptHash ¶
func PromptHash(v string) predicate.ReviewVerdict
PromptHash applies equality check predicate on the "prompt_hash" field. It's identical to PromptHashEQ.
func PromptHashContains ¶
func PromptHashContains(v string) predicate.ReviewVerdict
PromptHashContains applies the Contains predicate on the "prompt_hash" field.
func PromptHashContainsFold ¶
func PromptHashContainsFold(v string) predicate.ReviewVerdict
PromptHashContainsFold applies the ContainsFold predicate on the "prompt_hash" field.
func PromptHashEQ ¶
func PromptHashEQ(v string) predicate.ReviewVerdict
PromptHashEQ applies the EQ predicate on the "prompt_hash" field.
func PromptHashEqualFold ¶
func PromptHashEqualFold(v string) predicate.ReviewVerdict
PromptHashEqualFold applies the EqualFold predicate on the "prompt_hash" field.
func PromptHashGT ¶
func PromptHashGT(v string) predicate.ReviewVerdict
PromptHashGT applies the GT predicate on the "prompt_hash" field.
func PromptHashGTE ¶
func PromptHashGTE(v string) predicate.ReviewVerdict
PromptHashGTE applies the GTE predicate on the "prompt_hash" field.
func PromptHashHasPrefix ¶
func PromptHashHasPrefix(v string) predicate.ReviewVerdict
PromptHashHasPrefix applies the HasPrefix predicate on the "prompt_hash" field.
func PromptHashHasSuffix ¶
func PromptHashHasSuffix(v string) predicate.ReviewVerdict
PromptHashHasSuffix applies the HasSuffix predicate on the "prompt_hash" field.
func PromptHashIn ¶
func PromptHashIn(vs ...string) predicate.ReviewVerdict
PromptHashIn applies the In predicate on the "prompt_hash" field.
func PromptHashIsNil ¶
func PromptHashIsNil() predicate.ReviewVerdict
PromptHashIsNil applies the IsNil predicate on the "prompt_hash" field.
func PromptHashLT ¶
func PromptHashLT(v string) predicate.ReviewVerdict
PromptHashLT applies the LT predicate on the "prompt_hash" field.
func PromptHashLTE ¶
func PromptHashLTE(v string) predicate.ReviewVerdict
PromptHashLTE applies the LTE predicate on the "prompt_hash" field.
func PromptHashNEQ ¶
func PromptHashNEQ(v string) predicate.ReviewVerdict
PromptHashNEQ applies the NEQ predicate on the "prompt_hash" field.
func PromptHashNotIn ¶
func PromptHashNotIn(vs ...string) predicate.ReviewVerdict
PromptHashNotIn applies the NotIn predicate on the "prompt_hash" field.
func PromptHashNotNil ¶
func PromptHashNotNil() predicate.ReviewVerdict
PromptHashNotNil applies the NotNil predicate on the "prompt_hash" field.
func Summary ¶
func Summary(v string) predicate.ReviewVerdict
Summary applies equality check predicate on the "summary" field. It's identical to SummaryEQ.
func SummaryContains ¶
func SummaryContains(v string) predicate.ReviewVerdict
SummaryContains applies the Contains predicate on the "summary" field.
func SummaryContainsFold ¶
func SummaryContainsFold(v string) predicate.ReviewVerdict
SummaryContainsFold applies the ContainsFold predicate on the "summary" field.
func SummaryEQ ¶
func SummaryEQ(v string) predicate.ReviewVerdict
SummaryEQ applies the EQ predicate on the "summary" field.
func SummaryEqualFold ¶
func SummaryEqualFold(v string) predicate.ReviewVerdict
SummaryEqualFold applies the EqualFold predicate on the "summary" field.
func SummaryGT ¶
func SummaryGT(v string) predicate.ReviewVerdict
SummaryGT applies the GT predicate on the "summary" field.
func SummaryGTE ¶
func SummaryGTE(v string) predicate.ReviewVerdict
SummaryGTE applies the GTE predicate on the "summary" field.
func SummaryHasPrefix ¶
func SummaryHasPrefix(v string) predicate.ReviewVerdict
SummaryHasPrefix applies the HasPrefix predicate on the "summary" field.
func SummaryHasSuffix ¶
func SummaryHasSuffix(v string) predicate.ReviewVerdict
SummaryHasSuffix applies the HasSuffix predicate on the "summary" field.
func SummaryIn ¶
func SummaryIn(vs ...string) predicate.ReviewVerdict
SummaryIn applies the In predicate on the "summary" field.
func SummaryIsNil ¶
func SummaryIsNil() predicate.ReviewVerdict
SummaryIsNil applies the IsNil predicate on the "summary" field.
func SummaryLT ¶
func SummaryLT(v string) predicate.ReviewVerdict
SummaryLT applies the LT predicate on the "summary" field.
func SummaryLTE ¶
func SummaryLTE(v string) predicate.ReviewVerdict
SummaryLTE applies the LTE predicate on the "summary" field.
func SummaryNEQ ¶
func SummaryNEQ(v string) predicate.ReviewVerdict
SummaryNEQ applies the NEQ predicate on the "summary" field.
func SummaryNotIn ¶
func SummaryNotIn(vs ...string) predicate.ReviewVerdict
SummaryNotIn applies the NotIn predicate on the "summary" field.
func SummaryNotNil ¶
func SummaryNotNil() predicate.ReviewVerdict
SummaryNotNil applies the NotNil predicate on the "summary" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ReviewVerdict queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDiffHash ¶
func ByDiffHash(opts ...sql.OrderTermOption) OrderOption
ByDiffHash orders the results by the diff_hash field.
func ByDiffTokenCount ¶
func ByDiffTokenCount(opts ...sql.OrderTermOption) OrderOption
ByDiffTokenCount orders the results by the diff_token_count field.
func ByDiffTruncated ¶
func ByDiffTruncated(opts ...sql.OrderTermOption) OrderOption
ByDiffTruncated orders the results by the diff_truncated field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByItemSessionField ¶
func ByItemSessionField(field string, opts ...sql.OrderTermOption) OrderOption
ByItemSessionField orders the results by item_session field.
func ByOverallOutcome ¶
func ByOverallOutcome(opts ...sql.OrderTermOption) OrderOption
ByOverallOutcome orders the results by the overall_outcome field.
func ByOverrideAt ¶
func ByOverrideAt(opts ...sql.OrderTermOption) OrderOption
ByOverrideAt orders the results by the override_at field.
func ByOverrideBy ¶
func ByOverrideBy(opts ...sql.OrderTermOption) OrderOption
ByOverrideBy orders the results by the override_by field.
func ByOverrideReason ¶
func ByOverrideReason(opts ...sql.OrderTermOption) OrderOption
ByOverrideReason orders the results by the override_reason field.
func ByPerCriterion ¶
func ByPerCriterion(opts ...sql.OrderTermOption) OrderOption
ByPerCriterion orders the results by the per_criterion field.
func ByPromptHash ¶
func ByPromptHash(opts ...sql.OrderTermOption) OrderOption
ByPromptHash orders the results by the prompt_hash field.
func BySummary ¶
func BySummary(opts ...sql.OrderTermOption) OrderOption
BySummary orders the results by the summary field.