Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProcessInspector ¶
type ProcessInspector struct{}
ProcessInspector wraps gopsutil process inspection for non-Darwin platforms.
func NewProcessInspector ¶
func NewProcessInspector() *ProcessInspector
NewProcessInspector creates a new ProcessInspector.
func (*ProcessInspector) CreateTime ¶
func (p *ProcessInspector) CreateTime(pid int32) (int64, error)
CreateTime returns the creation time of the process in epoch milliseconds.
func (*ProcessInspector) Cwd ¶
func (p *ProcessInspector) Cwd(pid int32) (string, error)
Cwd returns the current working directory for the given PID.
Click to show internal directories.
Click to hide internal directories.