Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetReliableTerminalSize ¶
GetReliableTerminalSize returns the most reliable terminal dimensions This function maintains backward compatibility with existing code
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager handles terminal size detection and management
func (*Manager) CreateWindowSizeMsg ¶
func (m *Manager) CreateWindowSizeMsg() tea.WindowSizeMsg
CreateWindowSizeMsg creates a BubbleTea WindowSizeMsg with current dimensions
func (*Manager) DetectSize ¶
DetectSize attempts to detect the real terminal size using multiple methods
func (*Manager) GetReliableSize ¶
GetReliableSize returns the most reliable terminal dimensions
func (*Manager) HasSizeChanged ¶
HasSizeChanged returns true if the terminal size has changed since last check
type SignalManager ¶
type SignalManager struct {
// contains filtered or unexported fields
}
SignalManager handles terminal-related signal management
func NewSignalManager ¶
func NewSignalManager(sizeManager *Manager) *SignalManager
NewSignalManager creates a new signal manager with terminal size detection
func (*SignalManager) CreateSizeCheckCmd ¶
func (sm *SignalManager) CreateSizeCheckCmd() tea.Cmd
CreateSizeCheckCmd creates a ticker for checking terminal size changes (for IntelliJ compatibility)
func (*SignalManager) SetupResizeHandler ¶
func (sm *SignalManager) SetupResizeHandler() tea.Cmd
SetupResizeHandler sets up proper SIGWINCH signal handling for terminal resize events
type SizeCheckMsg ¶
type SizeCheckMsg struct{}
SizeCheckMsg is sent periodically to check terminal size for IntelliJ compatibility
type SizeInfo ¶
type SizeInfo struct {
// PTY dimensions (what the pseudo-terminal reports)
PTYWidth int
PTYHeight int
// Environment variable dimensions
EnvWidth int
EnvHeight int
// Actual dimensions we should use
ActualWidth int
ActualHeight int
// Debug information
Method string
IsReliable bool
Issues []string
}
SizeInfo contains comprehensive terminal size information
func DetectTerminalSize ¶
func DetectTerminalSize() *SizeInfo
DetectTerminalSize provides backward compatibility with the old function